! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! Linear Algebra Data and Routines File
! 
! Generated by KPP-2.2.4_gc symbolic chemistry Kinetics PreProcessor
!       (http://www.cs.vt.edu/~asandu/Software/KPP)
! KPP is distributed under GPL, the general public licence
!       (http://www.gnu.org/copyleft/gpl.html)
! (C) 1995-1997, V. Damian & A. Sandu, CGRER, Univ. Iowa
! (C) 1997-2005, A. Sandu, Michigan Tech, Virginia Tech
!     With important contributions from:
!        M. Damian, Villanova University, USA
!        R. Sander, Max-Planck Institute for Chemistry, Mainz, Germany
! 
! File                 : gckpp_LinearAlgebra.f90
! Time                 : Wed Aug 23 13:23:03 2017
! Working directory    : /n/home05/msulprizio/GC/FlexChem/Mechanisms/v11-02c/Tropchem
! Equation file        : gckpp.kpp
! Output root filename : gckpp
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~



MODULE gckpp_LinearAlgebra

  USE gckpp_Parameters
  USE gckpp_JacobianSP

  IMPLICIT NONE

CONTAINS


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! SPARSE_UTIL - SPARSE utility functions
!   Arguments :
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppDecomp( JVS, IER )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Sparse LU factorization
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER  :: IER
      REAL(kind=dp) :: JVS(LU_NONZERO), W(NVAR), a
      INTEGER  :: k, kk, j, jj

      a = 0. ! mz_rs_20050606
      IER = 0
      DO k=1,NVAR
        ! mz_rs_20050606: don't check if real value == 0
        ! IF ( JVS( LU_DIAG(k) ) .EQ. 0. ) THEN
        IF ( ABS(JVS(LU_DIAG(k))) < TINY(a) ) THEN
            IER = k
            RETURN
        END IF
        DO kk = LU_CROW(k), LU_CROW(k+1)-1
              W( LU_ICOL(kk) ) = JVS(kk)
        END DO
        DO kk = LU_CROW(k), LU_DIAG(k)-1
            j = LU_ICOL(kk)
            a = -W(j) / JVS( LU_DIAG(j) )
            W(j) = -a
            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
               W( LU_ICOL(jj) ) = W( LU_ICOL(jj) ) + a*JVS(jj)
            END DO
         END DO
         DO kk = LU_CROW(k), LU_CROW(k+1)-1
            JVS(kk) = W( LU_ICOL(kk) )
         END DO
      END DO
      
END SUBROUTINE KppDecomp


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppDecompCmplx( JVS, IER )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Sparse LU factorization, complex
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER        :: IER
      DOUBLE COMPLEX :: JVS(LU_NONZERO), W(NVAR), a
      REAL(kind=dp)  :: b = 0.0
      INTEGER        :: k, kk, j, jj

      IER = 0
      DO k=1,NVAR
        IF ( ABS(JVS(LU_DIAG(k))) < TINY(b) ) THEN
            IER = k
            RETURN
        END IF
        DO kk = LU_CROW(k), LU_CROW(k+1)-1
              W( LU_ICOL(kk) ) = JVS(kk)
        END DO
        DO kk = LU_CROW(k), LU_DIAG(k)-1
            j = LU_ICOL(kk)
            a = -W(j) / JVS( LU_DIAG(j) )
            W(j) = -a
            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
               W( LU_ICOL(jj) ) = W( LU_ICOL(jj) ) + a*JVS(jj)
            END DO
         END DO
         DO kk = LU_CROW(k), LU_CROW(k+1)-1
            JVS(kk) = W( LU_ICOL(kk) )
         END DO
      END DO
      
END SUBROUTINE KppDecompCmplx


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppDecompCmplxR( JVSR, JVSI, IER )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!    Sparse LU factorization, complex
!   (Real and Imaginary parts are used instead of complex data type)     
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       :: IER
      REAL(kind=dp) :: JVSR(LU_NONZERO), JVSI(LU_NONZERO) 
      REAL(kind=dp) :: WR(NVAR), WI(NVAR), ar, ai, den
      INTEGER       :: k, kk, j, jj

      IER = 0
      ar  = 0.0
      DO k=1,NVAR
        IF (  ( ABS(JVSR(LU_DIAG(k))) < TINY(ar) ) .AND. &
              ( ABS(JVSI(LU_DIAG(k))) < TINY(ar) ) )  THEN
            IER = k
            RETURN
        END IF
        DO kk = LU_CROW(k), LU_CROW(k+1)-1
              WR( LU_ICOL(kk) ) = JVSR(kk)
              WI( LU_ICOL(kk) ) = JVSI(kk)
        END DO
        DO kk = LU_CROW(k), LU_DIAG(k)-1
            j = LU_ICOL(kk)
            den = JVSR(LU_DIAG(j))**2 + JVSI(LU_DIAG(j))**2
            ar = -(WR(j)*JVSR(LU_DIAG(j)) + WI(j)*JVSI(LU_DIAG(j)))/den
            ai = -(WI(j)*JVSR(LU_DIAG(j)) - WR(j)*JVSI(LU_DIAG(j)))/den
            WR(j) = -ar
            WI(j) = -ai
            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
               WR( LU_ICOL(jj) ) = WR( LU_ICOL(jj) ) + ar*JVSR(jj) - ai*JVSI(jj)
               WI( LU_ICOL(jj) ) = WI( LU_ICOL(jj) ) + ar*JVSI(jj) + ai*JVSR(jj)
            END DO
         END DO
         DO kk = LU_CROW(k), LU_CROW(k+1)-1
            JVSR(kk) = WR( LU_ICOL(kk) )
            JVSI(kk) = WI( LU_ICOL(kk) )
         END DO
      END DO

END SUBROUTINE KppDecompCmplxR


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveIndirect( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Sparse solve subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER  :: i, j
      REAL(kind=dp) :: JVS(LU_NONZERO), X(NVAR), sum

      DO i=1,NVAR
         DO j = LU_CROW(i), LU_DIAG(i)-1 
             X(i) = X(i) - JVS(j)*X(LU_ICOL(j));
         END DO  
      END DO

      DO i=NVAR,1,-1
        sum = X(i);
        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
          sum = sum - JVS(j)*X(LU_ICOL(j));
        END DO
        X(i) = sum/JVS(LU_DIAG(i));
      END DO
      
END SUBROUTINE KppSolveIndirect


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveTRIndirect( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Complex sparse solve transpose subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       :: i, j
      REAL(kind=dp) :: JVS(LU_NONZERO), X(NVAR)

      DO i=1,NVAR
        X(i) = X(i)/JVS(LU_DIAG(i))
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO

      DO i=NVAR, 1, -1
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_CROW(i),LU_DIAG(i)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO
      
END SUBROUTINE KppSolveTRIndirect


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveCmplx( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Complex sparse solve subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER        :: i, j
      DOUBLE COMPLEX :: JVS(LU_NONZERO), X(NVAR), sum

      DO i=1,NVAR
         DO j = LU_CROW(i), LU_DIAG(i)-1 
             X(i) = X(i) - JVS(j)*X(LU_ICOL(j));
         END DO  
      END DO

      DO i=NVAR,1,-1
        sum = X(i);
        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
          sum = sum - JVS(j)*X(LU_ICOL(j));
        END DO
        X(i) = sum/JVS(LU_DIAG(i));
      END DO
      
END SUBROUTINE KppSolveCmplx

! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveCmplxR( JVSR, JVSI, XR, XI )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!   Complex sparse solve subroutine using indirect addressing
!   (Real and Imaginary parts are used instead of complex data type)     
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       ::  i, j
      REAL(kind=dp) ::  JVSR(LU_NONZERO), JVSI(LU_NONZERO), XR(NVAR), XI(NVAR), sumr, sumi, den

      DO i=1,NVAR
         DO j = LU_CROW(i), LU_DIAG(i)-1 
             XR(i) = XR(i) - (JVSR(j)*XR(LU_ICOL(j)) - JVSI(j)*XI(LU_ICOL(j)))
             XI(i) = XI(i) - (JVSR(j)*XI(LU_ICOL(j)) + JVSI(j)*XR(LU_ICOL(j)))
         END DO  
      END DO

      DO i=NVAR,1,-1
        sumr = XR(i); sumi = XI(i)
        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
            sumr = sumr - (JVSR(j)*XR(LU_ICOL(j)) - JVSI(j)*XI(LU_ICOL(j)))
            sumi = sumi - (JVSR(j)*XI(LU_ICOL(j)) + JVSI(j)*XR(LU_ICOL(j)))
        END DO
        den   = JVSR(LU_DIAG(i))**2 + JVSI(LU_DIAG(i))**2
        XR(i) = (sumr*JVSR(LU_DIAG(i)) + sumi*JVSI(LU_DIAG(i)))/den
        XI(i) = (sumi*JVSR(LU_DIAG(i)) - sumr*JVSI(LU_DIAG(i)))/den
      END DO
      
END SUBROUTINE KppSolveCmplxR


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveTRCmplx( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Complex sparse solve transpose subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER        :: i, j
      DOUBLE COMPLEX :: JVS(LU_NONZERO), X(NVAR)

      DO i=1,NVAR
        X(i) = X(i)/JVS(LU_DIAG(i))
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO

      DO i=NVAR, 1, -1
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_CROW(i),LU_DIAG(i)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO
      
END SUBROUTINE KppSolveTRCmplx


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveTRCmplxR( JVSR, JVSI, XR, XI )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!   Complex sparse solve transpose subroutine using indirect addressing
!   (Real and Imaginary parts are used instead of complex data type)     
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       ::  i, j
      REAL(kind=dp) ::  JVSR(LU_NONZERO), JVSI(LU_NONZERO), XR(NVAR), XI(NVAR), den

      DO i=1,NVAR
        den   = JVSR(LU_DIAG(i))**2 + JVSI(LU_DIAG(i))**2
        XR(i) = (XR(i)*JVSR(LU_DIAG(i)) + XI(i)*JVSI(LU_DIAG(i)))/den
        XI(i) = (XI(i)*JVSR(LU_DIAG(i)) - XR(i)*JVSI(LU_DIAG(i)))/den
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
	  XR(LU_ICOL(j)) = XR(LU_ICOL(j))-(JVSR(j)*XR(i) - JVSI(j)*XI(i))
	  XI(LU_ICOL(j)) = XI(LU_ICOL(j))-(JVSI(j)*XR(i) + JVSR(j)*XI(i))
	END DO
      END DO

      DO i=NVAR, 1, -1
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_CROW(i),LU_DIAG(i)-1
	  XR(LU_ICOL(j)) = XR(LU_ICOL(j))-(JVSR(j)*XR(i) - JVSI(j)*XI(i))
	  XI(LU_ICOL(j)) = XI(LU_ICOL(j))-(JVSI(j)*XR(i) + JVSR(j)*XI(i))
	END DO
      END DO
      
END SUBROUTINE KppSolveTRCmplxR


!
! Next few commented subroutines perform sparse big linear algebra
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE KppDecompBig( JVS, IP, IER )
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!        Sparse LU factorization
!!        for the Runge Kutta (3n)x(3n) linear system
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!  USE gckpp_Parameters
!  USE gckpp_JacobianSP
!
!      INTEGER  :: IP3(3), IER, IP(3,NVAR)
!      REAL(kind=dp) :: JVS(3,3,LU_NONZERO), W(3,3,NVAR), a(3,3), E(3,3)
!      INTEGER  :: k, kk, j, jj
!
!      a = 0.0d0
!      IER = 0
!      DO k=1,NVAR
!        DO kk = LU_CROW(k), LU_CROW(k+1)-1
!              W( 1:3,1:3,LU_ICOL(kk) ) = JVS(1:3,1:3,kk)
!        END DO
!        DO kk = LU_CROW(k), LU_DIAG(k)-1
!            j = LU_ICOL(kk)
!            E(1:3,1:3) = JVS( 1:3,1:3,LU_DIAG(j) )
!            ! CALL DGETRF(3,3,E,3,IP3,IER) 
!            CALL FAC3(E,IP3,IER)
!            IF ( IER /= 0 )  RETURN
!            ! a = W(j) / JVS( LU_DIAG(j) )
!            a(1:3,1:3) = W( 1:3,1:3,j )
!            ! CALL DGETRS ('N',3,3,E,3,IP3,a,3,IER) 
!            CALL SOL3('N',E,IP3,a(1,1))
!            CALL SOL3('N',E,IP3,a(1,2))
!            CALL SOL3('N',E,IP3,a(1,3))
!            W(1:3,1:3,j) = a(1:3,1:3)
!            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
!               W( 1:3,1:3,LU_ICOL(jj) ) = W( 1:3,1:3,LU_ICOL(jj) ) &
!                        - MATMUL( a(1:3,1:3) , JVS(1:3,1:3,jj) )
!            END DO
!         END DO
!         DO kk = LU_CROW(k), LU_CROW(k+1)-1
!            JVS(1:3,1:3,kk) = W( 1:3,1:3,LU_ICOL(kk) )
!         END DO
!      END DO
!
!      DO k=1,NVAR
!         ! CALL WGEFA(JVS(1,1,LU_DIAG(k)),3,3,IP(1,k),IER)
!         ! CALL DGETRF(3,3,JVS(1,1,LU_DIAG(k)),3,IP(1,k),IER)
!         CALL FAC3(JVS(1,1,LU_DIAG(k)),IP(1,k),IER)
!         IF ( IER /= 0 )  RETURN
!      END DO 
!      
!END SUBROUTINE KppDecompBig
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE KppSolveBig( JVS, IP, X )
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!        Sparse solve subroutine using indirect addressing
!!        for the Runge Kutta (3n)x(3n) linear system
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!  USE gckpp_Parameters
!  USE gckpp_JacobianSP
!
!      INTEGER  :: i, j, k, m, IP3(3), IP(3,NVAR), IER
!      REAL(kind=dp) :: JVS(3,3,LU_NONZERO), X(3,NVAR), sum(3)
!
!      DO i=1,NVAR
!        DO j = LU_CROW(i), LU_DIAG(i)-1 
!          !X(1:3,i) = X(1:3,i) - MATMUL(JVS(1:3,1:3,j),X(1:3,LU_ICOL(j)));
!          DO k=1,3
!            DO m=1,3
!	       X(k,i) = X(k,i) - JVS(k,m,j)*X(m,LU_ICOL(j))
!            END DO
!          END DO
!        END DO  
!      END DO
!
!      DO i=NVAR,1,-1
!        sum(1:3) = X(1:3,i);
!        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
!          !sum(1:3) = sum(1:3) - MATMUL(JVS(1:3,1:3,j),X(1:3,LU_ICOL(j)));
!          DO k=1,3
!            DO m=1,3
!	       sum(k) = sum(k) - JVS(k,m,j)*X(m,LU_ICOL(j))
!            END DO
!          END DO
!        END DO
!        ! X(i) = sum/JVS(LU_DIAG(i));
!        ! CALL DGETRS ('N',3,1,JVS(1:3,1:3,LU_DIAG(i)),3,IP(1,i),sum,3,0) 
!        ! CALL WGESL('N',JVS(1,1,LU_DIAG(i)),3,3,IP(1,i),sum)
!        CALL SOL3('N',JVS(1,1,LU_DIAG(i)),IP(1,i),sum)
!        X(1:3,i) = sum(1:3)
!      END DO
!      
!END SUBROUTINE KppSolveBig
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE KppSolveBigTR( JVS, IP, X )
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!        Big sparse transpose solve using indirect addressing
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!  USE gckpp_Parameters
!  USE gckpp_JacobianSP
!
!      INTEGER       :: i, j, k, m, IP(3,NVAR)
!      REAL(kind=dp) :: JVS(3,3,LU_NONZERO), X(3,NVAR)
!
!      DO i=1,NVAR
!        ! X(i) = X(i)/JVS(LU_DIAG(i))
!        CALL SOL3('T',JVS(1,1,LU_DIAG(i)),IP(1,i),X(1,i))
!        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
!	  !X(1:3,LU_ICOL(j)) = X(1:3,LU_ICOL(j)) &
!          !    - MATMUL( TRANSPOSE(JVS(1:3,1:3,j)), X(1:3,i) )
!          DO k=1,3
!            DO m=1,3
!	       X(k,LU_ICOL(j)) = X(k,LU_ICOL(j)) - JVS(m,k,j)*X(m,i)
!            END DO
!          END DO
!	END DO
!      END DO
!
!      DO i=NVAR, 1, -1
!        DO j=LU_CROW(i),LU_DIAG(i)-1
!	  !X(1:3,LU_ICOL(j)) = X(1:3,LU_ICOL(j)) &
!          !   - MATMUL( TRANSPOSE(JVS(1:3,1:3,j)), X(1:3,i) )
!          DO k=1,3
!            DO m=1,3
!	       X(k,LU_ICOL(j)) = X(k,LU_ICOL(j)) - JVS(m,k,j)*X(m,i)
!            END DO
!          END DO
!	END DO
!      END DO
!      
!END SUBROUTINE KppSolveBigTR
!
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE FAC3(A,IPVT,INFO)
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!     FAC3 FACTORS THE MATRIX A (3,3) BY
!!           GAUSS ELIMINATION WITH PARTIAL PIVOTING
!!     LINPACK - LIKE 
!!
!!     Remove comments to perform pivoting
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!
!      REAL(kind=dp) :: A(3,3)
!      INTEGER       :: IPVT(3),INFO
!!      INTEGER       :: L
!!      REAL(kind=dp) :: t, dmax, da, TMP(3)
!      REAL(kind=dp), PARAMETER :: ZERO = 0.0, ONE = 1.0
!
!      info = 0
!!      t = TINY(da)
!!      
!!      da = ABS(A(1,1)); L = 1
!!      IF ( ABS(A(2,1))>da ) THEN
!!        da = ABS(A(2,1)); L = 2
!!        IF ( ABS(A(3,1))>da ) THEN
!!          L = 3
!!        END IF  
!!      END IF  
!!      IPVT(1)  = L
!!      IF (L /=1 ) THEN
!!         TMP(1:3) = A(L,1:3)
!!         A(L,1:3) = A(1,1:3)
!!         A(1,1:3) = TMP(1:3)
!!      END IF
!!      IF (ABS(A(1,1)) < t) THEN
!!         info = 1
!!         return
!!      END IF   
!!
!      A(2,1) = A(2,1)/A(1,1)
!      A(2,2) = A(2,2) - A(2,1)*A(1,2)
!      A(2,3) = A(2,3) - A(2,1)*A(1,3)
!      A(3,1) = A(3,1)/A(1,1)
!      A(3,2) = A(3,2) - A(3,1)*A(1,2)
!      A(3,3) = A(3,3) - A(3,1)*A(1,3)
!      
!!      IPVT(2)  = 2
!!      IF (ABS(A(3,2))>ABS(A(2,2))) THEN
!!         IPVT(2)  = 3
!!         TMP(2:3) = A(3,2:3)
!!         A(3,2:3) = A(2,2:3)
!!         A(2,2:3) = TMP(2:3)
!!      END IF
!!      IF (ABS(A(2,2)) < t) THEN
!!         info = 1
!!         return
!!      END IF   
!!      
!      A(3,2)   = A(3,2)/A(2,2)
!      A(3,3)   = A(3,3) - A(3,2)*A(2,3)
!      IPVT(3)  = 3
!      
!END SUBROUTINE FAC3
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE SOL3(Trans,A,IPVT,b)
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!     SOL3 solves the system 3x3
!!     A * x = b  or  trans(a) * x = b
!!     using the factors computed by WGEFA.
!!
!!     Trans      = 'N'   to solve  A*x = b ,
!!                = 'T'   to solve  transpose(A)*x = b
!!     LINPACK - LIKE 
!!
!!     Remove comments to use pivoting
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!      CHARACTER     :: Trans
!      REAL(kind=dp) :: a(3,3),b(3)
!      INTEGER       :: IPVT(3)
!!      INTEGER       :: L
!!      REAL(kind=dp) :: TMP
!      
!      SELECT CASE (Trans)
!
!      CASE ('n','N')  !  Solve  A * x = b
!
!!     Solve  L*y = b
!!         L = IPVT(1)
!!         IF (L /= 1) THEN
!!            TMP = B(1); B(1) = B(L); B(L) = TMP
!!         END IF
!         b(2) = b(2)-A(2,1)*b(1)
!         b(3) = b(3)-A(3,1)*b(1)
!         
!!         L = IPVT(2)
!!         IF (L /= 2) THEN
!!            TMP = B(2); B(2) = B(L); B(L) = TMP
!!         END IF
!         b(3) = b(3)-A(3,2)*b(2)
!
!!     Solve  U*x = y
!         b(3) = b(3)/A(3,3)
!         b(2) = (b(2)-A(2,3)*b(3))/A(2,2)
!         b(1) = (b(1)-A(1,3)*b(3)-A(1,2)*b(2))/A(1,1)
!      
!      
!      CASE ('t','T')  !  Solve transpose(A) * x = b
!
!!      Solve transpose(U)*y = b
!         b(1) = b(1)/A(1,1)
!         b(2) = (b(2)-A(1,2)*b(1))/A(2,2)
!         b(3) = (b(3)-A(1,3)*b(1)-A(2,3)*b(2))/A(3,3)
!
!!      Solve transpose(L)*x = y
!         b(2) = b(2)-A(3,2)*b(3)
!!         L = ipvt(2)
!!         IF (L /= 2) THEN
!!            TMP = B(2); B(2) = B(L); B(L) = TMP
!!         END IF
!         b(1) = b(1)-A(3,1)*b(3)-A(2,1)*b(2)
!!         L = ipvt(1)
!!         IF (L /= 1) THEN
!!            TMP = B(1); B(1) = B(L); B(L) = TMP
!!         END IF
!   
!      END SELECT
!
!END SUBROUTINE SOL3

! End of SPARSE_UTIL function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! KppSolve - sparse back substitution
!   Arguments :
!      JVS       - sparse Jacobian of variables
!      X         - Vector for variables
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

SUBROUTINE KppSolve ( JVS, X )

! JVS - sparse Jacobian of variables
  REAL(kind=dp) :: JVS(LU_NONZERO)
! X - Vector for variables
  REAL(kind=dp) :: X(NVAR)

  X(41) = X(41)-JVS(306)*X(33)
  X(43) = X(43)-JVS(314)*X(38)
  X(46) = X(46)-JVS(329)*X(34)
  X(62) = X(62)-JVS(399)*X(61)
  X(63) = X(63)-JVS(407)*X(53)
  X(77) = X(77)-JVS(476)*X(74)
  X(85) = X(85)-JVS(524)*X(82)
  X(96) = X(96)-JVS(592)*X(84)
  X(98) = X(98)-JVS(605)*X(51)
  X(99) = X(99)-JVS(612)*X(36)
  X(101) = X(101)-JVS(626)*X(99)
  X(108) = X(108)-JVS(708)*X(70)
  X(111) = X(111)-JVS(730)*X(68)
  X(113) = X(113)-JVS(744)*X(57)
  X(115) = X(115)-JVS(763)*X(53)-JVS(764)*X(56)
  X(117) = X(117)-JVS(780)*X(40)-JVS(781)*X(44)-JVS(782)*X(45)-JVS(783)*X(79)-JVS(784)*X(86)-JVS(785)*X(87)-JVS(786)&
             &*X(103)
  X(118) = X(118)-JVS(794)*X(69)
  X(119) = X(119)-JVS(803)*X(33)-JVS(804)*X(35)-JVS(805)*X(38)-JVS(806)*X(58)-JVS(807)*X(74)-JVS(808)*X(75)-JVS(809)&
             &*X(77)-JVS(810)*X(97)-JVS(811)*X(112)-JVS(812)*X(116)-JVS(813)*X(117)
  X(120) = X(120)-JVS(827)*X(103)
  X(121) = X(121)-JVS(837)*X(110)
  X(123) = X(123)-JVS(858)*X(69)-JVS(859)*X(103)-JVS(860)*X(112)-JVS(861)*X(116)-JVS(862)*X(118)
  X(126) = X(126)-JVS(892)*X(88)
  X(127) = X(127)-JVS(899)*X(32)-JVS(900)*X(42)-JVS(901)*X(46)-JVS(902)*X(47)-JVS(903)*X(59)-JVS(904)*X(64)-JVS(905)&
             &*X(70)-JVS(906)*X(83)-JVS(907)*X(96)-JVS(908)*X(97)-JVS(909)*X(103)-JVS(910)*X(104)-JVS(911)*X(108)-JVS(912)&
             &*X(119)-JVS(913)*X(120)-JVS(914)*X(122)-JVS(915)*X(126)
  X(128) = X(128)-JVS(946)*X(103)-JVS(947)*X(126)
  X(129) = X(129)-JVS(957)*X(88)-JVS(958)*X(103)-JVS(959)*X(126)
  X(130) = X(130)-JVS(967)*X(53)-JVS(968)*X(57)
  X(131) = X(131)-JVS(978)*X(90)-JVS(979)*X(124)
  X(132) = X(132)-JVS(989)*X(74)-JVS(990)*X(81)-JVS(991)*X(82)-JVS(992)*X(97)-JVS(993)*X(106)-JVS(994)*X(117)-JVS(995)&
             &*X(120)-JVS(996)*X(126)-JVS(997)*X(129)
  X(133) = X(133)-JVS(1014)*X(73)-JVS(1015)*X(113)-JVS(1016)*X(130)
  X(134) = X(134)-JVS(1028)*X(81)-JVS(1029)*X(110)
  X(136) = X(136)-JVS(1046)*X(88)-JVS(1047)*X(126)-JVS(1048)*X(129)-JVS(1049)*X(135)
  X(137) = X(137)-JVS(1060)*X(92)-JVS(1061)*X(95)
  X(138) = X(138)-JVS(1071)*X(92)-JVS(1072)*X(95)-JVS(1073)*X(137)
  X(139) = X(139)-JVS(1082)*X(60)-JVS(1083)*X(64)-JVS(1084)*X(95)
  X(140) = X(140)-JVS(1099)*X(37)-JVS(1100)*X(67)-JVS(1101)*X(125)
  X(141) = X(141)-JVS(1114)*X(92)-JVS(1115)*X(95)
  X(142) = X(142)-JVS(1125)*X(82)-JVS(1126)*X(86)-JVS(1127)*X(87)
  X(143) = X(143)-JVS(1136)*X(95)
  X(144) = X(144)-JVS(1145)*X(92)
  X(145) = X(145)-JVS(1154)*X(90)-JVS(1155)*X(94)-JVS(1156)*X(124)
  X(147) = X(147)-JVS(1175)*X(95)-JVS(1176)*X(110)-JVS(1177)*X(143)
  X(148) = X(148)-JVS(1187)*X(35)-JVS(1188)*X(38)-JVS(1189)*X(58)-JVS(1190)*X(73)-JVS(1191)*X(74)-JVS(1192)*X(75)&
             &-JVS(1193)*X(76)-JVS(1194)*X(77)-JVS(1195)*X(81)-JVS(1196)*X(82)-JVS(1197)*X(97)-JVS(1198)*X(99)-JVS(1199)&
             &*X(107)-JVS(1200)*X(114)-JVS(1201)*X(117)-JVS(1202)*X(120)-JVS(1203)*X(123)-JVS(1204)*X(124)-JVS(1205)*X(125)&
             &-JVS(1206)*X(126)-JVS(1207)*X(128)-JVS(1208)*X(129)-JVS(1209)*X(133)-JVS(1210)*X(134)-JVS(1211)*X(135)&
             &-JVS(1212)*X(141)-JVS(1213)*X(142)-JVS(1214)*X(144)-JVS(1215)*X(146)-JVS(1216)*X(147)
  X(149) = X(149)-JVS(1239)*X(78)-JVS(1240)*X(121)
  X(150) = X(150)-JVS(1253)*X(1)-JVS(1254)*X(33)-JVS(1255)*X(38)-JVS(1256)*X(52)-JVS(1257)*X(55)-JVS(1258)*X(58)&
             &-JVS(1259)*X(59)-JVS(1260)*X(68)-JVS(1261)*X(73)-JVS(1262)*X(74)-JVS(1263)*X(76)-JVS(1264)*X(78)-JVS(1265)&
             &*X(79)-JVS(1266)*X(81)-JVS(1267)*X(86)-JVS(1268)*X(87)-JVS(1269)*X(90)-JVS(1270)*X(91)-JVS(1271)*X(94)&
             &-JVS(1272)*X(95)-JVS(1273)*X(98)-JVS(1274)*X(99)-JVS(1275)*X(103)-JVS(1276)*X(109)-JVS(1277)*X(110)-JVS(1278)&
             &*X(111)-JVS(1279)*X(112)-JVS(1280)*X(115)-JVS(1281)*X(116)-JVS(1282)*X(117)-JVS(1283)*X(118)-JVS(1284)*X(119)&
             &-JVS(1285)*X(120)-JVS(1286)*X(121)-JVS(1287)*X(123)-JVS(1288)*X(124)-JVS(1289)*X(125)-JVS(1290)*X(126)&
             &-JVS(1291)*X(128)-JVS(1292)*X(129)-JVS(1293)*X(130)-JVS(1294)*X(131)-JVS(1295)*X(132)-JVS(1296)*X(133)&
             &-JVS(1297)*X(134)-JVS(1298)*X(135)-JVS(1299)*X(136)-JVS(1300)*X(137)-JVS(1301)*X(138)-JVS(1302)*X(139)&
             &-JVS(1303)*X(140)-JVS(1304)*X(141)-JVS(1305)*X(142)-JVS(1306)*X(143)-JVS(1307)*X(144)-JVS(1308)*X(145)&
             &-JVS(1309)*X(146)-JVS(1310)*X(147)-JVS(1311)*X(149)
  X(151) = X(151)-JVS(1335)*X(93)-JVS(1336)*X(110)-JVS(1337)*X(112)-JVS(1338)*X(116)-JVS(1339)*X(146)
  X(152) = X(152)-JVS(1348)*X(79)-JVS(1349)*X(86)-JVS(1350)*X(87)-JVS(1351)*X(103)-JVS(1352)*X(135)-JVS(1353)*X(151)
  X(153) = X(153)-JVS(1363)*X(47)-JVS(1364)*X(71)-JVS(1365)*X(72)-JVS(1366)*X(96)-JVS(1367)*X(97)-JVS(1368)*X(136)&
             &-JVS(1369)*X(142)-JVS(1370)*X(143)-JVS(1371)*X(144)-JVS(1372)*X(151)-JVS(1373)*X(152)
  X(154) = X(154)-JVS(1384)*X(79)-JVS(1385)*X(86)-JVS(1386)*X(87)-JVS(1387)*X(110)
  X(155) = X(155)-JVS(1396)*X(93)-JVS(1397)*X(112)-JVS(1398)*X(116)-JVS(1399)*X(124)-JVS(1400)*X(136)-JVS(1401)*X(141)&
             &-JVS(1402)*X(146)-JVS(1403)*X(151)-JVS(1404)*X(153)-JVS(1405)*X(154)
  X(156) = X(156)-JVS(1416)*X(68)-JVS(1417)*X(74)-JVS(1418)*X(78)-JVS(1419)*X(82)-JVS(1420)*X(83)-JVS(1421)*X(85)&
             &-JVS(1422)*X(94)-JVS(1423)*X(97)-JVS(1424)*X(98)-JVS(1425)*X(99)-JVS(1426)*X(104)-JVS(1427)*X(106)-JVS(1428)&
             &*X(111)-JVS(1429)*X(117)-JVS(1430)*X(121)-JVS(1431)*X(122)-JVS(1432)*X(125)-JVS(1433)*X(126)-JVS(1434)*X(128)&
             &-JVS(1435)*X(129)-JVS(1436)*X(131)-JVS(1437)*X(133)-JVS(1438)*X(135)-JVS(1439)*X(137)-JVS(1440)*X(138)&
             &-JVS(1441)*X(141)-JVS(1442)*X(142)-JVS(1443)*X(143)-JVS(1444)*X(144)-JVS(1445)*X(145)-JVS(1446)*X(146)&
             &-JVS(1447)*X(147)-JVS(1448)*X(149)-JVS(1449)*X(151)-JVS(1450)*X(152)-JVS(1451)*X(153)-JVS(1452)*X(154)&
             &-JVS(1453)*X(155)
  X(157) = X(157)-JVS(1469)*X(60)-JVS(1470)*X(65)-JVS(1471)*X(67)-JVS(1472)*X(68)-JVS(1473)*X(105)-JVS(1474)*X(111)&
             &-JVS(1475)*X(118)-JVS(1476)*X(125)-JVS(1477)*X(135)-JVS(1478)*X(136)-JVS(1479)*X(139)-JVS(1480)*X(140)&
             &-JVS(1481)*X(141)-JVS(1482)*X(146)-JVS(1483)*X(147)-JVS(1484)*X(151)-JVS(1485)*X(153)-JVS(1486)*X(154)&
             &-JVS(1487)*X(155)
  X(158) = X(158)-JVS(1504)*X(79)-JVS(1505)*X(86)-JVS(1506)*X(87)-JVS(1507)*X(100)-JVS(1508)*X(110)-JVS(1509)*X(151)&
             &-JVS(1510)*X(154)
  X(159) = X(159)-JVS(1522)*X(71)-JVS(1523)*X(81)-JVS(1524)*X(84)-JVS(1525)*X(85)-JVS(1526)*X(92)-JVS(1527)*X(93)&
             &-JVS(1528)*X(104)-JVS(1529)*X(112)-JVS(1530)*X(116)-JVS(1531)*X(131)-JVS(1532)*X(134)-JVS(1533)*X(137)&
             &-JVS(1534)*X(138)-JVS(1535)*X(141)-JVS(1536)*X(142)-JVS(1537)*X(143)-JVS(1538)*X(144)-JVS(1539)*X(145)&
             &-JVS(1540)*X(146)-JVS(1541)*X(149)-JVS(1542)*X(151)-JVS(1543)*X(152)-JVS(1544)*X(153)-JVS(1545)*X(154)&
             &-JVS(1546)*X(155)-JVS(1547)*X(158)
  X(160) = X(160)-JVS(1560)*X(56)-JVS(1561)*X(69)-JVS(1562)*X(71)-JVS(1563)*X(72)-JVS(1564)*X(88)-JVS(1565)*X(92)&
             &-JVS(1566)*X(93)-JVS(1567)*X(96)-JVS(1568)*X(97)-JVS(1569)*X(102)-JVS(1570)*X(111)-JVS(1571)*X(112)-JVS(1572)&
             &*X(115)-JVS(1573)*X(116)-JVS(1574)*X(118)-JVS(1575)*X(122)-JVS(1576)*X(124)-JVS(1577)*X(126)-JVS(1578)*X(129)&
             &-JVS(1579)*X(130)-JVS(1580)*X(131)-JVS(1581)*X(134)-JVS(1582)*X(135)-JVS(1583)*X(136)-JVS(1584)*X(137)&
             &-JVS(1585)*X(138)-JVS(1586)*X(141)-JVS(1587)*X(142)-JVS(1588)*X(143)-JVS(1589)*X(144)-JVS(1590)*X(145)&
             &-JVS(1591)*X(146)-JVS(1592)*X(147)-JVS(1593)*X(149)-JVS(1594)*X(151)-JVS(1595)*X(152)-JVS(1596)*X(153)&
             &-JVS(1597)*X(154)-JVS(1598)*X(155)-JVS(1599)*X(158)-JVS(1600)*X(159)
  X(161) = X(161)-JVS(1614)*X(29)-JVS(1615)*X(30)-JVS(1616)*X(31)-JVS(1617)*X(39)-JVS(1618)*X(53)-JVS(1619)*X(61)&
             &-JVS(1620)*X(62)-JVS(1621)*X(63)-JVS(1622)*X(64)-JVS(1623)*X(70)-JVS(1624)*X(108)-JVS(1625)*X(113)-JVS(1626)&
             &*X(130)-JVS(1627)*X(144)-JVS(1628)*X(150)-JVS(1629)*X(151)-JVS(1630)*X(152)-JVS(1631)*X(153)-JVS(1632)*X(154)&
             &-JVS(1633)*X(155)-JVS(1634)*X(156)-JVS(1635)*X(157)-JVS(1636)*X(158)-JVS(1637)*X(159)-JVS(1638)*X(160)
  X(162) = X(162)-JVS(1651)*X(42)-JVS(1652)*X(47)-JVS(1653)*X(52)-JVS(1654)*X(54)-JVS(1655)*X(58)-JVS(1656)*X(59)&
             &-JVS(1657)*X(64)-JVS(1658)*X(66)-JVS(1659)*X(70)-JVS(1660)*X(83)-JVS(1661)*X(92)-JVS(1662)*X(94)-JVS(1663)&
             &*X(95)-JVS(1664)*X(98)-JVS(1665)*X(99)-JVS(1666)*X(100)-JVS(1667)*X(104)-JVS(1668)*X(105)-JVS(1669)*X(106)&
             &-JVS(1670)*X(107)-JVS(1671)*X(108)-JVS(1672)*X(109)-JVS(1673)*X(110)-JVS(1674)*X(114)-JVS(1675)*X(116)&
             &-JVS(1676)*X(119)-JVS(1677)*X(120)-JVS(1678)*X(121)-JVS(1679)*X(122)-JVS(1680)*X(125)-JVS(1681)*X(126)&
             &-JVS(1682)*X(127)-JVS(1683)*X(128)-JVS(1684)*X(129)-JVS(1685)*X(131)-JVS(1686)*X(132)-JVS(1687)*X(134)&
             &-JVS(1688)*X(135)-JVS(1689)*X(137)-JVS(1690)*X(138)-JVS(1691)*X(142)-JVS(1692)*X(143)-JVS(1693)*X(144)&
             &-JVS(1694)*X(145)-JVS(1695)*X(146)-JVS(1696)*X(147)-JVS(1697)*X(148)-JVS(1698)*X(149)-JVS(1699)*X(150)&
             &-JVS(1700)*X(151)-JVS(1701)*X(152)-JVS(1702)*X(153)-JVS(1703)*X(154)-JVS(1704)*X(155)-JVS(1705)*X(156)&
             &-JVS(1706)*X(157)-JVS(1707)*X(158)-JVS(1708)*X(159)-JVS(1709)*X(160)-JVS(1710)*X(161)
  X(163) = X(163)-JVS(1722)*X(50)-JVS(1723)*X(52)-JVS(1724)*X(55)-JVS(1725)*X(59)-JVS(1726)*X(66)-JVS(1727)*X(98)&
             &-JVS(1728)*X(101)-JVS(1729)*X(105)-JVS(1730)*X(110)-JVS(1731)*X(111)-JVS(1732)*X(112)-JVS(1733)*X(113)&
             &-JVS(1734)*X(114)-JVS(1735)*X(115)-JVS(1736)*X(116)-JVS(1737)*X(118)-JVS(1738)*X(123)-JVS(1739)*X(124)&
             &-JVS(1740)*X(125)-JVS(1741)*X(126)-JVS(1742)*X(128)-JVS(1743)*X(129)-JVS(1744)*X(130)-JVS(1745)*X(131)&
             &-JVS(1746)*X(133)-JVS(1747)*X(134)-JVS(1748)*X(135)-JVS(1749)*X(136)-JVS(1750)*X(137)-JVS(1751)*X(138)&
             &-JVS(1752)*X(139)-JVS(1753)*X(140)-JVS(1754)*X(141)-JVS(1755)*X(142)-JVS(1756)*X(143)-JVS(1757)*X(144)&
             &-JVS(1758)*X(145)-JVS(1759)*X(146)-JVS(1760)*X(147)-JVS(1761)*X(149)-JVS(1762)*X(151)-JVS(1763)*X(152)&
             &-JVS(1764)*X(153)-JVS(1765)*X(154)-JVS(1766)*X(155)-JVS(1767)*X(156)-JVS(1768)*X(157)-JVS(1769)*X(158)&
             &-JVS(1770)*X(159)-JVS(1771)*X(160)-JVS(1772)*X(161)-JVS(1773)*X(162)
  X(164) = X(164)-JVS(1784)*X(84)-JVS(1785)*X(92)-JVS(1786)*X(94)-JVS(1787)*X(95)-JVS(1788)*X(103)-JVS(1789)*X(108)&
             &-JVS(1790)*X(110)-JVS(1791)*X(122)-JVS(1792)*X(125)-JVS(1793)*X(135)-JVS(1794)*X(137)-JVS(1795)*X(138)&
             &-JVS(1796)*X(140)-JVS(1797)*X(142)-JVS(1798)*X(143)-JVS(1799)*X(144)-JVS(1800)*X(145)-JVS(1801)*X(146)&
             &-JVS(1802)*X(147)-JVS(1803)*X(151)-JVS(1804)*X(152)-JVS(1805)*X(154)-JVS(1806)*X(158)-JVS(1807)*X(159)&
             &-JVS(1808)*X(160)-JVS(1809)*X(161)-JVS(1810)*X(162)-JVS(1811)*X(163)
  X(165) = X(165)-JVS(1821)*X(41)-JVS(1822)*X(43)-JVS(1823)*X(48)-JVS(1824)*X(49)-JVS(1825)*X(58)-JVS(1826)*X(75)&
             &-JVS(1827)*X(77)-JVS(1828)*X(96)-JVS(1829)*X(97)-JVS(1830)*X(99)-JVS(1831)*X(100)-JVS(1832)*X(105)-JVS(1833)&
             &*X(106)-JVS(1834)*X(107)-JVS(1835)*X(108)-JVS(1836)*X(109)-JVS(1837)*X(110)-JVS(1838)*X(111)-JVS(1839)*X(112)&
             &-JVS(1840)*X(114)-JVS(1841)*X(115)-JVS(1842)*X(116)-JVS(1843)*X(117)-JVS(1844)*X(118)-JVS(1845)*X(121)&
             &-JVS(1846)*X(124)-JVS(1847)*X(125)-JVS(1848)*X(126)-JVS(1849)*X(128)-JVS(1850)*X(129)-JVS(1851)*X(130)&
             &-JVS(1852)*X(131)-JVS(1853)*X(133)-JVS(1854)*X(134)-JVS(1855)*X(135)-JVS(1856)*X(136)-JVS(1857)*X(137)&
             &-JVS(1858)*X(138)-JVS(1859)*X(139)-JVS(1860)*X(140)-JVS(1861)*X(141)-JVS(1862)*X(142)-JVS(1863)*X(143)&
             &-JVS(1864)*X(144)-JVS(1865)*X(145)-JVS(1866)*X(146)-JVS(1867)*X(147)-JVS(1868)*X(149)-JVS(1869)*X(151)&
             &-JVS(1870)*X(152)-JVS(1871)*X(153)-JVS(1872)*X(154)-JVS(1873)*X(155)-JVS(1874)*X(158)-JVS(1875)*X(159)&
             &-JVS(1876)*X(160)-JVS(1877)*X(161)-JVS(1878)*X(162)-JVS(1879)*X(163)-JVS(1880)*X(164)
  X(166) = X(166)-JVS(1889)*X(36)-JVS(1890)*X(37)-JVS(1891)*X(39)-JVS(1892)*X(42)-JVS(1893)*X(49)-JVS(1894)*X(51)&
             &-JVS(1895)*X(52)-JVS(1896)*X(54)-JVS(1897)*X(66)-JVS(1898)*X(69)-JVS(1899)*X(70)-JVS(1900)*X(75)-JVS(1901)&
             &*X(77)-JVS(1902)*X(83)-JVS(1903)*X(88)-JVS(1904)*X(91)-JVS(1905)*X(93)-JVS(1906)*X(94)-JVS(1907)*X(96)&
             &-JVS(1908)*X(97)-JVS(1909)*X(98)-JVS(1910)*X(99)-JVS(1911)*X(100)-JVS(1912)*X(103)-JVS(1913)*X(104)-JVS(1914)&
             &*X(105)-JVS(1915)*X(106)-JVS(1916)*X(107)-JVS(1917)*X(108)-JVS(1918)*X(109)-JVS(1919)*X(110)-JVS(1920)*X(111)&
             &-JVS(1921)*X(112)-JVS(1922)*X(114)-JVS(1923)*X(115)-JVS(1924)*X(116)-JVS(1925)*X(117)-JVS(1926)*X(118)&
             &-JVS(1927)*X(120)-JVS(1928)*X(121)-JVS(1929)*X(122)-JVS(1930)*X(123)-JVS(1931)*X(124)-JVS(1932)*X(125)&
             &-JVS(1933)*X(126)-JVS(1934)*X(127)-JVS(1935)*X(128)-JVS(1936)*X(129)-JVS(1937)*X(130)-JVS(1938)*X(131)&
             &-JVS(1939)*X(132)-JVS(1940)*X(133)-JVS(1941)*X(134)-JVS(1942)*X(135)-JVS(1943)*X(136)-JVS(1944)*X(137)&
             &-JVS(1945)*X(138)-JVS(1946)*X(139)-JVS(1947)*X(140)-JVS(1948)*X(141)-JVS(1949)*X(142)-JVS(1950)*X(143)&
             &-JVS(1951)*X(144)-JVS(1952)*X(145)-JVS(1953)*X(146)-JVS(1954)*X(147)-JVS(1955)*X(148)-JVS(1956)*X(149)&
             &-JVS(1957)*X(150)-JVS(1958)*X(151)-JVS(1959)*X(152)-JVS(1960)*X(153)-JVS(1961)*X(154)-JVS(1962)*X(155)&
             &-JVS(1963)*X(156)-JVS(1964)*X(157)-JVS(1965)*X(158)-JVS(1966)*X(159)-JVS(1967)*X(160)-JVS(1968)*X(161)&
             &-JVS(1969)*X(162)-JVS(1970)*X(163)-JVS(1971)*X(164)-JVS(1972)*X(165)
  X(167) = X(167)-JVS(1980)*X(29)-JVS(1981)*X(30)-JVS(1982)*X(31)-JVS(1983)*X(35)-JVS(1984)*X(40)-JVS(1985)*X(44)&
             &-JVS(1986)*X(45)-JVS(1987)*X(47)-JVS(1988)*X(49)-JVS(1989)*X(50)-JVS(1990)*X(53)-JVS(1991)*X(54)-JVS(1992)&
             &*X(55)-JVS(1993)*X(56)-JVS(1994)*X(57)-JVS(1995)*X(59)-JVS(1996)*X(60)-JVS(1997)*X(61)-JVS(1998)*X(62)&
             &-JVS(1999)*X(63)-JVS(2000)*X(64)-JVS(2001)*X(65)-JVS(2002)*X(67)-JVS(2003)*X(68)-JVS(2004)*X(69)-JVS(2005)&
             &*X(70)-JVS(2006)*X(71)-JVS(2007)*X(72)-JVS(2008)*X(73)-JVS(2009)*X(74)-JVS(2010)*X(75)-JVS(2011)*X(76)&
             &-JVS(2012)*X(77)-JVS(2013)*X(78)-JVS(2014)*X(79)-JVS(2015)*X(80)-JVS(2016)*X(81)-JVS(2017)*X(82)-JVS(2018)&
             &*X(83)-JVS(2019)*X(84)-JVS(2020)*X(85)-JVS(2021)*X(86)-JVS(2022)*X(87)-JVS(2023)*X(88)-JVS(2024)*X(89)&
             &-JVS(2025)*X(90)-JVS(2026)*X(91)-JVS(2027)*X(92)-JVS(2028)*X(93)-JVS(2029)*X(94)-JVS(2030)*X(95)-JVS(2031)&
             &*X(96)-JVS(2032)*X(97)-JVS(2033)*X(98)-JVS(2034)*X(99)-JVS(2035)*X(100)-JVS(2036)*X(101)-JVS(2037)*X(102)&
             &-JVS(2038)*X(103)-JVS(2039)*X(104)-JVS(2040)*X(105)-JVS(2041)*X(106)-JVS(2042)*X(107)-JVS(2043)*X(108)&
             &-JVS(2044)*X(109)-JVS(2045)*X(110)-JVS(2046)*X(111)-JVS(2047)*X(112)-JVS(2048)*X(113)-JVS(2049)*X(114)&
             &-JVS(2050)*X(115)-JVS(2051)*X(116)-JVS(2052)*X(117)-JVS(2053)*X(118)-JVS(2054)*X(119)-JVS(2055)*X(120)&
             &-JVS(2056)*X(121)-JVS(2057)*X(122)-JVS(2058)*X(123)-JVS(2059)*X(124)-JVS(2060)*X(125)-JVS(2061)*X(126)&
             &-JVS(2062)*X(127)-JVS(2063)*X(128)-JVS(2064)*X(129)-JVS(2065)*X(130)-JVS(2066)*X(131)-JVS(2067)*X(132)&
             &-JVS(2068)*X(133)-JVS(2069)*X(134)-JVS(2070)*X(135)-JVS(2071)*X(136)-JVS(2072)*X(137)-JVS(2073)*X(138)&
             &-JVS(2074)*X(139)-JVS(2075)*X(140)-JVS(2076)*X(141)-JVS(2077)*X(142)-JVS(2078)*X(143)-JVS(2079)*X(144)&
             &-JVS(2080)*X(145)-JVS(2081)*X(146)-JVS(2082)*X(147)-JVS(2083)*X(148)-JVS(2084)*X(149)-JVS(2085)*X(150)&
             &-JVS(2086)*X(151)-JVS(2087)*X(152)-JVS(2088)*X(153)-JVS(2089)*X(154)-JVS(2090)*X(155)-JVS(2091)*X(156)&
             &-JVS(2092)*X(157)-JVS(2093)*X(158)-JVS(2094)*X(159)-JVS(2095)*X(160)-JVS(2096)*X(161)-JVS(2097)*X(162)&
             &-JVS(2098)*X(163)-JVS(2099)*X(164)-JVS(2100)*X(165)-JVS(2101)*X(166)
  X(168) = X(168)-JVS(2108)*X(74)-JVS(2109)*X(75)-JVS(2110)*X(76)-JVS(2111)*X(78)-JVS(2112)*X(82)-JVS(2113)*X(85)&
             &-JVS(2114)*X(91)-JVS(2115)*X(92)-JVS(2116)*X(94)-JVS(2117)*X(95)-JVS(2118)*X(98)-JVS(2119)*X(100)-JVS(2120)&
             &*X(103)-JVS(2121)*X(105)-JVS(2122)*X(106)-JVS(2123)*X(107)-JVS(2124)*X(110)-JVS(2125)*X(113)-JVS(2126)*X(114)&
             &-JVS(2127)*X(117)-JVS(2128)*X(119)-JVS(2129)*X(121)-JVS(2130)*X(123)-JVS(2131)*X(124)-JVS(2132)*X(125)&
             &-JVS(2133)*X(126)-JVS(2134)*X(128)-JVS(2135)*X(129)-JVS(2136)*X(130)-JVS(2137)*X(132)-JVS(2138)*X(134)&
             &-JVS(2139)*X(135)-JVS(2140)*X(142)-JVS(2141)*X(144)-JVS(2142)*X(145)-JVS(2143)*X(146)-JVS(2144)*X(147)&
             &-JVS(2145)*X(148)-JVS(2146)*X(149)-JVS(2147)*X(150)-JVS(2148)*X(151)-JVS(2149)*X(152)-JVS(2150)*X(153)&
             &-JVS(2151)*X(154)-JVS(2152)*X(155)-JVS(2153)*X(156)-JVS(2154)*X(157)-JVS(2155)*X(158)-JVS(2156)*X(159)&
             &-JVS(2157)*X(160)-JVS(2158)*X(161)-JVS(2159)*X(162)-JVS(2160)*X(163)-JVS(2161)*X(164)-JVS(2162)*X(165)&
             &-JVS(2163)*X(166)-JVS(2164)*X(167)
  X(169) = X(169)-JVS(2170)*X(41)-JVS(2171)*X(43)-JVS(2172)*X(48)-JVS(2173)*X(52)-JVS(2174)*X(54)-JVS(2175)*X(55)&
             &-JVS(2176)*X(56)-JVS(2177)*X(57)-JVS(2178)*X(58)-JVS(2179)*X(60)-JVS(2180)*X(65)-JVS(2181)*X(67)-JVS(2182)&
             &*X(68)-JVS(2183)*X(69)-JVS(2184)*X(71)-JVS(2185)*X(72)-JVS(2186)*X(74)-JVS(2187)*X(75)-JVS(2188)*X(76)&
             &-JVS(2189)*X(77)-JVS(2190)*X(78)-JVS(2191)*X(79)-JVS(2192)*X(80)-JVS(2193)*X(81)-JVS(2194)*X(82)-JVS(2195)&
             &*X(84)-JVS(2196)*X(85)-JVS(2197)*X(86)-JVS(2198)*X(87)-JVS(2199)*X(88)-JVS(2200)*X(89)-JVS(2201)*X(91)&
             &-JVS(2202)*X(92)-JVS(2203)*X(93)-JVS(2204)*X(95)-JVS(2205)*X(96)-JVS(2206)*X(97)-JVS(2207)*X(98)-JVS(2208)&
             &*X(99)-JVS(2209)*X(100)-JVS(2210)*X(102)-JVS(2211)*X(103)-JVS(2212)*X(105)-JVS(2213)*X(106)-JVS(2214)*X(107)&
             &-JVS(2215)*X(108)-JVS(2216)*X(109)-JVS(2217)*X(110)-JVS(2218)*X(111)-JVS(2219)*X(112)-JVS(2220)*X(114)&
             &-JVS(2221)*X(115)-JVS(2222)*X(116)-JVS(2223)*X(117)-JVS(2224)*X(118)-JVS(2225)*X(119)-JVS(2226)*X(120)&
             &-JVS(2227)*X(121)-JVS(2228)*X(124)-JVS(2229)*X(125)-JVS(2230)*X(126)-JVS(2231)*X(128)-JVS(2232)*X(129)&
             &-JVS(2233)*X(130)-JVS(2234)*X(131)-JVS(2235)*X(132)-JVS(2236)*X(133)-JVS(2237)*X(134)-JVS(2238)*X(135)&
             &-JVS(2239)*X(136)-JVS(2240)*X(137)-JVS(2241)*X(138)-JVS(2242)*X(139)-JVS(2243)*X(140)-JVS(2244)*X(141)&
             &-JVS(2245)*X(142)-JVS(2246)*X(143)-JVS(2247)*X(144)-JVS(2248)*X(145)-JVS(2249)*X(146)-JVS(2250)*X(147)&
             &-JVS(2251)*X(148)-JVS(2252)*X(149)-JVS(2253)*X(150)-JVS(2254)*X(151)-JVS(2255)*X(152)-JVS(2256)*X(153)&
             &-JVS(2257)*X(154)-JVS(2258)*X(155)-JVS(2259)*X(156)-JVS(2260)*X(157)-JVS(2261)*X(158)-JVS(2262)*X(159)&
             &-JVS(2263)*X(160)-JVS(2264)*X(161)-JVS(2265)*X(162)-JVS(2266)*X(163)-JVS(2267)*X(164)-JVS(2268)*X(165)&
             &-JVS(2269)*X(166)-JVS(2270)*X(167)-JVS(2271)*X(168)
  X(170) = X(170)-JVS(2276)*X(79)-JVS(2277)*X(86)-JVS(2278)*X(87)-JVS(2279)*X(95)-JVS(2280)*X(110)-JVS(2281)*X(121)&
             &-JVS(2282)*X(143)-JVS(2283)*X(151)-JVS(2284)*X(154)-JVS(2285)*X(162)-JVS(2286)*X(163)-JVS(2287)*X(164)&
             &-JVS(2288)*X(165)-JVS(2289)*X(166)-JVS(2290)*X(167)-JVS(2291)*X(168)-JVS(2292)*X(169)
  X(171) = X(171)-JVS(2296)*X(50)-JVS(2297)*X(66)-JVS(2298)*X(73)-JVS(2299)*X(74)-JVS(2300)*X(76)-JVS(2301)*X(81)&
             &-JVS(2302)*X(90)-JVS(2303)*X(94)-JVS(2304)*X(98)-JVS(2305)*X(110)-JVS(2306)*X(111)-JVS(2307)*X(113)-JVS(2308)&
             &*X(114)-JVS(2309)*X(115)-JVS(2310)*X(117)-JVS(2311)*X(118)-JVS(2312)*X(120)-JVS(2313)*X(124)-JVS(2314)*X(125)&
             &-JVS(2315)*X(126)-JVS(2316)*X(129)-JVS(2317)*X(130)-JVS(2318)*X(131)-JVS(2319)*X(133)-JVS(2320)*X(134)&
             &-JVS(2321)*X(135)-JVS(2322)*X(136)-JVS(2323)*X(137)-JVS(2324)*X(138)-JVS(2325)*X(139)-JVS(2326)*X(140)&
             &-JVS(2327)*X(141)-JVS(2328)*X(142)-JVS(2329)*X(143)-JVS(2330)*X(144)-JVS(2331)*X(145)-JVS(2332)*X(146)&
             &-JVS(2333)*X(147)-JVS(2334)*X(148)-JVS(2335)*X(149)-JVS(2336)*X(151)-JVS(2337)*X(152)-JVS(2338)*X(153)&
             &-JVS(2339)*X(154)-JVS(2340)*X(155)-JVS(2341)*X(156)-JVS(2342)*X(157)-JVS(2343)*X(158)-JVS(2344)*X(159)&
             &-JVS(2345)*X(160)-JVS(2346)*X(161)-JVS(2347)*X(162)-JVS(2348)*X(163)-JVS(2349)*X(164)-JVS(2350)*X(165)&
             &-JVS(2351)*X(166)-JVS(2352)*X(167)-JVS(2353)*X(168)-JVS(2354)*X(169)-JVS(2355)*X(170)
  X(172) = X(172)-JVS(2358)*X(59)-JVS(2359)*X(100)-JVS(2360)*X(105)-JVS(2361)*X(106)-JVS(2362)*X(107)-JVS(2363)*X(109)&
             &-JVS(2364)*X(110)-JVS(2365)*X(114)-JVS(2366)*X(121)-JVS(2367)*X(147)-JVS(2368)*X(152)-JVS(2369)*X(154)&
             &-JVS(2370)*X(158)-JVS(2371)*X(162)-JVS(2372)*X(163)-JVS(2373)*X(164)-JVS(2374)*X(165)-JVS(2375)*X(166)&
             &-JVS(2376)*X(167)-JVS(2377)*X(168)-JVS(2378)*X(169)-JVS(2379)*X(170)-JVS(2380)*X(171)
  X(172) = X(172)/JVS(2381)
  X(171) = (X(171)-JVS(2357)*X(172))/(JVS(2356))
  X(170) = (X(170)-JVS(2294)*X(171)-JVS(2295)*X(172))/(JVS(2293))
  X(169) = (X(169)-JVS(2273)*X(170)-JVS(2274)*X(171)-JVS(2275)*X(172))/(JVS(2272))
  X(168) = (X(168)-JVS(2166)*X(169)-JVS(2167)*X(170)-JVS(2168)*X(171)-JVS(2169)*X(172))/(JVS(2165))
  X(167) = (X(167)-JVS(2103)*X(168)-JVS(2104)*X(169)-JVS(2105)*X(170)-JVS(2106)*X(171)-JVS(2107)*X(172))/(JVS(2102))
  X(166) = (X(166)-JVS(1974)*X(167)-JVS(1975)*X(168)-JVS(1976)*X(169)-JVS(1977)*X(170)-JVS(1978)*X(171)-JVS(1979)&
             &*X(172))/(JVS(1973))
  X(165) = (X(165)-JVS(1882)*X(166)-JVS(1883)*X(167)-JVS(1884)*X(168)-JVS(1885)*X(169)-JVS(1886)*X(170)-JVS(1887)*X(171)&
             &-JVS(1888)*X(172))/(JVS(1881))
  X(164) = (X(164)-JVS(1813)*X(165)-JVS(1814)*X(166)-JVS(1815)*X(167)-JVS(1816)*X(168)-JVS(1817)*X(169)-JVS(1818)*X(170)&
             &-JVS(1819)*X(171)-JVS(1820)*X(172))/(JVS(1812))
  X(163) = (X(163)-JVS(1775)*X(164)-JVS(1776)*X(165)-JVS(1777)*X(166)-JVS(1778)*X(167)-JVS(1779)*X(168)-JVS(1780)*X(169)&
             &-JVS(1781)*X(170)-JVS(1782)*X(171)-JVS(1783)*X(172))/(JVS(1774))
  X(162) = (X(162)-JVS(1712)*X(163)-JVS(1713)*X(164)-JVS(1714)*X(165)-JVS(1715)*X(166)-JVS(1716)*X(167)-JVS(1717)*X(168)&
             &-JVS(1718)*X(169)-JVS(1719)*X(170)-JVS(1720)*X(171)-JVS(1721)*X(172))/(JVS(1711))
  X(161) = (X(161)-JVS(1640)*X(162)-JVS(1641)*X(163)-JVS(1642)*X(164)-JVS(1643)*X(165)-JVS(1644)*X(166)-JVS(1645)*X(167)&
             &-JVS(1646)*X(168)-JVS(1647)*X(169)-JVS(1648)*X(170)-JVS(1649)*X(171)-JVS(1650)*X(172))/(JVS(1639))
  X(160) = (X(160)-JVS(1602)*X(161)-JVS(1603)*X(162)-JVS(1604)*X(163)-JVS(1605)*X(164)-JVS(1606)*X(165)-JVS(1607)*X(166)&
             &-JVS(1608)*X(167)-JVS(1609)*X(168)-JVS(1610)*X(169)-JVS(1611)*X(170)-JVS(1612)*X(171)-JVS(1613)*X(172))&
             &/(JVS(1601))
  X(159) = (X(159)-JVS(1549)*X(162)-JVS(1550)*X(163)-JVS(1551)*X(164)-JVS(1552)*X(165)-JVS(1553)*X(166)-JVS(1554)*X(167)&
             &-JVS(1555)*X(168)-JVS(1556)*X(169)-JVS(1557)*X(170)-JVS(1558)*X(171)-JVS(1559)*X(172))/(JVS(1548))
  X(158) = (X(158)-JVS(1512)*X(162)-JVS(1513)*X(163)-JVS(1514)*X(164)-JVS(1515)*X(165)-JVS(1516)*X(166)-JVS(1517)*X(167)&
             &-JVS(1518)*X(168)-JVS(1519)*X(169)-JVS(1520)*X(171)-JVS(1521)*X(172))/(JVS(1511))
  X(157) = (X(157)-JVS(1489)*X(158)-JVS(1490)*X(159)-JVS(1491)*X(160)-JVS(1492)*X(161)-JVS(1493)*X(162)-JVS(1494)*X(163)&
             &-JVS(1495)*X(164)-JVS(1496)*X(165)-JVS(1497)*X(166)-JVS(1498)*X(167)-JVS(1499)*X(168)-JVS(1500)*X(169)&
             &-JVS(1501)*X(170)-JVS(1502)*X(171)-JVS(1503)*X(172))/(JVS(1488))
  X(156) = (X(156)-JVS(1455)*X(158)-JVS(1456)*X(159)-JVS(1457)*X(161)-JVS(1458)*X(162)-JVS(1459)*X(163)-JVS(1460)*X(164)&
             &-JVS(1461)*X(165)-JVS(1462)*X(166)-JVS(1463)*X(167)-JVS(1464)*X(168)-JVS(1465)*X(169)-JVS(1466)*X(170)&
             &-JVS(1467)*X(171)-JVS(1468)*X(172))/(JVS(1454))
  X(155) = (X(155)-JVS(1407)*X(159)-JVS(1408)*X(162)-JVS(1409)*X(163)-JVS(1410)*X(164)-JVS(1411)*X(165)-JVS(1412)*X(167)&
             &-JVS(1413)*X(169)-JVS(1414)*X(170)-JVS(1415)*X(171))/(JVS(1406))
  X(154) = (X(154)-JVS(1389)*X(162)-JVS(1390)*X(163)-JVS(1391)*X(164)-JVS(1392)*X(165)-JVS(1393)*X(167)-JVS(1394)*X(169)&
             &-JVS(1395)*X(171))/(JVS(1388))
  X(153) = (X(153)-JVS(1375)*X(154)-JVS(1376)*X(155)-JVS(1377)*X(162)-JVS(1378)*X(163)-JVS(1379)*X(164)-JVS(1380)*X(165)&
             &-JVS(1381)*X(167)-JVS(1382)*X(169)-JVS(1383)*X(171))/(JVS(1374))
  X(152) = (X(152)-JVS(1355)*X(154)-JVS(1356)*X(162)-JVS(1357)*X(163)-JVS(1358)*X(164)-JVS(1359)*X(165)-JVS(1360)*X(167)&
             &-JVS(1361)*X(169)-JVS(1362)*X(171))/(JVS(1354))
  X(151) = (X(151)-JVS(1341)*X(162)-JVS(1342)*X(163)-JVS(1343)*X(164)-JVS(1344)*X(165)-JVS(1345)*X(167)-JVS(1346)*X(169)&
             &-JVS(1347)*X(171))/(JVS(1340))
  X(150) = (X(150)-JVS(1313)*X(151)-JVS(1314)*X(152)-JVS(1315)*X(153)-JVS(1316)*X(154)-JVS(1317)*X(155)-JVS(1318)*X(156)&
             &-JVS(1319)*X(157)-JVS(1320)*X(158)-JVS(1321)*X(159)-JVS(1322)*X(160)-JVS(1323)*X(161)-JVS(1324)*X(162)&
             &-JVS(1325)*X(163)-JVS(1326)*X(164)-JVS(1327)*X(165)-JVS(1328)*X(166)-JVS(1329)*X(167)-JVS(1330)*X(168)&
             &-JVS(1331)*X(169)-JVS(1332)*X(170)-JVS(1333)*X(171)-JVS(1334)*X(172))/(JVS(1312))
  X(149) = (X(149)-JVS(1242)*X(162)-JVS(1243)*X(163)-JVS(1244)*X(164)-JVS(1245)*X(165)-JVS(1246)*X(166)-JVS(1247)*X(167)&
             &-JVS(1248)*X(168)-JVS(1249)*X(169)-JVS(1250)*X(170)-JVS(1251)*X(171)-JVS(1252)*X(172))/(JVS(1241))
  X(148) = (X(148)-JVS(1218)*X(149)-JVS(1219)*X(151)-JVS(1220)*X(152)-JVS(1221)*X(153)-JVS(1222)*X(154)-JVS(1223)*X(155)&
             &-JVS(1224)*X(156)-JVS(1225)*X(158)-JVS(1226)*X(159)-JVS(1227)*X(161)-JVS(1228)*X(162)-JVS(1229)*X(163)&
             &-JVS(1230)*X(164)-JVS(1231)*X(165)-JVS(1232)*X(166)-JVS(1233)*X(167)-JVS(1234)*X(168)-JVS(1235)*X(169)&
             &-JVS(1236)*X(170)-JVS(1237)*X(171)-JVS(1238)*X(172))/(JVS(1217))
  X(147) = (X(147)-JVS(1179)*X(158)-JVS(1180)*X(162)-JVS(1181)*X(163)-JVS(1182)*X(164)-JVS(1183)*X(165)-JVS(1184)*X(167)&
             &-JVS(1185)*X(169)-JVS(1186)*X(171))/(JVS(1178))
  X(146) = (X(146)-JVS(1168)*X(151)-JVS(1169)*X(162)-JVS(1170)*X(163)-JVS(1171)*X(164)-JVS(1172)*X(165)-JVS(1173)*X(167)&
             &-JVS(1174)*X(171))/(JVS(1167))
  X(145) = (X(145)-JVS(1158)*X(162)-JVS(1159)*X(163)-JVS(1160)*X(164)-JVS(1161)*X(165)-JVS(1162)*X(166)-JVS(1163)*X(167)&
             &-JVS(1164)*X(169)-JVS(1165)*X(170)-JVS(1166)*X(171))/(JVS(1157))
  X(144) = (X(144)-JVS(1147)*X(162)-JVS(1148)*X(163)-JVS(1149)*X(164)-JVS(1150)*X(165)-JVS(1151)*X(167)-JVS(1152)*X(169)&
             &-JVS(1153)*X(171))/(JVS(1146))
  X(143) = (X(143)-JVS(1138)*X(162)-JVS(1139)*X(163)-JVS(1140)*X(164)-JVS(1141)*X(165)-JVS(1142)*X(167)-JVS(1143)*X(169)&
             &-JVS(1144)*X(171))/(JVS(1137))
  X(142) = (X(142)-JVS(1129)*X(152)-JVS(1130)*X(154)-JVS(1131)*X(163)-JVS(1132)*X(165)-JVS(1133)*X(167)-JVS(1134)*X(169)&
             &-JVS(1135)*X(171))/(JVS(1128))
  X(141) = (X(141)-JVS(1117)*X(159)-JVS(1118)*X(162)-JVS(1119)*X(163)-JVS(1120)*X(164)-JVS(1121)*X(165)-JVS(1122)*X(167)&
             &-JVS(1123)*X(169)-JVS(1124)*X(171))/(JVS(1116))
  X(140) = (X(140)-JVS(1103)*X(146)-JVS(1104)*X(158)-JVS(1105)*X(159)-JVS(1106)*X(160)-JVS(1107)*X(162)-JVS(1108)*X(163)&
             &-JVS(1109)*X(165)-JVS(1110)*X(166)-JVS(1111)*X(167)-JVS(1112)*X(169)-JVS(1113)*X(171))/(JVS(1102))
  X(139) = (X(139)-JVS(1086)*X(140)-JVS(1087)*X(153)-JVS(1088)*X(155)-JVS(1089)*X(159)-JVS(1090)*X(160)-JVS(1091)*X(161)&
             &-JVS(1092)*X(162)-JVS(1093)*X(163)-JVS(1094)*X(164)-JVS(1095)*X(165)-JVS(1096)*X(167)-JVS(1097)*X(169)&
             &-JVS(1098)*X(171))/(JVS(1085))
  X(138) = (X(138)-JVS(1075)*X(162)-JVS(1076)*X(163)-JVS(1077)*X(164)-JVS(1078)*X(165)-JVS(1079)*X(167)-JVS(1080)*X(169)&
             &-JVS(1081)*X(171))/(JVS(1074))
  X(137) = (X(137)-JVS(1063)*X(138)-JVS(1064)*X(162)-JVS(1065)*X(163)-JVS(1066)*X(164)-JVS(1067)*X(165)-JVS(1068)*X(167)&
             &-JVS(1069)*X(169)-JVS(1070)*X(171))/(JVS(1062))
  X(136) = (X(136)-JVS(1051)*X(151)-JVS(1052)*X(154)-JVS(1053)*X(155)-JVS(1054)*X(163)-JVS(1055)*X(164)-JVS(1056)*X(165)&
             &-JVS(1057)*X(167)-JVS(1058)*X(169)-JVS(1059)*X(171))/(JVS(1050))
  X(135) = (X(135)-JVS(1040)*X(151)-JVS(1041)*X(154)-JVS(1042)*X(163)-JVS(1043)*X(164)-JVS(1044)*X(165)-JVS(1045)&
             &*X(167))/(JVS(1039))
  X(134) = (X(134)-JVS(1031)*X(158)-JVS(1032)*X(162)-JVS(1033)*X(163)-JVS(1034)*X(164)-JVS(1035)*X(165)-JVS(1036)*X(167)&
             &-JVS(1037)*X(169)-JVS(1038)*X(171))/(JVS(1030))
  X(133) = (X(133)-JVS(1018)*X(141)-JVS(1019)*X(144)-JVS(1020)*X(153)-JVS(1021)*X(155)-JVS(1022)*X(161)-JVS(1023)*X(163)&
             &-JVS(1024)*X(165)-JVS(1025)*X(167)-JVS(1026)*X(169)-JVS(1027)*X(171))/(JVS(1017))
  X(132) = (X(132)-JVS(999)*X(134)-JVS(1000)*X(135)-JVS(1001)*X(142)-JVS(1002)*X(146)-JVS(1003)*X(152)-JVS(1004)*X(154)&
             &-JVS(1005)*X(163)-JVS(1006)*X(164)-JVS(1007)*X(165)-JVS(1008)*X(166)-JVS(1009)*X(167)-JVS(1010)*X(168)&
             &-JVS(1011)*X(169)-JVS(1012)*X(171)-JVS(1013)*X(172))/(JVS(998))
  X(131) = (X(131)-JVS(981)*X(145)-JVS(982)*X(162)-JVS(983)*X(163)-JVS(984)*X(165)-JVS(985)*X(167)-JVS(986)*X(169)&
             &-JVS(987)*X(170)-JVS(988)*X(171))/(JVS(980))
  X(130) = (X(130)-JVS(970)*X(153)-JVS(971)*X(155)-JVS(972)*X(161)-JVS(973)*X(163)-JVS(974)*X(165)-JVS(975)*X(167)&
             &-JVS(976)*X(169)-JVS(977)*X(171))/(JVS(969))
  X(129) = (X(129)-JVS(961)*X(135)-JVS(962)*X(154)-JVS(963)*X(164)-JVS(964)*X(165)-JVS(965)*X(167)-JVS(966)*X(169))&
             &/(JVS(960))
  X(128) = (X(128)-JVS(949)*X(129)-JVS(950)*X(135)-JVS(951)*X(149)-JVS(952)*X(154)-JVS(953)*X(164)-JVS(954)*X(165)&
             &-JVS(955)*X(167)-JVS(956)*X(169))/(JVS(948))
  X(127) = (X(127)-JVS(917)*X(128)-JVS(918)*X(129)-JVS(919)*X(131)-JVS(920)*X(132)-JVS(921)*X(134)-JVS(922)*X(135)&
             &-JVS(923)*X(137)-JVS(924)*X(138)-JVS(925)*X(142)-JVS(926)*X(143)-JVS(927)*X(144)-JVS(928)*X(146)-JVS(929)&
             &*X(148)-JVS(930)*X(150)-JVS(931)*X(154)-JVS(932)*X(155)-JVS(933)*X(157)-JVS(934)*X(159)-JVS(935)*X(160)&
             &-JVS(936)*X(161)-JVS(937)*X(162)-JVS(938)*X(163)-JVS(939)*X(164)-JVS(940)*X(165)-JVS(941)*X(166)-JVS(942)&
             &*X(167)-JVS(943)*X(169)-JVS(944)*X(170)-JVS(945)*X(171))/(JVS(916))
  X(126) = (X(126)-JVS(894)*X(129)-JVS(895)*X(135)-JVS(896)*X(165)-JVS(897)*X(167)-JVS(898)*X(169))/(JVS(893))
  X(125) = (X(125)-JVS(886)*X(146)-JVS(887)*X(162)-JVS(888)*X(165)-JVS(889)*X(166)-JVS(890)*X(167)-JVS(891)*X(169))&
             &/(JVS(885))
  X(124) = (X(124)-JVS(879)*X(162)-JVS(880)*X(163)-JVS(881)*X(165)-JVS(882)*X(169)-JVS(883)*X(170)-JVS(884)*X(171))&
             &/(JVS(878))
  X(123) = (X(123)-JVS(864)*X(124)-JVS(865)*X(125)-JVS(866)*X(126)-JVS(867)*X(135)-JVS(868)*X(146)-JVS(869)*X(147)&
             &-JVS(870)*X(154)-JVS(871)*X(162)-JVS(872)*X(163)-JVS(873)*X(164)-JVS(874)*X(165)-JVS(875)*X(167)-JVS(876)&
             &*X(169)-JVS(877)*X(171))/(JVS(863))
  X(122) = (X(122)-JVS(847)*X(137)-JVS(848)*X(138)-JVS(849)*X(143)-JVS(850)*X(144)-JVS(851)*X(162)-JVS(852)*X(163)&
             &-JVS(853)*X(164)-JVS(854)*X(165)-JVS(855)*X(167)-JVS(856)*X(169)-JVS(857)*X(171))/(JVS(846))
  X(121) = (X(121)-JVS(839)*X(162)-JVS(840)*X(164)-JVS(841)*X(165)-JVS(842)*X(166)-JVS(843)*X(167)-JVS(844)*X(168)&
             &-JVS(845)*X(172))/(JVS(838))
  X(120) = (X(120)-JVS(829)*X(126)-JVS(830)*X(129)-JVS(831)*X(134)-JVS(832)*X(154)-JVS(833)*X(164)-JVS(834)*X(165)&
             &-JVS(835)*X(167)-JVS(836)*X(169))/(JVS(828))
  X(119) = (X(119)-JVS(815)*X(132)-JVS(816)*X(135)-JVS(817)*X(142)-JVS(818)*X(146)-JVS(819)*X(154)-JVS(820)*X(162)&
             &-JVS(821)*X(163)-JVS(822)*X(164)-JVS(823)*X(165)-JVS(824)*X(167)-JVS(825)*X(169)-JVS(826)*X(171))/(JVS(814))
  X(118) = (X(118)-JVS(796)*X(147)-JVS(797)*X(162)-JVS(798)*X(163)-JVS(799)*X(165)-JVS(800)*X(167)-JVS(801)*X(169)&
             &-JVS(802)*X(171))/(JVS(795))
  X(117) = (X(117)-JVS(788)*X(135)-JVS(789)*X(154)-JVS(790)*X(164)-JVS(791)*X(165)-JVS(792)*X(167)-JVS(793)*X(169))&
             &/(JVS(787))
  X(116) = (X(116)-JVS(775)*X(146)-JVS(776)*X(162)-JVS(777)*X(163)-JVS(778)*X(165)-JVS(779)*X(169))/(JVS(774))
  X(115) = (X(115)-JVS(766)*X(153)-JVS(767)*X(155)-JVS(768)*X(161)-JVS(769)*X(163)-JVS(770)*X(165)-JVS(771)*X(167)&
             &-JVS(772)*X(169)-JVS(773)*X(171))/(JVS(765))
  X(114) = (X(114)-JVS(757)*X(158)-JVS(758)*X(164)-JVS(759)*X(165)-JVS(760)*X(166)-JVS(761)*X(168)-JVS(762)*X(172))&
             &/(JVS(756))
  X(113) = (X(113)-JVS(746)*X(130)-JVS(747)*X(144)-JVS(748)*X(153)-JVS(749)*X(155)-JVS(750)*X(161)-JVS(751)*X(163)&
             &-JVS(752)*X(165)-JVS(753)*X(167)-JVS(754)*X(169)-JVS(755)*X(171))/(JVS(745))
  X(112) = (X(112)-JVS(739)*X(146)-JVS(740)*X(163)-JVS(741)*X(165)-JVS(742)*X(167)-JVS(743)*X(169))/(JVS(738))
  X(111) = (X(111)-JVS(732)*X(147)-JVS(733)*X(163)-JVS(734)*X(165)-JVS(735)*X(167)-JVS(736)*X(169)-JVS(737)*X(171))&
             &/(JVS(731))
  X(110) = (X(110)-JVS(727)*X(162)-JVS(728)*X(164)-JVS(729)*X(167))/(JVS(726))
  X(109) = (X(109)-JVS(718)*X(110)-JVS(719)*X(147)-JVS(720)*X(158)-JVS(721)*X(164)-JVS(722)*X(165)-JVS(723)*X(166)&
             &-JVS(724)*X(170)-JVS(725)*X(172))/(JVS(717))
  X(108) = (X(108)-JVS(710)*X(161)-JVS(711)*X(162)-JVS(712)*X(164)-JVS(713)*X(165)-JVS(714)*X(166)-JVS(715)*X(167)&
             &-JVS(716)*X(169))/(JVS(709))
  X(107) = (X(107)-JVS(701)*X(152)-JVS(702)*X(164)-JVS(703)*X(165)-JVS(704)*X(166)-JVS(705)*X(168)-JVS(706)*X(170)&
             &-JVS(707)*X(172))/(JVS(700))
  X(106) = (X(106)-JVS(694)*X(152)-JVS(695)*X(164)-JVS(696)*X(165)-JVS(697)*X(166)-JVS(698)*X(168)-JVS(699)*X(172))&
             &/(JVS(693))
  X(105) = (X(105)-JVS(687)*X(147)-JVS(688)*X(164)-JVS(689)*X(165)-JVS(690)*X(166)-JVS(691)*X(168)-JVS(692)*X(172))&
             &/(JVS(686))
  X(104) = (X(104)-JVS(677)*X(137)-JVS(678)*X(138)-JVS(679)*X(144)-JVS(680)*X(162)-JVS(681)*X(163)-JVS(682)*X(165)&
             &-JVS(683)*X(167)-JVS(684)*X(169)-JVS(685)*X(171))/(JVS(676))
  X(103) = (X(103)-JVS(672)*X(154)-JVS(673)*X(164)-JVS(674)*X(165)-JVS(675)*X(167))/(JVS(671))
  X(102) = (X(102)-JVS(654)*X(111)-JVS(655)*X(115)-JVS(656)*X(118)-JVS(657)*X(130)-JVS(658)*X(131)-JVS(659)*X(134)&
             &-JVS(660)*X(136)-JVS(661)*X(138)-JVS(662)*X(141)-JVS(663)*X(142)-JVS(664)*X(143)-JVS(665)*X(144)-JVS(666)&
             &*X(149)-JVS(667)*X(153)-JVS(668)*X(154)-JVS(669)*X(163)-JVS(670)*X(167))/(JVS(653))
  X(101) = (X(101)-JVS(628)*X(105)-JVS(629)*X(111)-JVS(630)*X(115)-JVS(631)*X(118)-JVS(632)*X(124)-JVS(633)*X(128)&
             &-JVS(634)*X(130)-JVS(635)*X(131)-JVS(636)*X(133)-JVS(637)*X(134)-JVS(638)*X(136)-JVS(639)*X(139)-JVS(640)&
             &*X(141)-JVS(641)*X(142)-JVS(642)*X(149)-JVS(643)*X(151)-JVS(644)*X(153)-JVS(645)*X(154)-JVS(646)*X(156)&
             &-JVS(647)*X(163)-JVS(648)*X(165)-JVS(649)*X(166)-JVS(650)*X(167)-JVS(651)*X(169)-JVS(652)*X(171))/(JVS(627))
  X(100) = (X(100)-JVS(620)*X(110)-JVS(621)*X(164)-JVS(622)*X(165)-JVS(623)*X(166)-JVS(624)*X(168)-JVS(625)*X(172))&
             &/(JVS(619))
  X(99) = (X(99)-JVS(614)*X(128)-JVS(615)*X(165)-JVS(616)*X(166)-JVS(617)*X(167)-JVS(618)*X(169))/(JVS(613))
  X(98) = (X(98)-JVS(607)*X(125)-JVS(608)*X(162)-JVS(609)*X(166)-JVS(610)*X(167)-JVS(611)*X(170))/(JVS(606))
  X(97) = (X(97)-JVS(601)*X(154)-JVS(602)*X(165)-JVS(603)*X(169)-JVS(604)*X(171))/(JVS(600))
  X(96) = (X(96)-JVS(594)*X(142)-JVS(595)*X(164)-JVS(596)*X(165)-JVS(597)*X(167)-JVS(598)*X(169)-JVS(599)*X(171))&
            &/(JVS(593))
  X(95) = (X(95)-JVS(589)*X(162)-JVS(590)*X(164)-JVS(591)*X(167))/(JVS(588))
  X(94) = (X(94)-JVS(584)*X(145)-JVS(585)*X(164)-JVS(586)*X(166)-JVS(587)*X(167))/(JVS(583))
  X(93) = (X(93)-JVS(578)*X(112)-JVS(579)*X(116)-JVS(580)*X(151)-JVS(581)*X(167)-JVS(582)*X(169))/(JVS(577))
  X(92) = (X(92)-JVS(574)*X(162)-JVS(575)*X(164)-JVS(576)*X(167))/(JVS(573))
  X(91) = (X(91)-JVS(567)*X(126)-JVS(568)*X(135)-JVS(569)*X(164)-JVS(570)*X(165)-JVS(571)*X(167)-JVS(572)*X(169))&
            &/(JVS(566))
  X(90) = (X(90)-JVS(560)*X(124)-JVS(561)*X(145)-JVS(562)*X(162)-JVS(563)*X(167)-JVS(564)*X(169)-JVS(565)*X(170))&
            &/(JVS(559))
  X(89) = (X(89)-JVS(545)*X(95)-JVS(546)*X(99)-JVS(547)*X(103)-JVS(548)*X(109)-JVS(549)*X(117)-JVS(550)*X(120)-JVS(551)&
            &*X(126)-JVS(552)*X(132)-JVS(553)*X(144)-JVS(554)*X(156)-JVS(555)*X(164)-JVS(556)*X(165)-JVS(557)*X(167)&
            &-JVS(558)*X(169))/(JVS(544))
  X(88) = (X(88)-JVS(540)*X(126)-JVS(541)*X(129)-JVS(542)*X(167)-JVS(543)*X(169))/(JVS(539))
  X(87) = (X(87)-JVS(536)*X(154)-JVS(537)*X(167)-JVS(538)*X(169))/(JVS(535))
  X(86) = (X(86)-JVS(532)*X(154)-JVS(533)*X(167)-JVS(534)*X(169))/(JVS(531))
  X(85) = (X(85)-JVS(526)*X(142)-JVS(527)*X(165)-JVS(528)*X(167)-JVS(529)*X(169)-JVS(530)*X(171))/(JVS(525))
  X(84) = (X(84)-JVS(519)*X(142)-JVS(520)*X(164)-JVS(521)*X(165)-JVS(522)*X(167)-JVS(523)*X(171))/(JVS(518))
  X(83) = (X(83)-JVS(513)*X(104)-JVS(514)*X(122)-JVS(515)*X(162)-JVS(516)*X(164)-JVS(517)*X(167))/(JVS(512))
  X(82) = (X(82)-JVS(509)*X(142)-JVS(510)*X(167)-JVS(511)*X(169))/(JVS(508))
  X(81) = (X(81)-JVS(505)*X(134)-JVS(506)*X(167)-JVS(507)*X(169))/(JVS(504))
  X(80) = (X(80)-JVS(492)*X(92)-JVS(493)*X(95)-JVS(494)*X(100)-JVS(495)*X(105)-JVS(496)*X(106)-JVS(497)*X(107)-JVS(498)&
            &*X(109)-JVS(499)*X(114)-JVS(500)*X(121)-JVS(501)*X(164)-JVS(502)*X(167)-JVS(503)*X(169))/(JVS(491))
  X(79) = (X(79)-JVS(488)*X(154)-JVS(489)*X(167)-JVS(490)*X(169))/(JVS(487))
  X(78) = (X(78)-JVS(483)*X(121)-JVS(484)*X(149)-JVS(485)*X(167)-JVS(486)*X(169))/(JVS(482))
  X(77) = (X(77)-JVS(478)*X(154)-JVS(479)*X(165)-JVS(480)*X(167)-JVS(481)*X(169))/(JVS(477))
  X(76) = (X(76)-JVS(472)*X(117)-JVS(473)*X(165)-JVS(474)*X(167)-JVS(475)*X(169))/(JVS(471))
  X(75) = (X(75)-JVS(468)*X(154)-JVS(469)*X(165)-JVS(470)*X(169))/(JVS(467))
  X(74) = (X(74)-JVS(465)*X(154)-JVS(466)*X(167))/(JVS(464))
  X(73) = (X(73)-JVS(460)*X(133)-JVS(461)*X(141)-JVS(462)*X(167)-JVS(463)*X(169))/(JVS(459))
  X(72) = (X(72)-JVS(454)*X(96)-JVS(455)*X(97)-JVS(456)*X(153)-JVS(457)*X(167)-JVS(458)*X(169))/(JVS(453))
  X(71) = (X(71)-JVS(449)*X(143)-JVS(450)*X(144)-JVS(451)*X(167)-JVS(452)*X(169))/(JVS(448))
  X(70) = (X(70)-JVS(445)*X(108)-JVS(446)*X(161)-JVS(447)*X(166))/(JVS(444))
  X(69) = (X(69)-JVS(441)*X(118)-JVS(442)*X(167)-JVS(443)*X(169))/(JVS(440))
  X(68) = (X(68)-JVS(437)*X(111)-JVS(438)*X(167)-JVS(439)*X(169))/(JVS(436))
  X(67) = (X(67)-JVS(432)*X(125)-JVS(433)*X(140)-JVS(434)*X(167)-JVS(435)*X(169))/(JVS(431))
  X(66) = (X(66)-JVS(427)*X(98)-JVS(428)*X(166)-JVS(429)*X(167)-JVS(430)*X(171))/(JVS(426))
  X(65) = (X(65)-JVS(421)*X(135)-JVS(422)*X(139)-JVS(423)*X(163)-JVS(424)*X(164)-JVS(425)*X(167))/(JVS(420))
  X(64) = (X(64)-JVS(417)*X(161)-JVS(418)*X(162)-JVS(419)*X(167))/(JVS(416))
  X(63) = (X(63)-JVS(409)*X(64)-JVS(410)*X(113)-JVS(411)*X(150)-JVS(412)*X(157)-JVS(413)*X(161)-JVS(414)*X(167)-JVS(415)&
            &*X(169))/(JVS(408))
  X(62) = (X(62)-JVS(401)*X(63)-JVS(402)*X(70)-JVS(403)*X(108)-JVS(404)*X(161)-JVS(405)*X(167)-JVS(406)*X(169))&
            &/(JVS(400))
  X(61) = (X(61)-JVS(394)*X(62)-JVS(395)*X(70)-JVS(396)*X(108)-JVS(397)*X(167)-JVS(398)*X(169))/(JVS(393))
  X(60) = (X(60)-JVS(390)*X(139)-JVS(391)*X(167)-JVS(392)*X(169))/(JVS(389))
  X(59) = (X(59)-JVS(387)*X(162)-JVS(388)*X(167))/(JVS(386))
  X(58) = (X(58)-JVS(384)*X(162)-JVS(385)*X(167))/(JVS(383))
  X(57) = (X(57)-JVS(380)*X(130)-JVS(381)*X(167)-JVS(382)*X(169))/(JVS(379))
  X(56) = (X(56)-JVS(376)*X(115)-JVS(377)*X(167)-JVS(378)*X(169))/(JVS(375))
  X(55) = (X(55)-JVS(372)*X(163)-JVS(373)*X(167)-JVS(374)*X(169))/(JVS(371))
  X(54) = (X(54)-JVS(368)*X(166)-JVS(369)*X(167)-JVS(370)*X(169))/(JVS(367))
  X(53) = (X(53)-JVS(365)*X(161)-JVS(366)*X(167))/(JVS(364))
  X(52) = (X(52)-JVS(362)*X(163)-JVS(363)*X(166))/(JVS(361))
  X(51) = (X(51)-JVS(356)*X(98)-JVS(357)*X(162)-JVS(358)*X(166)-JVS(359)*X(167)-JVS(360)*X(170))/(JVS(355))
  X(50) = (X(50)-JVS(352)*X(167)-JVS(353)*X(169)-JVS(354)*X(171))/(JVS(351))
  X(49) = (X(49)-JVS(348)*X(165)-JVS(349)*X(166)-JVS(350)*X(167))/(JVS(347))
  X(48) = (X(48)-JVS(343)*X(58)-JVS(344)*X(165)-JVS(345)*X(167)-JVS(346)*X(169))/(JVS(342))
  X(47) = (X(47)-JVS(340)*X(162)-JVS(341)*X(167))/(JVS(339))
  X(46) = (X(46)-JVS(331)*X(103)-JVS(332)*X(120)-JVS(333)*X(126)-JVS(334)*X(128)-JVS(335)*X(129)-JVS(336)*X(135)&
            &-JVS(337)*X(155)-JVS(338)*X(165))/(JVS(330))
  X(45) = (X(45)-JVS(325)*X(79)-JVS(326)*X(86)-JVS(327)*X(103)-JVS(328)*X(167))/(JVS(324))
  X(44) = (X(44)-JVS(320)*X(79)-JVS(321)*X(86)-JVS(322)*X(103)-JVS(323)*X(167))/(JVS(319))
  X(43) = (X(43)-JVS(316)*X(165)-JVS(317)*X(167)-JVS(318)*X(169))/(JVS(315))
  X(42) = (X(42)-JVS(312)*X(162)-JVS(313)*X(166))/(JVS(311))
  X(41) = (X(41)-JVS(308)*X(165)-JVS(309)*X(167)-JVS(310)*X(169))/(JVS(307))
  X(40) = (X(40)-JVS(303)*X(87)-JVS(304)*X(135)-JVS(305)*X(167))/(JVS(302))
  X(39) = (X(39)-JVS(300)*X(161)-JVS(301)*X(166))/(JVS(299))
  X(38) = (X(38)-JVS(298)*X(167))/(JVS(297))
  X(37) = (X(37)-JVS(295)*X(140)-JVS(296)*X(166))/(JVS(294))
  X(36) = (X(36)-JVS(292)*X(99)-JVS(293)*X(166))/(JVS(291))
  X(35) = (X(35)-JVS(290)*X(75))/(JVS(289))
  X(34) = (X(34)-JVS(286)*X(126)-JVS(287)*X(129)-JVS(288)*X(165))/(JVS(285))
  X(33) = (X(33)-JVS(284)*X(167))/(JVS(283))
  X(32) = (X(32)-JVS(280)*X(83)-JVS(281)*X(104)-JVS(282)*X(122))/(JVS(279))
  X(31) = (X(31)-JVS(278)*X(167))/(JVS(277))
  X(30) = (X(30)-JVS(276)*X(167))/(JVS(275))
  X(29) = (X(29)-JVS(274)*X(167))/(JVS(273))
  X(28) = (X(28)-JVS(264)*X(100)-JVS(265)*X(105)-JVS(266)*X(106)-JVS(267)*X(107)-JVS(268)*X(109)-JVS(269)*X(114)&
            &-JVS(270)*X(121)-JVS(271)*X(167)-JVS(272)*X(172))/(JVS(263))
  X(27) = (X(27)-JVS(255)*X(100)-JVS(256)*X(105)-JVS(257)*X(106)-JVS(258)*X(107)-JVS(259)*X(114)-JVS(260)*X(121)&
            &-JVS(261)*X(167)-JVS(262)*X(168))/(JVS(254))
  X(26) = (X(26)-JVS(212)*X(74)-JVS(213)*X(75)-JVS(214)*X(76)-JVS(215)*X(78)-JVS(216)*X(82)-JVS(217)*X(85)-JVS(218)&
            &*X(91)-JVS(219)*X(92)-JVS(220)*X(94)-JVS(221)*X(95)-JVS(222)*X(98)-JVS(223)*X(103)-JVS(224)*X(110)-JVS(225)&
            &*X(113)-JVS(226)*X(117)-JVS(227)*X(119)-JVS(228)*X(123)-JVS(229)*X(124)-JVS(230)*X(125)-JVS(231)*X(128)&
            &-JVS(232)*X(132)-JVS(233)*X(142)-JVS(234)*X(145)-JVS(235)*X(147)-JVS(236)*X(148)-JVS(237)*X(149)-JVS(238)&
            &*X(150)-JVS(239)*X(152)-JVS(240)*X(154)-JVS(241)*X(156)-JVS(242)*X(157)-JVS(243)*X(158)-JVS(244)*X(160)&
            &-JVS(245)*X(161)-JVS(246)*X(162)-JVS(247)*X(163)-JVS(248)*X(164)-JVS(249)*X(165)-JVS(250)*X(167)-JVS(251)&
            &*X(169)-JVS(252)*X(170)-JVS(253)*X(171))/(JVS(211))
  X(25) = (X(25)-JVS(165)*X(42)-JVS(166)*X(47)-JVS(167)*X(51)-JVS(168)*X(58)-JVS(169)*X(59)-JVS(170)*X(61)-JVS(171)&
            &*X(64)-JVS(172)*X(84)-JVS(173)*X(88)-JVS(174)*X(92)-JVS(175)*X(95)-JVS(176)*X(99)-JVS(177)*X(103)-JVS(178)&
            &*X(104)-JVS(179)*X(108)-JVS(180)*X(110)-JVS(181)*X(112)-JVS(182)*X(116)-JVS(183)*X(119)-JVS(184)*X(120)&
            &-JVS(185)*X(122)-JVS(186)*X(125)-JVS(187)*X(128)-JVS(188)*X(135)-JVS(189)*X(137)-JVS(190)*X(143)-JVS(191)&
            &*X(144)-JVS(192)*X(146)-JVS(193)*X(147)-JVS(194)*X(148)-JVS(195)*X(150)-JVS(196)*X(151)-JVS(197)*X(152)&
            &-JVS(198)*X(155)-JVS(199)*X(157)-JVS(200)*X(158)-JVS(201)*X(159)-JVS(202)*X(160)-JVS(203)*X(162)-JVS(204)&
            &*X(163)-JVS(205)*X(164)-JVS(206)*X(165)-JVS(207)*X(166)-JVS(208)*X(167)-JVS(209)*X(169)-JVS(210)*X(170))&
            &/(JVS(164))
  X(24) = (X(24)-JVS(105)*X(32)-JVS(106)*X(36)-JVS(107)*X(46)-JVS(108)*X(49)-JVS(109)*X(52)-JVS(110)*X(54)-JVS(111)&
            &*X(62)-JVS(112)*X(66)-JVS(113)*X(75)-JVS(114)*X(77)-JVS(115)*X(83)-JVS(116)*X(96)-JVS(117)*X(97)-JVS(118)*X(98)&
            &-JVS(119)*X(99)-JVS(120)*X(100)-JVS(121)*X(104)-JVS(122)*X(105)-JVS(123)*X(106)-JVS(124)*X(107)-JVS(125)*X(109)&
            &-JVS(126)*X(111)-JVS(127)*X(114)-JVS(128)*X(115)-JVS(129)*X(116)-JVS(130)*X(117)-JVS(131)*X(118)-JVS(132)&
            &*X(120)-JVS(133)*X(121)-JVS(134)*X(122)-JVS(135)*X(124)-JVS(136)*X(125)-JVS(137)*X(126)-JVS(138)*X(127)&
            &-JVS(139)*X(129)-JVS(140)*X(130)-JVS(141)*X(131)-JVS(142)*X(133)-JVS(143)*X(134)-JVS(144)*X(136)-JVS(145)&
            &*X(137)-JVS(146)*X(138)-JVS(147)*X(139)-JVS(148)*X(140)-JVS(149)*X(141)-JVS(150)*X(142)-JVS(151)*X(143)&
            &-JVS(152)*X(144)-JVS(153)*X(145)-JVS(154)*X(149)-JVS(155)*X(151)-JVS(156)*X(153)-JVS(157)*X(154)-JVS(158)&
            &*X(163)-JVS(159)*X(165)-JVS(160)*X(166)-JVS(161)*X(167)-JVS(162)*X(169)-JVS(163)*X(171))/(JVS(104))
  X(23) = (X(23)-JVS(103)*X(148))/(JVS(102))
  X(22) = (X(22)-JVS(100)*X(98)-JVS(101)*X(167))/(JVS(99))
  X(21) = (X(21)-JVS(98)*X(22))/(JVS(97))
  X(20) = (X(20)-JVS(94)*X(40)-JVS(95)*X(44)-JVS(96)*X(45))/(JVS(93))
  X(19) = (X(19)-JVS(92)*X(119))/(JVS(91))
  X(18) = (X(18)-JVS(82)*X(100)-JVS(83)*X(105)-JVS(84)*X(106)-JVS(85)*X(107)-JVS(86)*X(109)-JVS(87)*X(114)-JVS(88)&
            &*X(121)-JVS(89)*X(167)-JVS(90)*X(172))/(JVS(81))
  X(17) = (X(17)-JVS(79)*X(120)-JVS(80)*X(167))/(JVS(78))
  X(16) = (X(16)-JVS(76)*X(59)-JVS(77)*X(167))/(JVS(75))
  X(15) = (X(15)-JVS(73)*X(48)-JVS(74)*X(165))/(JVS(72))
  X(14) = (X(14)-JVS(70)*X(48)-JVS(71)*X(169))/(JVS(69))
  X(13) = (X(13)-JVS(65)*X(79)-JVS(66)*X(86)-JVS(67)*X(87)-JVS(68)*X(167))/(JVS(64))
  X(12) = (X(12)-JVS(63)*X(13))/(JVS(62))
  X(11) = (X(11)-JVS(60)*X(43)-JVS(61)*X(165))/(JVS(59))
  X(10) = (X(10)-JVS(57)*X(43)-JVS(58)*X(169))/(JVS(56))
  X(9) = (X(9)-JVS(54)*X(110)-JVS(55)*X(162))/(JVS(53))
  X(8) = (X(8)-JVS(51)*X(110)-JVS(52)*X(167))/(JVS(50))
  X(7) = (X(7)-JVS(48)*X(41)-JVS(49)*X(165))/(JVS(47))
  X(6) = (X(6)-JVS(45)*X(41)-JVS(46)*X(169))/(JVS(44))
  X(5) = (X(5)-JVS(36)*X(112)-JVS(37)*X(116)-JVS(38)*X(125)-JVS(39)*X(162)-JVS(40)*X(163)-JVS(41)*X(165)-JVS(42)*X(166)&
           &-JVS(43)*X(169))/(JVS(35))
  X(4) = (X(4)-JVS(34)*X(5))/(JVS(33))
  X(3) = (X(3)-JVS(31)*X(32)-JVS(32)*X(46))/(JVS(30))
  X(2) = (X(2)-JVS(3)*X(58)-JVS(4)*X(74)-JVS(5)*X(78)-JVS(6)*X(84)-JVS(7)*X(89)-JVS(8)*X(91)-JVS(9)*X(96)-JVS(10)*X(98)&
           &-JVS(11)*X(99)-JVS(12)*X(101)-JVS(13)*X(103)-JVS(14)*X(117)-JVS(15)*X(124)-JVS(16)*X(131)-JVS(17)*X(132)-JVS(18)&
           &*X(135)-JVS(19)*X(145)-JVS(20)*X(154)-JVS(21)*X(156)-JVS(22)*X(162)-JVS(23)*X(163)-JVS(24)*X(164)-JVS(25)*X(165)&
           &-JVS(26)*X(167)-JVS(27)*X(168)-JVS(28)*X(169)-JVS(29)*X(171))/(JVS(2))
  X(1) = X(1)/JVS(1)
      
END SUBROUTINE KppSolve

! End of KppSolve function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! KppSolveTR - sparse, transposed back substitution
!   Arguments :
!      JVS       - sparse Jacobian of variables
!      X         - Vector for variables
!      XX        - Vector for output variables
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

SUBROUTINE KppSolveTR ( JVS, X, XX )

! JVS - sparse Jacobian of variables
  REAL(kind=dp) :: JVS(LU_NONZERO)
! X - Vector for variables
  REAL(kind=dp) :: X(NVAR)
! XX - Vector for output variables
  REAL(kind=dp) :: XX(NVAR)

  XX(1) = X(1)/JVS(1)
  XX(2) = X(2)/JVS(2)
  XX(3) = X(3)/JVS(30)
  XX(4) = X(4)/JVS(33)
  XX(5) = (X(5)-JVS(34)*XX(4))/(JVS(35))
  XX(6) = X(6)/JVS(44)
  XX(7) = X(7)/JVS(47)
  XX(8) = X(8)/JVS(50)
  XX(9) = X(9)/JVS(53)
  XX(10) = X(10)/JVS(56)
  XX(11) = X(11)/JVS(59)
  XX(12) = X(12)/JVS(62)
  XX(13) = (X(13)-JVS(63)*XX(12))/(JVS(64))
  XX(14) = X(14)/JVS(69)
  XX(15) = X(15)/JVS(72)
  XX(16) = X(16)/JVS(75)
  XX(17) = X(17)/JVS(78)
  XX(18) = X(18)/JVS(81)
  XX(19) = X(19)/JVS(91)
  XX(20) = X(20)/JVS(93)
  XX(21) = X(21)/JVS(97)
  XX(22) = (X(22)-JVS(98)*XX(21))/(JVS(99))
  XX(23) = X(23)/JVS(102)
  XX(24) = X(24)/JVS(104)
  XX(25) = X(25)/JVS(164)
  XX(26) = X(26)/JVS(211)
  XX(27) = X(27)/JVS(254)
  XX(28) = X(28)/JVS(263)
  XX(29) = X(29)/JVS(273)
  XX(30) = X(30)/JVS(275)
  XX(31) = X(31)/JVS(277)
  XX(32) = (X(32)-JVS(31)*XX(3)-JVS(105)*XX(24))/(JVS(279))
  XX(33) = X(33)/JVS(283)
  XX(34) = X(34)/JVS(285)
  XX(35) = X(35)/JVS(289)
  XX(36) = (X(36)-JVS(106)*XX(24))/(JVS(291))
  XX(37) = X(37)/JVS(294)
  XX(38) = X(38)/JVS(297)
  XX(39) = X(39)/JVS(299)
  XX(40) = (X(40)-JVS(94)*XX(20))/(JVS(302))
  XX(41) = (X(41)-JVS(45)*XX(6)-JVS(48)*XX(7))/(JVS(307))
  XX(42) = (X(42)-JVS(165)*XX(25))/(JVS(311))
  XX(43) = (X(43)-JVS(57)*XX(10)-JVS(60)*XX(11))/(JVS(315))
  XX(44) = (X(44)-JVS(95)*XX(20))/(JVS(319))
  XX(45) = (X(45)-JVS(96)*XX(20))/(JVS(324))
  XX(46) = (X(46)-JVS(32)*XX(3)-JVS(107)*XX(24))/(JVS(330))
  XX(47) = (X(47)-JVS(166)*XX(25))/(JVS(339))
  XX(48) = (X(48)-JVS(70)*XX(14)-JVS(73)*XX(15))/(JVS(342))
  XX(49) = (X(49)-JVS(108)*XX(24))/(JVS(347))
  XX(50) = X(50)/JVS(351)
  XX(51) = (X(51)-JVS(167)*XX(25))/(JVS(355))
  XX(52) = (X(52)-JVS(109)*XX(24))/(JVS(361))
  XX(53) = X(53)/JVS(364)
  XX(54) = (X(54)-JVS(110)*XX(24))/(JVS(367))
  XX(55) = X(55)/JVS(371)
  XX(56) = X(56)/JVS(375)
  XX(57) = X(57)/JVS(379)
  XX(58) = (X(58)-JVS(3)*XX(2)-JVS(168)*XX(25)-JVS(343)*XX(48))/(JVS(383))
  XX(59) = (X(59)-JVS(76)*XX(16)-JVS(169)*XX(25))/(JVS(386))
  XX(60) = X(60)/JVS(389)
  XX(61) = (X(61)-JVS(170)*XX(25))/(JVS(393))
  XX(62) = (X(62)-JVS(111)*XX(24)-JVS(394)*XX(61))/(JVS(400))
  XX(63) = (X(63)-JVS(401)*XX(62))/(JVS(408))
  XX(64) = (X(64)-JVS(171)*XX(25)-JVS(409)*XX(63))/(JVS(416))
  XX(65) = X(65)/JVS(420)
  XX(66) = (X(66)-JVS(112)*XX(24))/(JVS(426))
  XX(67) = X(67)/JVS(431)
  XX(68) = X(68)/JVS(436)
  XX(69) = X(69)/JVS(440)
  XX(70) = (X(70)-JVS(395)*XX(61)-JVS(402)*XX(62))/(JVS(444))
  XX(71) = X(71)/JVS(448)
  XX(72) = X(72)/JVS(453)
  XX(73) = X(73)/JVS(459)
  XX(74) = (X(74)-JVS(4)*XX(2)-JVS(212)*XX(26))/(JVS(464))
  XX(75) = (X(75)-JVS(113)*XX(24)-JVS(213)*XX(26)-JVS(290)*XX(35))/(JVS(467))
  XX(76) = (X(76)-JVS(214)*XX(26))/(JVS(471))
  XX(77) = (X(77)-JVS(114)*XX(24))/(JVS(477))
  XX(78) = (X(78)-JVS(5)*XX(2)-JVS(215)*XX(26))/(JVS(482))
  XX(79) = (X(79)-JVS(65)*XX(13)-JVS(320)*XX(44)-JVS(325)*XX(45))/(JVS(487))
  XX(80) = X(80)/JVS(491)
  XX(81) = X(81)/JVS(504)
  XX(82) = (X(82)-JVS(216)*XX(26))/(JVS(508))
  XX(83) = (X(83)-JVS(115)*XX(24)-JVS(280)*XX(32))/(JVS(512))
  XX(84) = (X(84)-JVS(6)*XX(2)-JVS(172)*XX(25))/(JVS(518))
  XX(85) = (X(85)-JVS(217)*XX(26))/(JVS(525))
  XX(86) = (X(86)-JVS(66)*XX(13)-JVS(321)*XX(44)-JVS(326)*XX(45))/(JVS(531))
  XX(87) = (X(87)-JVS(67)*XX(13)-JVS(303)*XX(40))/(JVS(535))
  XX(88) = (X(88)-JVS(173)*XX(25))/(JVS(539))
  XX(89) = (X(89)-JVS(7)*XX(2))/(JVS(544))
  XX(90) = X(90)/JVS(559)
  XX(91) = (X(91)-JVS(8)*XX(2)-JVS(218)*XX(26))/(JVS(566))
  XX(92) = (X(92)-JVS(174)*XX(25)-JVS(219)*XX(26)-JVS(492)*XX(80))/(JVS(573))
  XX(93) = X(93)/JVS(577)
  XX(94) = (X(94)-JVS(220)*XX(26))/(JVS(583))
  XX(95) = (X(95)-JVS(175)*XX(25)-JVS(221)*XX(26)-JVS(493)*XX(80)-JVS(545)*XX(89))/(JVS(588))
  XX(96) = (X(96)-JVS(9)*XX(2)-JVS(116)*XX(24)-JVS(454)*XX(72))/(JVS(593))
  XX(97) = (X(97)-JVS(117)*XX(24)-JVS(455)*XX(72))/(JVS(600))
  XX(98) = (X(98)-JVS(10)*XX(2)-JVS(100)*XX(22)-JVS(118)*XX(24)-JVS(222)*XX(26)-JVS(356)*XX(51)-JVS(427)*XX(66))&
             &/(JVS(606))
  XX(99) = (X(99)-JVS(11)*XX(2)-JVS(119)*XX(24)-JVS(176)*XX(25)-JVS(292)*XX(36)-JVS(546)*XX(89))/(JVS(613))
  XX(100) = (X(100)-JVS(82)*XX(18)-JVS(120)*XX(24)-JVS(255)*XX(27)-JVS(264)*XX(28)-JVS(494)*XX(80))/(JVS(619))
  XX(101) = (X(101)-JVS(12)*XX(2))/(JVS(627))
  XX(102) = X(102)/JVS(653)
  XX(103) = (X(103)-JVS(13)*XX(2)-JVS(177)*XX(25)-JVS(223)*XX(26)-JVS(322)*XX(44)-JVS(327)*XX(45)-JVS(331)*XX(46)&
              &-JVS(547)*XX(89))/(JVS(671))
  XX(104) = (X(104)-JVS(121)*XX(24)-JVS(178)*XX(25)-JVS(281)*XX(32)-JVS(513)*XX(83))/(JVS(676))
  XX(105) = (X(105)-JVS(83)*XX(18)-JVS(122)*XX(24)-JVS(256)*XX(27)-JVS(265)*XX(28)-JVS(495)*XX(80)-JVS(628)*XX(101))&
              &/(JVS(686))
  XX(106) = (X(106)-JVS(84)*XX(18)-JVS(123)*XX(24)-JVS(257)*XX(27)-JVS(266)*XX(28)-JVS(496)*XX(80))/(JVS(693))
  XX(107) = (X(107)-JVS(85)*XX(18)-JVS(124)*XX(24)-JVS(258)*XX(27)-JVS(267)*XX(28)-JVS(497)*XX(80))/(JVS(700))
  XX(108) = (X(108)-JVS(179)*XX(25)-JVS(396)*XX(61)-JVS(403)*XX(62)-JVS(445)*XX(70))/(JVS(709))
  XX(109) = (X(109)-JVS(86)*XX(18)-JVS(125)*XX(24)-JVS(268)*XX(28)-JVS(498)*XX(80)-JVS(548)*XX(89))/(JVS(717))
  XX(110) = (X(110)-JVS(51)*XX(8)-JVS(54)*XX(9)-JVS(180)*XX(25)-JVS(224)*XX(26)-JVS(620)*XX(100)-JVS(718)*XX(109))&
              &/(JVS(726))
  XX(111) = (X(111)-JVS(126)*XX(24)-JVS(437)*XX(68)-JVS(629)*XX(101)-JVS(654)*XX(102))/(JVS(731))
  XX(112) = (X(112)-JVS(36)*XX(5)-JVS(181)*XX(25)-JVS(578)*XX(93))/(JVS(738))
  XX(113) = (X(113)-JVS(225)*XX(26)-JVS(410)*XX(63))/(JVS(745))
  XX(114) = (X(114)-JVS(87)*XX(18)-JVS(127)*XX(24)-JVS(259)*XX(27)-JVS(269)*XX(28)-JVS(499)*XX(80))/(JVS(756))
  XX(115) = (X(115)-JVS(128)*XX(24)-JVS(376)*XX(56)-JVS(630)*XX(101)-JVS(655)*XX(102))/(JVS(765))
  XX(116) = (X(116)-JVS(37)*XX(5)-JVS(129)*XX(24)-JVS(182)*XX(25)-JVS(579)*XX(93))/(JVS(774))
  XX(117) = (X(117)-JVS(14)*XX(2)-JVS(130)*XX(24)-JVS(226)*XX(26)-JVS(472)*XX(76)-JVS(549)*XX(89))/(JVS(787))
  XX(118) = (X(118)-JVS(131)*XX(24)-JVS(441)*XX(69)-JVS(631)*XX(101)-JVS(656)*XX(102))/(JVS(795))
  XX(119) = (X(119)-JVS(92)*XX(19)-JVS(183)*XX(25)-JVS(227)*XX(26))/(JVS(814))
  XX(120) = (X(120)-JVS(79)*XX(17)-JVS(132)*XX(24)-JVS(184)*XX(25)-JVS(332)*XX(46)-JVS(550)*XX(89))/(JVS(828))
  XX(121) = (X(121)-JVS(88)*XX(18)-JVS(133)*XX(24)-JVS(260)*XX(27)-JVS(270)*XX(28)-JVS(483)*XX(78)-JVS(500)*XX(80))&
              &/(JVS(838))
  XX(122) = (X(122)-JVS(134)*XX(24)-JVS(185)*XX(25)-JVS(282)*XX(32)-JVS(514)*XX(83))/(JVS(846))
  XX(123) = (X(123)-JVS(228)*XX(26))/(JVS(863))
  XX(124) = (X(124)-JVS(15)*XX(2)-JVS(135)*XX(24)-JVS(229)*XX(26)-JVS(560)*XX(90)-JVS(632)*XX(101)-JVS(864)*XX(123))&
              &/(JVS(878))
  XX(125) = (X(125)-JVS(38)*XX(5)-JVS(136)*XX(24)-JVS(186)*XX(25)-JVS(230)*XX(26)-JVS(432)*XX(67)-JVS(607)*XX(98)&
              &-JVS(865)*XX(123))/(JVS(885))
  XX(126) = (X(126)-JVS(137)*XX(24)-JVS(286)*XX(34)-JVS(333)*XX(46)-JVS(540)*XX(88)-JVS(551)*XX(89)-JVS(567)*XX(91)&
              &-JVS(829)*XX(120)-JVS(866)*XX(123))/(JVS(893))
  XX(127) = (X(127)-JVS(138)*XX(24))/(JVS(916))
  XX(128) = (X(128)-JVS(187)*XX(25)-JVS(231)*XX(26)-JVS(334)*XX(46)-JVS(614)*XX(99)-JVS(633)*XX(101)-JVS(917)*XX(127))&
              &/(JVS(948))
  XX(129) = (X(129)-JVS(139)*XX(24)-JVS(287)*XX(34)-JVS(335)*XX(46)-JVS(541)*XX(88)-JVS(830)*XX(120)-JVS(894)*XX(126)&
              &-JVS(918)*XX(127)-JVS(949)*XX(128))/(JVS(960))
  XX(130) = (X(130)-JVS(140)*XX(24)-JVS(380)*XX(57)-JVS(634)*XX(101)-JVS(657)*XX(102)-JVS(746)*XX(113))/(JVS(969))
  XX(131) = (X(131)-JVS(16)*XX(2)-JVS(141)*XX(24)-JVS(635)*XX(101)-JVS(658)*XX(102)-JVS(919)*XX(127))/(JVS(980))
  XX(132) = (X(132)-JVS(17)*XX(2)-JVS(232)*XX(26)-JVS(552)*XX(89)-JVS(815)*XX(119)-JVS(920)*XX(127))/(JVS(998))
  XX(133) = (X(133)-JVS(142)*XX(24)-JVS(460)*XX(73)-JVS(636)*XX(101))/(JVS(1017))
  XX(134) = (X(134)-JVS(143)*XX(24)-JVS(505)*XX(81)-JVS(637)*XX(101)-JVS(659)*XX(102)-JVS(831)*XX(120)-JVS(921)*XX(127)&
              &-JVS(999)*XX(132))/(JVS(1030))
  XX(135) = (X(135)-JVS(18)*XX(2)-JVS(188)*XX(25)-JVS(304)*XX(40)-JVS(336)*XX(46)-JVS(421)*XX(65)-JVS(568)*XX(91)&
              &-JVS(788)*XX(117)-JVS(816)*XX(119)-JVS(867)*XX(123)-JVS(895)*XX(126)-JVS(922)*XX(127)-JVS(950)*XX(128)&
              &-JVS(961)*XX(129)-JVS(1000)*XX(132))/(JVS(1039))
  XX(136) = (X(136)-JVS(144)*XX(24)-JVS(638)*XX(101)-JVS(660)*XX(102))/(JVS(1050))
  XX(137) = (X(137)-JVS(145)*XX(24)-JVS(189)*XX(25)-JVS(677)*XX(104)-JVS(847)*XX(122)-JVS(923)*XX(127))/(JVS(1062))
  XX(138) = (X(138)-JVS(146)*XX(24)-JVS(661)*XX(102)-JVS(678)*XX(104)-JVS(848)*XX(122)-JVS(924)*XX(127)-JVS(1063)&
              &*XX(137))/(JVS(1074))
  XX(139) = (X(139)-JVS(147)*XX(24)-JVS(390)*XX(60)-JVS(422)*XX(65)-JVS(639)*XX(101))/(JVS(1085))
  XX(140) = (X(140)-JVS(148)*XX(24)-JVS(295)*XX(37)-JVS(433)*XX(67)-JVS(1086)*XX(139))/(JVS(1102))
  XX(141) = (X(141)-JVS(149)*XX(24)-JVS(461)*XX(73)-JVS(640)*XX(101)-JVS(662)*XX(102)-JVS(1018)*XX(133))/(JVS(1116))
  XX(142) = (X(142)-JVS(150)*XX(24)-JVS(233)*XX(26)-JVS(509)*XX(82)-JVS(519)*XX(84)-JVS(526)*XX(85)-JVS(594)*XX(96)&
              &-JVS(641)*XX(101)-JVS(663)*XX(102)-JVS(817)*XX(119)-JVS(925)*XX(127)-JVS(1001)*XX(132))/(JVS(1128))
  XX(143) = (X(143)-JVS(151)*XX(24)-JVS(190)*XX(25)-JVS(449)*XX(71)-JVS(664)*XX(102)-JVS(849)*XX(122)-JVS(926)*XX(127))&
              &/(JVS(1137))
  XX(144) = (X(144)-JVS(152)*XX(24)-JVS(191)*XX(25)-JVS(450)*XX(71)-JVS(553)*XX(89)-JVS(665)*XX(102)-JVS(679)*XX(104)&
              &-JVS(747)*XX(113)-JVS(850)*XX(122)-JVS(927)*XX(127)-JVS(1019)*XX(133))/(JVS(1146))
  XX(145) = (X(145)-JVS(19)*XX(2)-JVS(153)*XX(24)-JVS(234)*XX(26)-JVS(561)*XX(90)-JVS(584)*XX(94)-JVS(981)*XX(131))&
              &/(JVS(1157))
  XX(146) = (X(146)-JVS(192)*XX(25)-JVS(739)*XX(112)-JVS(775)*XX(116)-JVS(818)*XX(119)-JVS(868)*XX(123)-JVS(886)*XX(125)&
              &-JVS(928)*XX(127)-JVS(1002)*XX(132)-JVS(1103)*XX(140))/(JVS(1167))
  XX(147) = (X(147)-JVS(193)*XX(25)-JVS(235)*XX(26)-JVS(687)*XX(105)-JVS(719)*XX(109)-JVS(732)*XX(111)-JVS(796)*XX(118)&
              &-JVS(869)*XX(123))/(JVS(1178))
  XX(148) = (X(148)-JVS(103)*XX(23)-JVS(194)*XX(25)-JVS(236)*XX(26)-JVS(929)*XX(127))/(JVS(1217))
  XX(149) = (X(149)-JVS(154)*XX(24)-JVS(237)*XX(26)-JVS(484)*XX(78)-JVS(642)*XX(101)-JVS(666)*XX(102)-JVS(951)*XX(128)&
              &-JVS(1218)*XX(148))/(JVS(1241))
  XX(150) = (X(150)-JVS(195)*XX(25)-JVS(238)*XX(26)-JVS(411)*XX(63)-JVS(930)*XX(127))/(JVS(1312))
  XX(151) = (X(151)-JVS(155)*XX(24)-JVS(196)*XX(25)-JVS(580)*XX(93)-JVS(643)*XX(101)-JVS(1040)*XX(135)-JVS(1051)*XX(136)&
              &-JVS(1168)*XX(146)-JVS(1219)*XX(148)-JVS(1313)*XX(150))/(JVS(1340))
  XX(152) = (X(152)-JVS(197)*XX(25)-JVS(239)*XX(26)-JVS(694)*XX(106)-JVS(701)*XX(107)-JVS(1003)*XX(132)-JVS(1129)&
              &*XX(142)-JVS(1220)*XX(148)-JVS(1314)*XX(150))/(JVS(1354))
  XX(153) = (X(153)-JVS(156)*XX(24)-JVS(456)*XX(72)-JVS(644)*XX(101)-JVS(667)*XX(102)-JVS(748)*XX(113)-JVS(766)*XX(115)&
              &-JVS(970)*XX(130)-JVS(1020)*XX(133)-JVS(1087)*XX(139)-JVS(1221)*XX(148)-JVS(1315)*XX(150))/(JVS(1374))
  XX(154) = (X(154)-JVS(20)*XX(2)-JVS(157)*XX(24)-JVS(240)*XX(26)-JVS(465)*XX(74)-JVS(468)*XX(75)-JVS(478)*XX(77)&
              &-JVS(488)*XX(79)-JVS(532)*XX(86)-JVS(536)*XX(87)-JVS(601)*XX(97)-JVS(645)*XX(101)-JVS(668)*XX(102)-JVS(672)&
              &*XX(103)-JVS(789)*XX(117)-JVS(819)*XX(119)-JVS(832)*XX(120)-JVS(870)*XX(123)-JVS(931)*XX(127)-JVS(952)&
              &*XX(128)-JVS(962)*XX(129)-JVS(1004)*XX(132)-JVS(1041)*XX(135)-JVS(1052)*XX(136)-JVS(1130)*XX(142)-JVS(1222)&
              &*XX(148)-JVS(1316)*XX(150)-JVS(1355)*XX(152)-JVS(1375)*XX(153))/(JVS(1388))
  XX(155) = (X(155)-JVS(198)*XX(25)-JVS(337)*XX(46)-JVS(749)*XX(113)-JVS(767)*XX(115)-JVS(932)*XX(127)-JVS(971)*XX(130)&
              &-JVS(1021)*XX(133)-JVS(1053)*XX(136)-JVS(1088)*XX(139)-JVS(1223)*XX(148)-JVS(1317)*XX(150)-JVS(1376)*XX(153))&
              &/(JVS(1406))
  XX(156) = (X(156)-JVS(21)*XX(2)-JVS(241)*XX(26)-JVS(554)*XX(89)-JVS(646)*XX(101)-JVS(1224)*XX(148)-JVS(1318)*XX(150))&
              &/(JVS(1454))
  XX(157) = (X(157)-JVS(199)*XX(25)-JVS(242)*XX(26)-JVS(412)*XX(63)-JVS(933)*XX(127)-JVS(1319)*XX(150))/(JVS(1488))
  XX(158) = (X(158)-JVS(200)*XX(25)-JVS(243)*XX(26)-JVS(720)*XX(109)-JVS(757)*XX(114)-JVS(1031)*XX(134)-JVS(1104)&
              &*XX(140)-JVS(1179)*XX(147)-JVS(1225)*XX(148)-JVS(1320)*XX(150)-JVS(1455)*XX(156)-JVS(1489)*XX(157))&
              &/(JVS(1511))
  XX(159) = (X(159)-JVS(201)*XX(25)-JVS(934)*XX(127)-JVS(1089)*XX(139)-JVS(1105)*XX(140)-JVS(1117)*XX(141)-JVS(1226)&
              &*XX(148)-JVS(1321)*XX(150)-JVS(1407)*XX(155)-JVS(1456)*XX(156)-JVS(1490)*XX(157))/(JVS(1548))
  XX(160) = (X(160)-JVS(202)*XX(25)-JVS(244)*XX(26)-JVS(935)*XX(127)-JVS(1090)*XX(139)-JVS(1106)*XX(140)-JVS(1322)&
              &*XX(150)-JVS(1491)*XX(157))/(JVS(1601))
  XX(161) = (X(161)-JVS(245)*XX(26)-JVS(300)*XX(39)-JVS(365)*XX(53)-JVS(404)*XX(62)-JVS(413)*XX(63)-JVS(417)*XX(64)&
              &-JVS(446)*XX(70)-JVS(710)*XX(108)-JVS(750)*XX(113)-JVS(768)*XX(115)-JVS(936)*XX(127)-JVS(972)*XX(130)&
              &-JVS(1022)*XX(133)-JVS(1091)*XX(139)-JVS(1227)*XX(148)-JVS(1323)*XX(150)-JVS(1457)*XX(156)-JVS(1492)*XX(157)&
              &-JVS(1602)*XX(160))/(JVS(1639))
  XX(162) = (X(162)-JVS(22)*XX(2)-JVS(39)*XX(5)-JVS(55)*XX(9)-JVS(203)*XX(25)-JVS(246)*XX(26)-JVS(312)*XX(42)-JVS(340)&
              &*XX(47)-JVS(357)*XX(51)-JVS(384)*XX(58)-JVS(387)*XX(59)-JVS(418)*XX(64)-JVS(515)*XX(83)-JVS(562)*XX(90)&
              &-JVS(574)*XX(92)-JVS(589)*XX(95)-JVS(608)*XX(98)-JVS(680)*XX(104)-JVS(711)*XX(108)-JVS(727)*XX(110)-JVS(776)&
              &*XX(116)-JVS(797)*XX(118)-JVS(820)*XX(119)-JVS(839)*XX(121)-JVS(851)*XX(122)-JVS(871)*XX(123)-JVS(879)&
              &*XX(124)-JVS(887)*XX(125)-JVS(937)*XX(127)-JVS(982)*XX(131)-JVS(1032)*XX(134)-JVS(1064)*XX(137)-JVS(1075)&
              &*XX(138)-JVS(1092)*XX(139)-JVS(1107)*XX(140)-JVS(1118)*XX(141)-JVS(1138)*XX(143)-JVS(1147)*XX(144)-JVS(1158)&
              &*XX(145)-JVS(1169)*XX(146)-JVS(1180)*XX(147)-JVS(1228)*XX(148)-JVS(1242)*XX(149)-JVS(1324)*XX(150)-JVS(1341)&
              &*XX(151)-JVS(1356)*XX(152)-JVS(1377)*XX(153)-JVS(1389)*XX(154)-JVS(1408)*XX(155)-JVS(1458)*XX(156)-JVS(1493)&
              &*XX(157)-JVS(1512)*XX(158)-JVS(1549)*XX(159)-JVS(1603)*XX(160)-JVS(1640)*XX(161))/(JVS(1711))
  XX(163) = (X(163)-JVS(23)*XX(2)-JVS(40)*XX(5)-JVS(158)*XX(24)-JVS(204)*XX(25)-JVS(247)*XX(26)-JVS(362)*XX(52)-JVS(372)&
              &*XX(55)-JVS(423)*XX(65)-JVS(647)*XX(101)-JVS(669)*XX(102)-JVS(681)*XX(104)-JVS(733)*XX(111)-JVS(740)*XX(112)&
              &-JVS(751)*XX(113)-JVS(769)*XX(115)-JVS(777)*XX(116)-JVS(798)*XX(118)-JVS(821)*XX(119)-JVS(852)*XX(122)&
              &-JVS(872)*XX(123)-JVS(880)*XX(124)-JVS(938)*XX(127)-JVS(973)*XX(130)-JVS(983)*XX(131)-JVS(1005)*XX(132)&
              &-JVS(1023)*XX(133)-JVS(1033)*XX(134)-JVS(1042)*XX(135)-JVS(1054)*XX(136)-JVS(1065)*XX(137)-JVS(1076)*XX(138)&
              &-JVS(1093)*XX(139)-JVS(1108)*XX(140)-JVS(1119)*XX(141)-JVS(1131)*XX(142)-JVS(1139)*XX(143)-JVS(1148)*XX(144)&
              &-JVS(1159)*XX(145)-JVS(1170)*XX(146)-JVS(1181)*XX(147)-JVS(1229)*XX(148)-JVS(1243)*XX(149)-JVS(1325)*XX(150)&
              &-JVS(1342)*XX(151)-JVS(1357)*XX(152)-JVS(1378)*XX(153)-JVS(1390)*XX(154)-JVS(1409)*XX(155)-JVS(1459)*XX(156)&
              &-JVS(1494)*XX(157)-JVS(1513)*XX(158)-JVS(1550)*XX(159)-JVS(1604)*XX(160)-JVS(1641)*XX(161)-JVS(1712)*XX(162))&
              &/(JVS(1774))
  XX(164) = (X(164)-JVS(24)*XX(2)-JVS(205)*XX(25)-JVS(248)*XX(26)-JVS(424)*XX(65)-JVS(501)*XX(80)-JVS(516)*XX(83)&
              &-JVS(520)*XX(84)-JVS(555)*XX(89)-JVS(569)*XX(91)-JVS(575)*XX(92)-JVS(585)*XX(94)-JVS(590)*XX(95)-JVS(595)&
              &*XX(96)-JVS(621)*XX(100)-JVS(673)*XX(103)-JVS(688)*XX(105)-JVS(695)*XX(106)-JVS(702)*XX(107)-JVS(712)*XX(108)&
              &-JVS(721)*XX(109)-JVS(728)*XX(110)-JVS(758)*XX(114)-JVS(790)*XX(117)-JVS(822)*XX(119)-JVS(833)*XX(120)&
              &-JVS(840)*XX(121)-JVS(853)*XX(122)-JVS(873)*XX(123)-JVS(939)*XX(127)-JVS(953)*XX(128)-JVS(963)*XX(129)&
              &-JVS(1006)*XX(132)-JVS(1034)*XX(134)-JVS(1043)*XX(135)-JVS(1055)*XX(136)-JVS(1066)*XX(137)-JVS(1077)*XX(138)&
              &-JVS(1094)*XX(139)-JVS(1120)*XX(141)-JVS(1140)*XX(143)-JVS(1149)*XX(144)-JVS(1160)*XX(145)-JVS(1171)*XX(146)&
              &-JVS(1182)*XX(147)-JVS(1230)*XX(148)-JVS(1244)*XX(149)-JVS(1326)*XX(150)-JVS(1343)*XX(151)-JVS(1358)*XX(152)&
              &-JVS(1379)*XX(153)-JVS(1391)*XX(154)-JVS(1410)*XX(155)-JVS(1460)*XX(156)-JVS(1495)*XX(157)-JVS(1514)*XX(158)&
              &-JVS(1551)*XX(159)-JVS(1605)*XX(160)-JVS(1642)*XX(161)-JVS(1713)*XX(162)-JVS(1775)*XX(163))/(JVS(1812))
  XX(165) = (X(165)-JVS(25)*XX(2)-JVS(41)*XX(5)-JVS(49)*XX(7)-JVS(61)*XX(11)-JVS(74)*XX(15)-JVS(159)*XX(24)-JVS(206)&
              &*XX(25)-JVS(249)*XX(26)-JVS(288)*XX(34)-JVS(308)*XX(41)-JVS(316)*XX(43)-JVS(338)*XX(46)-JVS(344)*XX(48)&
              &-JVS(348)*XX(49)-JVS(469)*XX(75)-JVS(473)*XX(76)-JVS(479)*XX(77)-JVS(521)*XX(84)-JVS(527)*XX(85)-JVS(556)&
              &*XX(89)-JVS(570)*XX(91)-JVS(596)*XX(96)-JVS(602)*XX(97)-JVS(615)*XX(99)-JVS(622)*XX(100)-JVS(648)*XX(101)&
              &-JVS(674)*XX(103)-JVS(682)*XX(104)-JVS(689)*XX(105)-JVS(696)*XX(106)-JVS(703)*XX(107)-JVS(713)*XX(108)&
              &-JVS(722)*XX(109)-JVS(734)*XX(111)-JVS(741)*XX(112)-JVS(752)*XX(113)-JVS(759)*XX(114)-JVS(770)*XX(115)&
              &-JVS(778)*XX(116)-JVS(791)*XX(117)-JVS(799)*XX(118)-JVS(823)*XX(119)-JVS(834)*XX(120)-JVS(841)*XX(121)&
              &-JVS(854)*XX(122)-JVS(874)*XX(123)-JVS(881)*XX(124)-JVS(888)*XX(125)-JVS(896)*XX(126)-JVS(940)*XX(127)&
              &-JVS(954)*XX(128)-JVS(964)*XX(129)-JVS(974)*XX(130)-JVS(984)*XX(131)-JVS(1007)*XX(132)-JVS(1024)*XX(133)&
              &-JVS(1035)*XX(134)-JVS(1044)*XX(135)-JVS(1056)*XX(136)-JVS(1067)*XX(137)-JVS(1078)*XX(138)-JVS(1095)*XX(139)&
              &-JVS(1109)*XX(140)-JVS(1121)*XX(141)-JVS(1132)*XX(142)-JVS(1141)*XX(143)-JVS(1150)*XX(144)-JVS(1161)*XX(145)&
              &-JVS(1172)*XX(146)-JVS(1183)*XX(147)-JVS(1231)*XX(148)-JVS(1245)*XX(149)-JVS(1327)*XX(150)-JVS(1344)*XX(151)&
              &-JVS(1359)*XX(152)-JVS(1380)*XX(153)-JVS(1392)*XX(154)-JVS(1411)*XX(155)-JVS(1461)*XX(156)-JVS(1496)*XX(157)&
              &-JVS(1515)*XX(158)-JVS(1552)*XX(159)-JVS(1606)*XX(160)-JVS(1643)*XX(161)-JVS(1714)*XX(162)-JVS(1776)*XX(163)&
              &-JVS(1813)*XX(164))/(JVS(1881))
  XX(166) = (X(166)-JVS(42)*XX(5)-JVS(160)*XX(24)-JVS(207)*XX(25)-JVS(293)*XX(36)-JVS(296)*XX(37)-JVS(301)*XX(39)&
              &-JVS(313)*XX(42)-JVS(349)*XX(49)-JVS(358)*XX(51)-JVS(363)*XX(52)-JVS(368)*XX(54)-JVS(428)*XX(66)-JVS(447)&
              &*XX(70)-JVS(586)*XX(94)-JVS(609)*XX(98)-JVS(616)*XX(99)-JVS(623)*XX(100)-JVS(649)*XX(101)-JVS(690)*XX(105)&
              &-JVS(697)*XX(106)-JVS(704)*XX(107)-JVS(714)*XX(108)-JVS(723)*XX(109)-JVS(760)*XX(114)-JVS(842)*XX(121)&
              &-JVS(889)*XX(125)-JVS(941)*XX(127)-JVS(1008)*XX(132)-JVS(1110)*XX(140)-JVS(1162)*XX(145)-JVS(1232)*XX(148)&
              &-JVS(1246)*XX(149)-JVS(1328)*XX(150)-JVS(1462)*XX(156)-JVS(1497)*XX(157)-JVS(1516)*XX(158)-JVS(1553)*XX(159)&
              &-JVS(1607)*XX(160)-JVS(1644)*XX(161)-JVS(1715)*XX(162)-JVS(1777)*XX(163)-JVS(1814)*XX(164)-JVS(1882)*XX(165))&
              &/(JVS(1973))
  XX(167) = (X(167)-JVS(26)*XX(2)-JVS(52)*XX(8)-JVS(68)*XX(13)-JVS(77)*XX(16)-JVS(80)*XX(17)-JVS(89)*XX(18)-JVS(101)&
              &*XX(22)-JVS(161)*XX(24)-JVS(208)*XX(25)-JVS(250)*XX(26)-JVS(261)*XX(27)-JVS(271)*XX(28)-JVS(274)*XX(29)&
              &-JVS(276)*XX(30)-JVS(278)*XX(31)-JVS(284)*XX(33)-JVS(298)*XX(38)-JVS(305)*XX(40)-JVS(309)*XX(41)-JVS(317)&
              &*XX(43)-JVS(323)*XX(44)-JVS(328)*XX(45)-JVS(341)*XX(47)-JVS(345)*XX(48)-JVS(350)*XX(49)-JVS(352)*XX(50)&
              &-JVS(359)*XX(51)-JVS(366)*XX(53)-JVS(369)*XX(54)-JVS(373)*XX(55)-JVS(377)*XX(56)-JVS(381)*XX(57)-JVS(385)&
              &*XX(58)-JVS(388)*XX(59)-JVS(391)*XX(60)-JVS(397)*XX(61)-JVS(405)*XX(62)-JVS(414)*XX(63)-JVS(419)*XX(64)&
              &-JVS(425)*XX(65)-JVS(429)*XX(66)-JVS(434)*XX(67)-JVS(438)*XX(68)-JVS(442)*XX(69)-JVS(451)*XX(71)-JVS(457)&
              &*XX(72)-JVS(462)*XX(73)-JVS(466)*XX(74)-JVS(474)*XX(76)-JVS(480)*XX(77)-JVS(485)*XX(78)-JVS(489)*XX(79)&
              &-JVS(502)*XX(80)-JVS(506)*XX(81)-JVS(510)*XX(82)-JVS(517)*XX(83)-JVS(522)*XX(84)-JVS(528)*XX(85)-JVS(533)&
              &*XX(86)-JVS(537)*XX(87)-JVS(542)*XX(88)-JVS(557)*XX(89)-JVS(563)*XX(90)-JVS(571)*XX(91)-JVS(576)*XX(92)&
              &-JVS(581)*XX(93)-JVS(587)*XX(94)-JVS(591)*XX(95)-JVS(597)*XX(96)-JVS(610)*XX(98)-JVS(617)*XX(99)-JVS(650)&
              &*XX(101)-JVS(670)*XX(102)-JVS(675)*XX(103)-JVS(683)*XX(104)-JVS(715)*XX(108)-JVS(729)*XX(110)-JVS(735)&
              &*XX(111)-JVS(742)*XX(112)-JVS(753)*XX(113)-JVS(771)*XX(115)-JVS(792)*XX(117)-JVS(800)*XX(118)-JVS(824)&
              &*XX(119)-JVS(835)*XX(120)-JVS(843)*XX(121)-JVS(855)*XX(122)-JVS(875)*XX(123)-JVS(890)*XX(125)-JVS(897)&
              &*XX(126)-JVS(942)*XX(127)-JVS(955)*XX(128)-JVS(965)*XX(129)-JVS(975)*XX(130)-JVS(985)*XX(131)-JVS(1009)&
              &*XX(132)-JVS(1025)*XX(133)-JVS(1036)*XX(134)-JVS(1045)*XX(135)-JVS(1057)*XX(136)-JVS(1068)*XX(137)-JVS(1079)&
              &*XX(138)-JVS(1096)*XX(139)-JVS(1111)*XX(140)-JVS(1122)*XX(141)-JVS(1133)*XX(142)-JVS(1142)*XX(143)-JVS(1151)&
              &*XX(144)-JVS(1163)*XX(145)-JVS(1173)*XX(146)-JVS(1184)*XX(147)-JVS(1233)*XX(148)-JVS(1247)*XX(149)-JVS(1329)&
              &*XX(150)-JVS(1345)*XX(151)-JVS(1360)*XX(152)-JVS(1381)*XX(153)-JVS(1393)*XX(154)-JVS(1412)*XX(155)-JVS(1463)&
              &*XX(156)-JVS(1498)*XX(157)-JVS(1517)*XX(158)-JVS(1554)*XX(159)-JVS(1608)*XX(160)-JVS(1645)*XX(161)-JVS(1716)&
              &*XX(162)-JVS(1778)*XX(163)-JVS(1815)*XX(164)-JVS(1883)*XX(165)-JVS(1974)*XX(166))/(JVS(2102))
  XX(168) = (X(168)-JVS(27)*XX(2)-JVS(262)*XX(27)-JVS(624)*XX(100)-JVS(691)*XX(105)-JVS(698)*XX(106)-JVS(705)*XX(107)&
              &-JVS(761)*XX(114)-JVS(844)*XX(121)-JVS(1010)*XX(132)-JVS(1234)*XX(148)-JVS(1248)*XX(149)-JVS(1330)*XX(150)&
              &-JVS(1464)*XX(156)-JVS(1499)*XX(157)-JVS(1518)*XX(158)-JVS(1555)*XX(159)-JVS(1609)*XX(160)-JVS(1646)*XX(161)&
              &-JVS(1717)*XX(162)-JVS(1779)*XX(163)-JVS(1816)*XX(164)-JVS(1884)*XX(165)-JVS(1975)*XX(166)-JVS(2103)*XX(167))&
              &/(JVS(2165))
  XX(169) = (X(169)-JVS(28)*XX(2)-JVS(43)*XX(5)-JVS(46)*XX(6)-JVS(58)*XX(10)-JVS(71)*XX(14)-JVS(162)*XX(24)-JVS(209)&
              &*XX(25)-JVS(251)*XX(26)-JVS(310)*XX(41)-JVS(318)*XX(43)-JVS(346)*XX(48)-JVS(353)*XX(50)-JVS(370)*XX(54)&
              &-JVS(374)*XX(55)-JVS(378)*XX(56)-JVS(382)*XX(57)-JVS(392)*XX(60)-JVS(398)*XX(61)-JVS(406)*XX(62)-JVS(415)&
              &*XX(63)-JVS(435)*XX(67)-JVS(439)*XX(68)-JVS(443)*XX(69)-JVS(452)*XX(71)-JVS(458)*XX(72)-JVS(463)*XX(73)&
              &-JVS(470)*XX(75)-JVS(475)*XX(76)-JVS(481)*XX(77)-JVS(486)*XX(78)-JVS(490)*XX(79)-JVS(503)*XX(80)-JVS(507)&
              &*XX(81)-JVS(511)*XX(82)-JVS(529)*XX(85)-JVS(534)*XX(86)-JVS(538)*XX(87)-JVS(543)*XX(88)-JVS(558)*XX(89)&
              &-JVS(564)*XX(90)-JVS(572)*XX(91)-JVS(582)*XX(93)-JVS(598)*XX(96)-JVS(603)*XX(97)-JVS(618)*XX(99)-JVS(651)&
              &*XX(101)-JVS(684)*XX(104)-JVS(716)*XX(108)-JVS(736)*XX(111)-JVS(743)*XX(112)-JVS(754)*XX(113)-JVS(772)&
              &*XX(115)-JVS(779)*XX(116)-JVS(793)*XX(117)-JVS(801)*XX(118)-JVS(825)*XX(119)-JVS(836)*XX(120)-JVS(856)&
              &*XX(122)-JVS(876)*XX(123)-JVS(882)*XX(124)-JVS(891)*XX(125)-JVS(898)*XX(126)-JVS(943)*XX(127)-JVS(956)&
              &*XX(128)-JVS(966)*XX(129)-JVS(976)*XX(130)-JVS(986)*XX(131)-JVS(1011)*XX(132)-JVS(1026)*XX(133)-JVS(1037)&
              &*XX(134)-JVS(1058)*XX(136)-JVS(1069)*XX(137)-JVS(1080)*XX(138)-JVS(1097)*XX(139)-JVS(1112)*XX(140)-JVS(1123)&
              &*XX(141)-JVS(1134)*XX(142)-JVS(1143)*XX(143)-JVS(1152)*XX(144)-JVS(1164)*XX(145)-JVS(1185)*XX(147)-JVS(1235)&
              &*XX(148)-JVS(1249)*XX(149)-JVS(1331)*XX(150)-JVS(1346)*XX(151)-JVS(1361)*XX(152)-JVS(1382)*XX(153)-JVS(1394)&
              &*XX(154)-JVS(1413)*XX(155)-JVS(1465)*XX(156)-JVS(1500)*XX(157)-JVS(1519)*XX(158)-JVS(1556)*XX(159)-JVS(1610)&
              &*XX(160)-JVS(1647)*XX(161)-JVS(1718)*XX(162)-JVS(1780)*XX(163)-JVS(1817)*XX(164)-JVS(1885)*XX(165)-JVS(1976)&
              &*XX(166)-JVS(2104)*XX(167)-JVS(2166)*XX(168))/(JVS(2272))
  XX(170) = (X(170)-JVS(210)*XX(25)-JVS(252)*XX(26)-JVS(360)*XX(51)-JVS(565)*XX(90)-JVS(611)*XX(98)-JVS(706)*XX(107)&
              &-JVS(724)*XX(109)-JVS(883)*XX(124)-JVS(944)*XX(127)-JVS(987)*XX(131)-JVS(1165)*XX(145)-JVS(1236)*XX(148)&
              &-JVS(1250)*XX(149)-JVS(1332)*XX(150)-JVS(1414)*XX(155)-JVS(1466)*XX(156)-JVS(1501)*XX(157)-JVS(1557)*XX(159)&
              &-JVS(1611)*XX(160)-JVS(1648)*XX(161)-JVS(1719)*XX(162)-JVS(1781)*XX(163)-JVS(1818)*XX(164)-JVS(1886)*XX(165)&
              &-JVS(1977)*XX(166)-JVS(2105)*XX(167)-JVS(2167)*XX(168)-JVS(2273)*XX(169))/(JVS(2293))
  XX(171) = (X(171)-JVS(29)*XX(2)-JVS(163)*XX(24)-JVS(253)*XX(26)-JVS(354)*XX(50)-JVS(430)*XX(66)-JVS(523)*XX(84)&
              &-JVS(530)*XX(85)-JVS(599)*XX(96)-JVS(604)*XX(97)-JVS(652)*XX(101)-JVS(685)*XX(104)-JVS(737)*XX(111)-JVS(755)&
              &*XX(113)-JVS(773)*XX(115)-JVS(802)*XX(118)-JVS(826)*XX(119)-JVS(857)*XX(122)-JVS(877)*XX(123)-JVS(884)&
              &*XX(124)-JVS(945)*XX(127)-JVS(977)*XX(130)-JVS(988)*XX(131)-JVS(1012)*XX(132)-JVS(1027)*XX(133)-JVS(1038)&
              &*XX(134)-JVS(1059)*XX(136)-JVS(1070)*XX(137)-JVS(1081)*XX(138)-JVS(1098)*XX(139)-JVS(1113)*XX(140)-JVS(1124)&
              &*XX(141)-JVS(1135)*XX(142)-JVS(1144)*XX(143)-JVS(1153)*XX(144)-JVS(1166)*XX(145)-JVS(1174)*XX(146)-JVS(1186)&
              &*XX(147)-JVS(1237)*XX(148)-JVS(1251)*XX(149)-JVS(1333)*XX(150)-JVS(1347)*XX(151)-JVS(1362)*XX(152)-JVS(1383)&
              &*XX(153)-JVS(1395)*XX(154)-JVS(1415)*XX(155)-JVS(1467)*XX(156)-JVS(1502)*XX(157)-JVS(1520)*XX(158)-JVS(1558)&
              &*XX(159)-JVS(1612)*XX(160)-JVS(1649)*XX(161)-JVS(1720)*XX(162)-JVS(1782)*XX(163)-JVS(1819)*XX(164)-JVS(1887)&
              &*XX(165)-JVS(1978)*XX(166)-JVS(2106)*XX(167)-JVS(2168)*XX(168)-JVS(2274)*XX(169)-JVS(2294)*XX(170))&
              &/(JVS(2356))
  XX(172) = (X(172)-JVS(90)*XX(18)-JVS(272)*XX(28)-JVS(625)*XX(100)-JVS(692)*XX(105)-JVS(699)*XX(106)-JVS(707)*XX(107)&
              &-JVS(725)*XX(109)-JVS(762)*XX(114)-JVS(845)*XX(121)-JVS(1013)*XX(132)-JVS(1238)*XX(148)-JVS(1252)*XX(149)&
              &-JVS(1334)*XX(150)-JVS(1468)*XX(156)-JVS(1503)*XX(157)-JVS(1521)*XX(158)-JVS(1559)*XX(159)-JVS(1613)*XX(160)&
              &-JVS(1650)*XX(161)-JVS(1721)*XX(162)-JVS(1783)*XX(163)-JVS(1820)*XX(164)-JVS(1888)*XX(165)-JVS(1979)*XX(166)&
              &-JVS(2107)*XX(167)-JVS(2169)*XX(168)-JVS(2275)*XX(169)-JVS(2295)*XX(170)-JVS(2357)*XX(171))/(JVS(2381))
  XX(172) = XX(172)
  XX(171) = XX(171)-JVS(2380)*XX(172)
  XX(170) = XX(170)-JVS(2355)*XX(171)-JVS(2379)*XX(172)
  XX(169) = XX(169)-JVS(2292)*XX(170)-JVS(2354)*XX(171)-JVS(2378)*XX(172)
  XX(168) = XX(168)-JVS(2271)*XX(169)-JVS(2291)*XX(170)-JVS(2353)*XX(171)-JVS(2377)*XX(172)
  XX(167) = XX(167)-JVS(2164)*XX(168)-JVS(2270)*XX(169)-JVS(2290)*XX(170)-JVS(2352)*XX(171)-JVS(2376)*XX(172)
  XX(166) = XX(166)-JVS(2101)*XX(167)-JVS(2163)*XX(168)-JVS(2269)*XX(169)-JVS(2289)*XX(170)-JVS(2351)*XX(171)-JVS(2375)&
              &*XX(172)
  XX(165) = XX(165)-JVS(1972)*XX(166)-JVS(2100)*XX(167)-JVS(2162)*XX(168)-JVS(2268)*XX(169)-JVS(2288)*XX(170)-JVS(2350)&
              &*XX(171)-JVS(2374)*XX(172)
  XX(164) = XX(164)-JVS(1880)*XX(165)-JVS(1971)*XX(166)-JVS(2099)*XX(167)-JVS(2161)*XX(168)-JVS(2267)*XX(169)-JVS(2287)&
              &*XX(170)-JVS(2349)*XX(171)-JVS(2373)*XX(172)
  XX(163) = XX(163)-JVS(1811)*XX(164)-JVS(1879)*XX(165)-JVS(1970)*XX(166)-JVS(2098)*XX(167)-JVS(2160)*XX(168)-JVS(2266)&
              &*XX(169)-JVS(2286)*XX(170)-JVS(2348)*XX(171)-JVS(2372)*XX(172)
  XX(162) = XX(162)-JVS(1773)*XX(163)-JVS(1810)*XX(164)-JVS(1878)*XX(165)-JVS(1969)*XX(166)-JVS(2097)*XX(167)-JVS(2159)&
              &*XX(168)-JVS(2265)*XX(169)-JVS(2285)*XX(170)-JVS(2347)*XX(171)-JVS(2371)*XX(172)
  XX(161) = XX(161)-JVS(1710)*XX(162)-JVS(1772)*XX(163)-JVS(1809)*XX(164)-JVS(1877)*XX(165)-JVS(1968)*XX(166)-JVS(2096)&
              &*XX(167)-JVS(2158)*XX(168)-JVS(2264)*XX(169)-JVS(2346)*XX(171)
  XX(160) = XX(160)-JVS(1638)*XX(161)-JVS(1709)*XX(162)-JVS(1771)*XX(163)-JVS(1808)*XX(164)-JVS(1876)*XX(165)-JVS(1967)&
              &*XX(166)-JVS(2095)*XX(167)-JVS(2157)*XX(168)-JVS(2263)*XX(169)-JVS(2345)*XX(171)
  XX(159) = XX(159)-JVS(1600)*XX(160)-JVS(1637)*XX(161)-JVS(1708)*XX(162)-JVS(1770)*XX(163)-JVS(1807)*XX(164)-JVS(1875)&
              &*XX(165)-JVS(1966)*XX(166)-JVS(2094)*XX(167)-JVS(2156)*XX(168)-JVS(2262)*XX(169)-JVS(2344)*XX(171)
  XX(158) = XX(158)-JVS(1547)*XX(159)-JVS(1599)*XX(160)-JVS(1636)*XX(161)-JVS(1707)*XX(162)-JVS(1769)*XX(163)-JVS(1806)&
              &*XX(164)-JVS(1874)*XX(165)-JVS(1965)*XX(166)-JVS(2093)*XX(167)-JVS(2155)*XX(168)-JVS(2261)*XX(169)-JVS(2343)&
              &*XX(171)-JVS(2370)*XX(172)
  XX(157) = XX(157)-JVS(1635)*XX(161)-JVS(1706)*XX(162)-JVS(1768)*XX(163)-JVS(1964)*XX(166)-JVS(2092)*XX(167)-JVS(2154)&
              &*XX(168)-JVS(2260)*XX(169)-JVS(2342)*XX(171)
  XX(156) = XX(156)-JVS(1634)*XX(161)-JVS(1705)*XX(162)-JVS(1767)*XX(163)-JVS(1963)*XX(166)-JVS(2091)*XX(167)-JVS(2153)&
              &*XX(168)-JVS(2259)*XX(169)-JVS(2341)*XX(171)
  XX(155) = XX(155)-JVS(1453)*XX(156)-JVS(1487)*XX(157)-JVS(1546)*XX(159)-JVS(1598)*XX(160)-JVS(1633)*XX(161)-JVS(1704)&
              &*XX(162)-JVS(1766)*XX(163)-JVS(1873)*XX(165)-JVS(1962)*XX(166)-JVS(2090)*XX(167)-JVS(2152)*XX(168)-JVS(2258)&
              &*XX(169)-JVS(2340)*XX(171)
  XX(154) = XX(154)-JVS(1405)*XX(155)-JVS(1452)*XX(156)-JVS(1486)*XX(157)-JVS(1510)*XX(158)-JVS(1545)*XX(159)-JVS(1597)&
              &*XX(160)-JVS(1632)*XX(161)-JVS(1703)*XX(162)-JVS(1765)*XX(163)-JVS(1805)*XX(164)-JVS(1872)*XX(165)-JVS(1961)&
              &*XX(166)-JVS(2089)*XX(167)-JVS(2151)*XX(168)-JVS(2257)*XX(169)-JVS(2284)*XX(170)-JVS(2339)*XX(171)-JVS(2369)&
              &*XX(172)
  XX(153) = XX(153)-JVS(1404)*XX(155)-JVS(1451)*XX(156)-JVS(1485)*XX(157)-JVS(1544)*XX(159)-JVS(1596)*XX(160)-JVS(1631)&
              &*XX(161)-JVS(1702)*XX(162)-JVS(1764)*XX(163)-JVS(1871)*XX(165)-JVS(1960)*XX(166)-JVS(2088)*XX(167)-JVS(2150)&
              &*XX(168)-JVS(2256)*XX(169)-JVS(2338)*XX(171)
  XX(152) = XX(152)-JVS(1373)*XX(153)-JVS(1450)*XX(156)-JVS(1543)*XX(159)-JVS(1595)*XX(160)-JVS(1630)*XX(161)-JVS(1701)&
              &*XX(162)-JVS(1763)*XX(163)-JVS(1804)*XX(164)-JVS(1870)*XX(165)-JVS(1959)*XX(166)-JVS(2087)*XX(167)-JVS(2149)&
              &*XX(168)-JVS(2255)*XX(169)-JVS(2337)*XX(171)-JVS(2368)*XX(172)
  XX(151) = XX(151)-JVS(1353)*XX(152)-JVS(1372)*XX(153)-JVS(1403)*XX(155)-JVS(1449)*XX(156)-JVS(1484)*XX(157)-JVS(1509)&
              &*XX(158)-JVS(1542)*XX(159)-JVS(1594)*XX(160)-JVS(1629)*XX(161)-JVS(1700)*XX(162)-JVS(1762)*XX(163)-JVS(1803)&
              &*XX(164)-JVS(1869)*XX(165)-JVS(1958)*XX(166)-JVS(2086)*XX(167)-JVS(2148)*XX(168)-JVS(2254)*XX(169)-JVS(2283)&
              &*XX(170)-JVS(2336)*XX(171)
  XX(150) = XX(150)-JVS(1628)*XX(161)-JVS(1699)*XX(162)-JVS(1957)*XX(166)-JVS(2085)*XX(167)-JVS(2147)*XX(168)-JVS(2253)&
              &*XX(169)
  XX(149) = XX(149)-JVS(1311)*XX(150)-JVS(1448)*XX(156)-JVS(1541)*XX(159)-JVS(1593)*XX(160)-JVS(1698)*XX(162)-JVS(1761)&
              &*XX(163)-JVS(1868)*XX(165)-JVS(1956)*XX(166)-JVS(2084)*XX(167)-JVS(2146)*XX(168)-JVS(2252)*XX(169)-JVS(2335)&
              &*XX(171)
  XX(148) = XX(148)-JVS(1697)*XX(162)-JVS(1955)*XX(166)-JVS(2083)*XX(167)-JVS(2145)*XX(168)-JVS(2251)*XX(169)-JVS(2334)&
              &*XX(171)
  XX(147) = XX(147)-JVS(1216)*XX(148)-JVS(1310)*XX(150)-JVS(1447)*XX(156)-JVS(1483)*XX(157)-JVS(1592)*XX(160)-JVS(1696)&
              &*XX(162)-JVS(1760)*XX(163)-JVS(1802)*XX(164)-JVS(1867)*XX(165)-JVS(1954)*XX(166)-JVS(2082)*XX(167)-JVS(2144)&
              &*XX(168)-JVS(2250)*XX(169)-JVS(2333)*XX(171)-JVS(2367)*XX(172)
  XX(146) = XX(146)-JVS(1215)*XX(148)-JVS(1309)*XX(150)-JVS(1339)*XX(151)-JVS(1402)*XX(155)-JVS(1446)*XX(156)-JVS(1482)&
              &*XX(157)-JVS(1540)*XX(159)-JVS(1591)*XX(160)-JVS(1695)*XX(162)-JVS(1759)*XX(163)-JVS(1801)*XX(164)-JVS(1866)&
              &*XX(165)-JVS(1953)*XX(166)-JVS(2081)*XX(167)-JVS(2143)*XX(168)-JVS(2249)*XX(169)-JVS(2332)*XX(171)
  XX(145) = XX(145)-JVS(1308)*XX(150)-JVS(1445)*XX(156)-JVS(1539)*XX(159)-JVS(1590)*XX(160)-JVS(1694)*XX(162)-JVS(1758)&
              &*XX(163)-JVS(1800)*XX(164)-JVS(1865)*XX(165)-JVS(1952)*XX(166)-JVS(2080)*XX(167)-JVS(2142)*XX(168)-JVS(2248)&
              &*XX(169)-JVS(2331)*XX(171)
  XX(144) = XX(144)-JVS(1214)*XX(148)-JVS(1307)*XX(150)-JVS(1371)*XX(153)-JVS(1444)*XX(156)-JVS(1538)*XX(159)-JVS(1589)&
              &*XX(160)-JVS(1627)*XX(161)-JVS(1693)*XX(162)-JVS(1757)*XX(163)-JVS(1799)*XX(164)-JVS(1864)*XX(165)-JVS(1951)&
              &*XX(166)-JVS(2079)*XX(167)-JVS(2141)*XX(168)-JVS(2247)*XX(169)-JVS(2330)*XX(171)
  XX(143) = XX(143)-JVS(1177)*XX(147)-JVS(1306)*XX(150)-JVS(1370)*XX(153)-JVS(1443)*XX(156)-JVS(1537)*XX(159)-JVS(1588)&
              &*XX(160)-JVS(1692)*XX(162)-JVS(1756)*XX(163)-JVS(1798)*XX(164)-JVS(1863)*XX(165)-JVS(1950)*XX(166)-JVS(2078)&
              &*XX(167)-JVS(2246)*XX(169)-JVS(2282)*XX(170)-JVS(2329)*XX(171)
  XX(142) = XX(142)-JVS(1213)*XX(148)-JVS(1305)*XX(150)-JVS(1369)*XX(153)-JVS(1442)*XX(156)-JVS(1536)*XX(159)-JVS(1587)&
              &*XX(160)-JVS(1691)*XX(162)-JVS(1755)*XX(163)-JVS(1797)*XX(164)-JVS(1862)*XX(165)-JVS(1949)*XX(166)-JVS(2077)&
              &*XX(167)-JVS(2140)*XX(168)-JVS(2245)*XX(169)-JVS(2328)*XX(171)
  XX(141) = XX(141)-JVS(1212)*XX(148)-JVS(1304)*XX(150)-JVS(1401)*XX(155)-JVS(1441)*XX(156)-JVS(1481)*XX(157)-JVS(1535)&
              &*XX(159)-JVS(1586)*XX(160)-JVS(1754)*XX(163)-JVS(1861)*XX(165)-JVS(1948)*XX(166)-JVS(2076)*XX(167)-JVS(2244)&
              &*XX(169)-JVS(2327)*XX(171)
  XX(140) = XX(140)-JVS(1303)*XX(150)-JVS(1480)*XX(157)-JVS(1753)*XX(163)-JVS(1796)*XX(164)-JVS(1860)*XX(165)-JVS(1947)&
              &*XX(166)-JVS(2075)*XX(167)-JVS(2243)*XX(169)-JVS(2326)*XX(171)
  XX(139) = XX(139)-JVS(1302)*XX(150)-JVS(1479)*XX(157)-JVS(1752)*XX(163)-JVS(1859)*XX(165)-JVS(1946)*XX(166)-JVS(2074)&
              &*XX(167)-JVS(2242)*XX(169)-JVS(2325)*XX(171)
  XX(138) = XX(138)-JVS(1301)*XX(150)-JVS(1440)*XX(156)-JVS(1534)*XX(159)-JVS(1585)*XX(160)-JVS(1690)*XX(162)-JVS(1751)&
              &*XX(163)-JVS(1795)*XX(164)-JVS(1858)*XX(165)-JVS(1945)*XX(166)-JVS(2073)*XX(167)-JVS(2241)*XX(169)-JVS(2324)&
              &*XX(171)
  XX(137) = XX(137)-JVS(1073)*XX(138)-JVS(1300)*XX(150)-JVS(1439)*XX(156)-JVS(1533)*XX(159)-JVS(1584)*XX(160)-JVS(1689)&
              &*XX(162)-JVS(1750)*XX(163)-JVS(1794)*XX(164)-JVS(1857)*XX(165)-JVS(1944)*XX(166)-JVS(2072)*XX(167)-JVS(2240)&
              &*XX(169)-JVS(2323)*XX(171)
  XX(136) = XX(136)-JVS(1299)*XX(150)-JVS(1368)*XX(153)-JVS(1400)*XX(155)-JVS(1478)*XX(157)-JVS(1583)*XX(160)-JVS(1749)&
              &*XX(163)-JVS(1856)*XX(165)-JVS(1943)*XX(166)-JVS(2071)*XX(167)-JVS(2239)*XX(169)-JVS(2322)*XX(171)
  XX(135) = XX(135)-JVS(1049)*XX(136)-JVS(1211)*XX(148)-JVS(1298)*XX(150)-JVS(1352)*XX(152)-JVS(1438)*XX(156)-JVS(1477)&
              &*XX(157)-JVS(1582)*XX(160)-JVS(1688)*XX(162)-JVS(1748)*XX(163)-JVS(1793)*XX(164)-JVS(1855)*XX(165)-JVS(1942)&
              &*XX(166)-JVS(2070)*XX(167)-JVS(2139)*XX(168)-JVS(2238)*XX(169)-JVS(2321)*XX(171)
  XX(134) = XX(134)-JVS(1210)*XX(148)-JVS(1297)*XX(150)-JVS(1532)*XX(159)-JVS(1581)*XX(160)-JVS(1687)*XX(162)-JVS(1747)&
              &*XX(163)-JVS(1854)*XX(165)-JVS(1941)*XX(166)-JVS(2069)*XX(167)-JVS(2138)*XX(168)-JVS(2237)*XX(169)-JVS(2320)&
              &*XX(171)
  XX(133) = XX(133)-JVS(1209)*XX(148)-JVS(1296)*XX(150)-JVS(1437)*XX(156)-JVS(1746)*XX(163)-JVS(1853)*XX(165)-JVS(1940)&
              &*XX(166)-JVS(2068)*XX(167)-JVS(2236)*XX(169)-JVS(2319)*XX(171)
  XX(132) = XX(132)-JVS(1295)*XX(150)-JVS(1686)*XX(162)-JVS(1939)*XX(166)-JVS(2067)*XX(167)-JVS(2137)*XX(168)-JVS(2235)&
              &*XX(169)
  XX(131) = XX(131)-JVS(1294)*XX(150)-JVS(1436)*XX(156)-JVS(1531)*XX(159)-JVS(1580)*XX(160)-JVS(1685)*XX(162)-JVS(1745)&
              &*XX(163)-JVS(1852)*XX(165)-JVS(1938)*XX(166)-JVS(2066)*XX(167)-JVS(2234)*XX(169)-JVS(2318)*XX(171)
  XX(130) = XX(130)-JVS(1016)*XX(133)-JVS(1293)*XX(150)-JVS(1579)*XX(160)-JVS(1626)*XX(161)-JVS(1744)*XX(163)-JVS(1851)&
              &*XX(165)-JVS(1937)*XX(166)-JVS(2065)*XX(167)-JVS(2136)*XX(168)-JVS(2233)*XX(169)-JVS(2317)*XX(171)
  XX(129) = XX(129)-JVS(997)*XX(132)-JVS(1048)*XX(136)-JVS(1208)*XX(148)-JVS(1292)*XX(150)-JVS(1435)*XX(156)-JVS(1578)&
              &*XX(160)-JVS(1684)*XX(162)-JVS(1743)*XX(163)-JVS(1850)*XX(165)-JVS(1936)*XX(166)-JVS(2064)*XX(167)-JVS(2135)&
              &*XX(168)-JVS(2232)*XX(169)-JVS(2316)*XX(171)
  XX(128) = XX(128)-JVS(1207)*XX(148)-JVS(1291)*XX(150)-JVS(1434)*XX(156)-JVS(1683)*XX(162)-JVS(1742)*XX(163)-JVS(1849)&
              &*XX(165)-JVS(1935)*XX(166)-JVS(2063)*XX(167)-JVS(2134)*XX(168)-JVS(2231)*XX(169)
  XX(127) = XX(127)-JVS(1682)*XX(162)-JVS(1934)*XX(166)-JVS(2062)*XX(167)
  XX(126) = XX(126)-JVS(915)*XX(127)-JVS(947)*XX(128)-JVS(959)*XX(129)-JVS(996)*XX(132)-JVS(1047)*XX(136)-JVS(1206)&
              &*XX(148)-JVS(1290)*XX(150)-JVS(1433)*XX(156)-JVS(1577)*XX(160)-JVS(1681)*XX(162)-JVS(1741)*XX(163)-JVS(1848)&
              &*XX(165)-JVS(1933)*XX(166)-JVS(2061)*XX(167)-JVS(2133)*XX(168)-JVS(2230)*XX(169)-JVS(2315)*XX(171)
  XX(125) = XX(125)-JVS(1101)*XX(140)-JVS(1205)*XX(148)-JVS(1289)*XX(150)-JVS(1432)*XX(156)-JVS(1476)*XX(157)-JVS(1680)&
              &*XX(162)-JVS(1740)*XX(163)-JVS(1792)*XX(164)-JVS(1847)*XX(165)-JVS(1932)*XX(166)-JVS(2060)*XX(167)-JVS(2132)&
              &*XX(168)-JVS(2229)*XX(169)-JVS(2314)*XX(171)
  XX(124) = XX(124)-JVS(979)*XX(131)-JVS(1156)*XX(145)-JVS(1204)*XX(148)-JVS(1288)*XX(150)-JVS(1399)*XX(155)-JVS(1576)&
              &*XX(160)-JVS(1739)*XX(163)-JVS(1846)*XX(165)-JVS(1931)*XX(166)-JVS(2059)*XX(167)-JVS(2131)*XX(168)-JVS(2228)&
              &*XX(169)-JVS(2313)*XX(171)
  XX(123) = XX(123)-JVS(1203)*XX(148)-JVS(1287)*XX(150)-JVS(1738)*XX(163)-JVS(1930)*XX(166)-JVS(2058)*XX(167)-JVS(2130)&
              &*XX(168)
  XX(122) = XX(122)-JVS(914)*XX(127)-JVS(1431)*XX(156)-JVS(1575)*XX(160)-JVS(1679)*XX(162)-JVS(1791)*XX(164)-JVS(1929)&
              &*XX(166)-JVS(2057)*XX(167)
  XX(121) = XX(121)-JVS(1240)*XX(149)-JVS(1286)*XX(150)-JVS(1430)*XX(156)-JVS(1678)*XX(162)-JVS(1845)*XX(165)-JVS(1928)&
              &*XX(166)-JVS(2056)*XX(167)-JVS(2129)*XX(168)-JVS(2227)*XX(169)-JVS(2281)*XX(170)-JVS(2366)*XX(172)
  XX(120) = XX(120)-JVS(913)*XX(127)-JVS(995)*XX(132)-JVS(1202)*XX(148)-JVS(1285)*XX(150)-JVS(1677)*XX(162)-JVS(1927)&
              &*XX(166)-JVS(2055)*XX(167)-JVS(2226)*XX(169)-JVS(2312)*XX(171)
  XX(119) = XX(119)-JVS(912)*XX(127)-JVS(1284)*XX(150)-JVS(1676)*XX(162)-JVS(2054)*XX(167)-JVS(2128)*XX(168)-JVS(2225)&
              &*XX(169)
  XX(118) = XX(118)-JVS(862)*XX(123)-JVS(1283)*XX(150)-JVS(1475)*XX(157)-JVS(1574)*XX(160)-JVS(1737)*XX(163)-JVS(1844)&
              &*XX(165)-JVS(1926)*XX(166)-JVS(2053)*XX(167)-JVS(2224)*XX(169)-JVS(2311)*XX(171)
  XX(117) = XX(117)-JVS(813)*XX(119)-JVS(994)*XX(132)-JVS(1201)*XX(148)-JVS(1282)*XX(150)-JVS(1429)*XX(156)-JVS(1843)&
              &*XX(165)-JVS(1925)*XX(166)-JVS(2052)*XX(167)-JVS(2127)*XX(168)-JVS(2223)*XX(169)-JVS(2310)*XX(171)
  XX(116) = XX(116)-JVS(812)*XX(119)-JVS(861)*XX(123)-JVS(1281)*XX(150)-JVS(1338)*XX(151)-JVS(1398)*XX(155)-JVS(1530)&
              &*XX(159)-JVS(1573)*XX(160)-JVS(1675)*XX(162)-JVS(1736)*XX(163)-JVS(1842)*XX(165)-JVS(1924)*XX(166)-JVS(2051)&
              &*XX(167)-JVS(2222)*XX(169)
  XX(115) = XX(115)-JVS(1280)*XX(150)-JVS(1572)*XX(160)-JVS(1735)*XX(163)-JVS(1841)*XX(165)-JVS(1923)*XX(166)-JVS(2050)&
              &*XX(167)-JVS(2221)*XX(169)-JVS(2309)*XX(171)
  XX(114) = XX(114)-JVS(1200)*XX(148)-JVS(1674)*XX(162)-JVS(1734)*XX(163)-JVS(1840)*XX(165)-JVS(1922)*XX(166)-JVS(2049)&
              &*XX(167)-JVS(2126)*XX(168)-JVS(2220)*XX(169)-JVS(2308)*XX(171)-JVS(2365)*XX(172)
  XX(113) = XX(113)-JVS(1015)*XX(133)-JVS(1625)*XX(161)-JVS(1733)*XX(163)-JVS(2048)*XX(167)-JVS(2125)*XX(168)-JVS(2307)&
              &*XX(171)
  XX(112) = XX(112)-JVS(811)*XX(119)-JVS(860)*XX(123)-JVS(1279)*XX(150)-JVS(1337)*XX(151)-JVS(1397)*XX(155)-JVS(1529)&
              &*XX(159)-JVS(1571)*XX(160)-JVS(1732)*XX(163)-JVS(1839)*XX(165)-JVS(1921)*XX(166)-JVS(2047)*XX(167)-JVS(2219)&
              &*XX(169)
  XX(111) = XX(111)-JVS(1278)*XX(150)-JVS(1428)*XX(156)-JVS(1474)*XX(157)-JVS(1570)*XX(160)-JVS(1731)*XX(163)-JVS(1838)&
              &*XX(165)-JVS(1920)*XX(166)-JVS(2046)*XX(167)-JVS(2218)*XX(169)-JVS(2306)*XX(171)
  XX(110) = XX(110)-JVS(837)*XX(121)-JVS(1029)*XX(134)-JVS(1176)*XX(147)-JVS(1277)*XX(150)-JVS(1336)*XX(151)-JVS(1387)&
              &*XX(154)-JVS(1508)*XX(158)-JVS(1673)*XX(162)-JVS(1730)*XX(163)-JVS(1790)*XX(164)-JVS(1837)*XX(165)-JVS(1919)&
              &*XX(166)-JVS(2045)*XX(167)-JVS(2124)*XX(168)-JVS(2217)*XX(169)-JVS(2280)*XX(170)-JVS(2305)*XX(171)-JVS(2364)&
              &*XX(172)
  XX(109) = XX(109)-JVS(1276)*XX(150)-JVS(1672)*XX(162)-JVS(1836)*XX(165)-JVS(1918)*XX(166)-JVS(2044)*XX(167)-JVS(2216)&
              &*XX(169)-JVS(2363)*XX(172)
  XX(108) = XX(108)-JVS(911)*XX(127)-JVS(1624)*XX(161)-JVS(1671)*XX(162)-JVS(1789)*XX(164)-JVS(1835)*XX(165)-JVS(1917)&
              &*XX(166)-JVS(2043)*XX(167)-JVS(2215)*XX(169)
  XX(107) = XX(107)-JVS(1199)*XX(148)-JVS(1670)*XX(162)-JVS(1834)*XX(165)-JVS(1916)*XX(166)-JVS(2042)*XX(167)-JVS(2123)&
              &*XX(168)-JVS(2214)*XX(169)-JVS(2362)*XX(172)
  XX(106) = XX(106)-JVS(993)*XX(132)-JVS(1427)*XX(156)-JVS(1669)*XX(162)-JVS(1833)*XX(165)-JVS(1915)*XX(166)-JVS(2041)&
              &*XX(167)-JVS(2122)*XX(168)-JVS(2213)*XX(169)-JVS(2361)*XX(172)
  XX(105) = XX(105)-JVS(1473)*XX(157)-JVS(1668)*XX(162)-JVS(1729)*XX(163)-JVS(1832)*XX(165)-JVS(1914)*XX(166)-JVS(2040)&
              &*XX(167)-JVS(2121)*XX(168)-JVS(2212)*XX(169)-JVS(2360)*XX(172)
  XX(104) = XX(104)-JVS(910)*XX(127)-JVS(1426)*XX(156)-JVS(1528)*XX(159)-JVS(1667)*XX(162)-JVS(1913)*XX(166)-JVS(2039)&
              &*XX(167)
  XX(103) = XX(103)-JVS(786)*XX(117)-JVS(827)*XX(120)-JVS(859)*XX(123)-JVS(909)*XX(127)-JVS(946)*XX(128)-JVS(958)&
              &*XX(129)-JVS(1275)*XX(150)-JVS(1351)*XX(152)-JVS(1788)*XX(164)-JVS(1912)*XX(166)-JVS(2038)*XX(167)-JVS(2120)&
              &*XX(168)-JVS(2211)*XX(169)
  XX(102) = XX(102)-JVS(1569)*XX(160)-JVS(2037)*XX(167)-JVS(2210)*XX(169)
  XX(101) = XX(101)-JVS(1728)*XX(163)-JVS(2036)*XX(167)
  XX(100) = XX(100)-JVS(1507)*XX(158)-JVS(1666)*XX(162)-JVS(1831)*XX(165)-JVS(1911)*XX(166)-JVS(2035)*XX(167)-JVS(2119)&
              &*XX(168)-JVS(2209)*XX(169)-JVS(2359)*XX(172)
  XX(99) = XX(99)-JVS(626)*XX(101)-JVS(1198)*XX(148)-JVS(1274)*XX(150)-JVS(1425)*XX(156)-JVS(1665)*XX(162)-JVS(1830)&
             &*XX(165)-JVS(1910)*XX(166)-JVS(2034)*XX(167)-JVS(2208)*XX(169)
  XX(98) = XX(98)-JVS(1273)*XX(150)-JVS(1424)*XX(156)-JVS(1664)*XX(162)-JVS(1727)*XX(163)-JVS(1909)*XX(166)-JVS(2033)&
             &*XX(167)-JVS(2118)*XX(168)-JVS(2207)*XX(169)-JVS(2304)*XX(171)
  XX(97) = XX(97)-JVS(810)*XX(119)-JVS(908)*XX(127)-JVS(992)*XX(132)-JVS(1197)*XX(148)-JVS(1367)*XX(153)-JVS(1423)&
             &*XX(156)-JVS(1568)*XX(160)-JVS(1829)*XX(165)-JVS(1908)*XX(166)-JVS(2032)*XX(167)-JVS(2206)*XX(169)
  XX(96) = XX(96)-JVS(907)*XX(127)-JVS(1366)*XX(153)-JVS(1567)*XX(160)-JVS(1828)*XX(165)-JVS(1907)*XX(166)-JVS(2031)&
             &*XX(167)-JVS(2205)*XX(169)
  XX(95) = XX(95)-JVS(1061)*XX(137)-JVS(1072)*XX(138)-JVS(1084)*XX(139)-JVS(1115)*XX(141)-JVS(1136)*XX(143)-JVS(1175)&
             &*XX(147)-JVS(1272)*XX(150)-JVS(1663)*XX(162)-JVS(1787)*XX(164)-JVS(2030)*XX(167)-JVS(2117)*XX(168)-JVS(2204)&
             &*XX(169)-JVS(2279)*XX(170)
  XX(94) = XX(94)-JVS(1155)*XX(145)-JVS(1271)*XX(150)-JVS(1422)*XX(156)-JVS(1662)*XX(162)-JVS(1786)*XX(164)-JVS(1906)&
             &*XX(166)-JVS(2029)*XX(167)-JVS(2116)*XX(168)-JVS(2303)*XX(171)
  XX(93) = XX(93)-JVS(1335)*XX(151)-JVS(1396)*XX(155)-JVS(1527)*XX(159)-JVS(1566)*XX(160)-JVS(1905)*XX(166)-JVS(2028)&
             &*XX(167)-JVS(2203)*XX(169)
  XX(92) = XX(92)-JVS(1060)*XX(137)-JVS(1071)*XX(138)-JVS(1114)*XX(141)-JVS(1145)*XX(144)-JVS(1526)*XX(159)-JVS(1565)&
             &*XX(160)-JVS(1661)*XX(162)-JVS(1785)*XX(164)-JVS(2027)*XX(167)-JVS(2115)*XX(168)-JVS(2202)*XX(169)
  XX(91) = XX(91)-JVS(1270)*XX(150)-JVS(1904)*XX(166)-JVS(2026)*XX(167)-JVS(2114)*XX(168)-JVS(2201)*XX(169)
  XX(90) = XX(90)-JVS(978)*XX(131)-JVS(1154)*XX(145)-JVS(1269)*XX(150)-JVS(2025)*XX(167)-JVS(2302)*XX(171)
  XX(89) = XX(89)-JVS(2024)*XX(167)-JVS(2200)*XX(169)
  XX(88) = XX(88)-JVS(892)*XX(126)-JVS(957)*XX(129)-JVS(1046)*XX(136)-JVS(1564)*XX(160)-JVS(1903)*XX(166)-JVS(2023)&
             &*XX(167)-JVS(2199)*XX(169)
  XX(87) = XX(87)-JVS(785)*XX(117)-JVS(1127)*XX(142)-JVS(1268)*XX(150)-JVS(1350)*XX(152)-JVS(1386)*XX(154)-JVS(1506)&
             &*XX(158)-JVS(2022)*XX(167)-JVS(2198)*XX(169)-JVS(2278)*XX(170)
  XX(86) = XX(86)-JVS(784)*XX(117)-JVS(1126)*XX(142)-JVS(1267)*XX(150)-JVS(1349)*XX(152)-JVS(1385)*XX(154)-JVS(1505)&
             &*XX(158)-JVS(2021)*XX(167)-JVS(2197)*XX(169)-JVS(2277)*XX(170)
  XX(85) = XX(85)-JVS(1421)*XX(156)-JVS(1525)*XX(159)-JVS(2020)*XX(167)-JVS(2113)*XX(168)-JVS(2196)*XX(169)
  XX(84) = XX(84)-JVS(592)*XX(96)-JVS(1524)*XX(159)-JVS(1784)*XX(164)-JVS(2019)*XX(167)-JVS(2195)*XX(169)
  XX(83) = XX(83)-JVS(906)*XX(127)-JVS(1420)*XX(156)-JVS(1660)*XX(162)-JVS(1902)*XX(166)-JVS(2018)*XX(167)
  XX(82) = XX(82)-JVS(524)*XX(85)-JVS(991)*XX(132)-JVS(1125)*XX(142)-JVS(1196)*XX(148)-JVS(1419)*XX(156)-JVS(2017)&
             &*XX(167)-JVS(2112)*XX(168)-JVS(2194)*XX(169)
  XX(81) = XX(81)-JVS(990)*XX(132)-JVS(1028)*XX(134)-JVS(1195)*XX(148)-JVS(1266)*XX(150)-JVS(1523)*XX(159)-JVS(2016)&
             &*XX(167)-JVS(2193)*XX(169)-JVS(2301)*XX(171)
  XX(80) = XX(80)-JVS(2015)*XX(167)-JVS(2192)*XX(169)
  XX(79) = XX(79)-JVS(783)*XX(117)-JVS(1265)*XX(150)-JVS(1348)*XX(152)-JVS(1384)*XX(154)-JVS(1504)*XX(158)-JVS(2014)&
             &*XX(167)-JVS(2191)*XX(169)-JVS(2276)*XX(170)
  XX(78) = XX(78)-JVS(1239)*XX(149)-JVS(1264)*XX(150)-JVS(1418)*XX(156)-JVS(2013)*XX(167)-JVS(2111)*XX(168)-JVS(2190)&
             &*XX(169)
  XX(77) = XX(77)-JVS(809)*XX(119)-JVS(1194)*XX(148)-JVS(1827)*XX(165)-JVS(1901)*XX(166)-JVS(2012)*XX(167)-JVS(2189)&
             &*XX(169)
  XX(76) = XX(76)-JVS(1193)*XX(148)-JVS(1263)*XX(150)-JVS(2011)*XX(167)-JVS(2110)*XX(168)-JVS(2188)*XX(169)-JVS(2300)&
             &*XX(171)
  XX(75) = XX(75)-JVS(808)*XX(119)-JVS(1192)*XX(148)-JVS(1826)*XX(165)-JVS(1900)*XX(166)-JVS(2010)*XX(167)-JVS(2109)&
             &*XX(168)-JVS(2187)*XX(169)
  XX(74) = XX(74)-JVS(476)*XX(77)-JVS(807)*XX(119)-JVS(989)*XX(132)-JVS(1191)*XX(148)-JVS(1262)*XX(150)-JVS(1417)&
             &*XX(156)-JVS(2009)*XX(167)-JVS(2108)*XX(168)-JVS(2186)*XX(169)-JVS(2299)*XX(171)
  XX(73) = XX(73)-JVS(1014)*XX(133)-JVS(1190)*XX(148)-JVS(1261)*XX(150)-JVS(2008)*XX(167)-JVS(2298)*XX(171)
  XX(72) = XX(72)-JVS(1365)*XX(153)-JVS(1563)*XX(160)-JVS(2007)*XX(167)-JVS(2185)*XX(169)
  XX(71) = XX(71)-JVS(1364)*XX(153)-JVS(1522)*XX(159)-JVS(1562)*XX(160)-JVS(2006)*XX(167)-JVS(2184)*XX(169)
  XX(70) = XX(70)-JVS(708)*XX(108)-JVS(905)*XX(127)-JVS(1623)*XX(161)-JVS(1659)*XX(162)-JVS(1899)*XX(166)-JVS(2005)&
             &*XX(167)
  XX(69) = XX(69)-JVS(794)*XX(118)-JVS(858)*XX(123)-JVS(1561)*XX(160)-JVS(1898)*XX(166)-JVS(2004)*XX(167)-JVS(2183)&
             &*XX(169)
  XX(68) = XX(68)-JVS(730)*XX(111)-JVS(1260)*XX(150)-JVS(1416)*XX(156)-JVS(1472)*XX(157)-JVS(2003)*XX(167)-JVS(2182)&
             &*XX(169)
  XX(67) = XX(67)-JVS(1100)*XX(140)-JVS(1471)*XX(157)-JVS(2002)*XX(167)-JVS(2181)*XX(169)
  XX(66) = XX(66)-JVS(1658)*XX(162)-JVS(1726)*XX(163)-JVS(1897)*XX(166)-JVS(2297)*XX(171)
  XX(65) = XX(65)-JVS(1470)*XX(157)-JVS(2001)*XX(167)-JVS(2180)*XX(169)
  XX(64) = XX(64)-JVS(904)*XX(127)-JVS(1083)*XX(139)-JVS(1622)*XX(161)-JVS(1657)*XX(162)-JVS(2000)*XX(167)
  XX(63) = XX(63)-JVS(1621)*XX(161)-JVS(1999)*XX(167)
  XX(62) = XX(62)-JVS(1620)*XX(161)-JVS(1998)*XX(167)
  XX(61) = XX(61)-JVS(399)*XX(62)-JVS(1619)*XX(161)-JVS(1997)*XX(167)
  XX(60) = XX(60)-JVS(1082)*XX(139)-JVS(1469)*XX(157)-JVS(1996)*XX(167)-JVS(2179)*XX(169)
  XX(59) = XX(59)-JVS(903)*XX(127)-JVS(1259)*XX(150)-JVS(1656)*XX(162)-JVS(1725)*XX(163)-JVS(1995)*XX(167)-JVS(2358)&
             &*XX(172)
  XX(58) = XX(58)-JVS(806)*XX(119)-JVS(1189)*XX(148)-JVS(1258)*XX(150)-JVS(1655)*XX(162)-JVS(1825)*XX(165)-JVS(2178)&
             &*XX(169)
  XX(57) = XX(57)-JVS(744)*XX(113)-JVS(968)*XX(130)-JVS(1994)*XX(167)-JVS(2177)*XX(169)
  XX(56) = XX(56)-JVS(764)*XX(115)-JVS(1560)*XX(160)-JVS(1993)*XX(167)-JVS(2176)*XX(169)
  XX(55) = XX(55)-JVS(1257)*XX(150)-JVS(1724)*XX(163)-JVS(1992)*XX(167)-JVS(2175)*XX(169)
  XX(54) = XX(54)-JVS(1654)*XX(162)-JVS(1896)*XX(166)-JVS(1991)*XX(167)-JVS(2174)*XX(169)
  XX(53) = XX(53)-JVS(407)*XX(63)-JVS(763)*XX(115)-JVS(967)*XX(130)-JVS(1618)*XX(161)-JVS(1990)*XX(167)
  XX(52) = XX(52)-JVS(1256)*XX(150)-JVS(1653)*XX(162)-JVS(1723)*XX(163)-JVS(1895)*XX(166)-JVS(2173)*XX(169)
  XX(51) = XX(51)-JVS(605)*XX(98)-JVS(1894)*XX(166)
  XX(50) = XX(50)-JVS(1722)*XX(163)-JVS(1989)*XX(167)-JVS(2296)*XX(171)
  XX(49) = XX(49)-JVS(1824)*XX(165)-JVS(1893)*XX(166)-JVS(1988)*XX(167)
  XX(48) = XX(48)-JVS(1823)*XX(165)-JVS(2172)*XX(169)
  XX(47) = XX(47)-JVS(902)*XX(127)-JVS(1363)*XX(153)-JVS(1652)*XX(162)-JVS(1987)*XX(167)
  XX(46) = XX(46)-JVS(901)*XX(127)
  XX(45) = XX(45)-JVS(782)*XX(117)-JVS(1986)*XX(167)
  XX(44) = XX(44)-JVS(781)*XX(117)-JVS(1985)*XX(167)
  XX(43) = XX(43)-JVS(1822)*XX(165)-JVS(2171)*XX(169)
  XX(42) = XX(42)-JVS(900)*XX(127)-JVS(1651)*XX(162)-JVS(1892)*XX(166)
  XX(41) = XX(41)-JVS(1821)*XX(165)-JVS(2170)*XX(169)
  XX(40) = XX(40)-JVS(780)*XX(117)-JVS(1984)*XX(167)
  XX(39) = XX(39)-JVS(1617)*XX(161)-JVS(1891)*XX(166)
  XX(38) = XX(38)-JVS(314)*XX(43)-JVS(805)*XX(119)-JVS(1188)*XX(148)-JVS(1255)*XX(150)
  XX(37) = XX(37)-JVS(1099)*XX(140)-JVS(1890)*XX(166)
  XX(36) = XX(36)-JVS(612)*XX(99)-JVS(1889)*XX(166)
  XX(35) = XX(35)-JVS(804)*XX(119)-JVS(1187)*XX(148)-JVS(1983)*XX(167)
  XX(34) = XX(34)-JVS(329)*XX(46)
  XX(33) = XX(33)-JVS(306)*XX(41)-JVS(803)*XX(119)-JVS(1254)*XX(150)
  XX(32) = XX(32)-JVS(899)*XX(127)
  XX(31) = XX(31)-JVS(1616)*XX(161)-JVS(1982)*XX(167)
  XX(30) = XX(30)-JVS(1615)*XX(161)-JVS(1981)*XX(167)
  XX(29) = XX(29)-JVS(1614)*XX(161)-JVS(1980)*XX(167)
  XX(28) = XX(28)
  XX(27) = XX(27)
  XX(26) = XX(26)
  XX(25) = XX(25)
  XX(24) = XX(24)
  XX(23) = XX(23)
  XX(22) = XX(22)
  XX(21) = XX(21)
  XX(20) = XX(20)
  XX(19) = XX(19)
  XX(18) = XX(18)
  XX(17) = XX(17)
  XX(16) = XX(16)
  XX(15) = XX(15)
  XX(14) = XX(14)
  XX(13) = XX(13)
  XX(12) = XX(12)
  XX(11) = XX(11)
  XX(10) = XX(10)
  XX(9) = XX(9)
  XX(8) = XX(8)
  XX(7) = XX(7)
  XX(6) = XX(6)
  XX(5) = XX(5)
  XX(4) = XX(4)
  XX(3) = XX(3)
  XX(2) = XX(2)
  XX(1) = XX(1)-JVS(1253)*XX(150)
      
END SUBROUTINE KppSolveTR

! End of KppSolveTR function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! BLAS_UTIL - BLAS-LIKE utility functions
!   Arguments :
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

!--------------------------------------------------------------
!
! BLAS/LAPACK-like subroutines used by the integration algorithms
! It is recommended to replace them by calls to the optimized
!      BLAS/LAPACK library for your machine
!
!  (C) Adrian Sandu, Aug. 2004
!      Virginia Polytechnic Institute and State University
!--------------------------------------------------------------


!--------------------------------------------------------------
      SUBROUTINE WCOPY(N,X,incX,Y,incY)
!--------------------------------------------------------------
!     copies a vector, x, to a vector, y:  y <- x
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL  SCOPY(N,X,1,Y,1)   or   CALL  DCOPY(N,X,1,Y,1)
!--------------------------------------------------------------
!     USE gckpp_Precision
      
      INTEGER  :: i,incX,incY,M,MP1,N
      REAL(kind=dp) :: X(N),Y(N)

      IF (N.LE.0) RETURN

      M = MOD(N,8)
      IF( M .NE. 0 ) THEN
        DO i = 1,M
          Y(i) = X(i)
        END DO
        IF( N .LT. 8 ) RETURN
      END IF    
      MP1 = M+1
      DO i = MP1,N,8
        Y(i) = X(i)
        Y(i + 1) = X(i + 1)
        Y(i + 2) = X(i + 2)
        Y(i + 3) = X(i + 3)
        Y(i + 4) = X(i + 4)
        Y(i + 5) = X(i + 5)
        Y(i + 6) = X(i + 6)
        Y(i + 7) = X(i + 7)
      END DO

      END SUBROUTINE WCOPY


!--------------------------------------------------------------
      SUBROUTINE WAXPY(N,Alpha,X,incX,Y,incY)
!--------------------------------------------------------------
!     constant times a vector plus a vector: y <- y + Alpha*x
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL SAXPY(N,Alpha,X,1,Y,1) or  CALL DAXPY(N,Alpha,X,1,Y,1)
!--------------------------------------------------------------

      INTEGER  :: i,incX,incY,M,MP1,N
      REAL(kind=dp) :: X(N),Y(N),Alpha
      REAL(kind=dp), PARAMETER :: ZERO = 0.0_dp

      IF (Alpha .EQ. ZERO) RETURN
      IF (N .LE. 0) RETURN

      M = MOD(N,4)
      IF( M .NE. 0 ) THEN
        DO i = 1,M
          Y(i) = Y(i) + Alpha*X(i)
        END DO
        IF( N .LT. 4 ) RETURN
      END IF
      MP1 = M + 1
      DO i = MP1,N,4
        Y(i) = Y(i) + Alpha*X(i)
        Y(i + 1) = Y(i + 1) + Alpha*X(i + 1)
        Y(i + 2) = Y(i + 2) + Alpha*X(i + 2)
        Y(i + 3) = Y(i + 3) + Alpha*X(i + 3)
      END DO
      
      END SUBROUTINE WAXPY



!--------------------------------------------------------------
      SUBROUTINE WSCAL(N,Alpha,X,incX)
!--------------------------------------------------------------
!     constant times a vector: x(1:N) <- Alpha*x(1:N) 
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL SSCAL(N,Alpha,X,1) or  CALL DSCAL(N,Alpha,X,1)
!--------------------------------------------------------------

      INTEGER  :: i,incX,M,MP1,N
      REAL(kind=dp)  :: X(N),Alpha
      REAL(kind=dp), PARAMETER  :: ZERO=0.0_dp, ONE=1.0_dp

      IF (Alpha .EQ. ONE) RETURN
      IF (N .LE. 0) RETURN

      M = MOD(N,5)
      IF( M .NE. 0 ) THEN
        IF (Alpha .EQ. (-ONE)) THEN
          DO i = 1,M
            X(i) = -X(i)
          END DO
        ELSEIF (Alpha .EQ. ZERO) THEN
          DO i = 1,M
            X(i) = ZERO
          END DO
        ELSE
          DO i = 1,M
            X(i) = Alpha*X(i)
          END DO
        END IF
        IF( N .LT. 5 ) RETURN
      END IF
      MP1 = M + 1
      IF (Alpha .EQ. (-ONE)) THEN
        DO i = MP1,N,5
          X(i)     = -X(i)
          X(i + 1) = -X(i + 1)
          X(i + 2) = -X(i + 2)
          X(i + 3) = -X(i + 3)
          X(i + 4) = -X(i + 4)
        END DO
      ELSEIF (Alpha .EQ. ZERO) THEN
        DO i = MP1,N,5
          X(i)     = ZERO
          X(i + 1) = ZERO
          X(i + 2) = ZERO
          X(i + 3) = ZERO
          X(i + 4) = ZERO
        END DO
      ELSE
        DO i = MP1,N,5
          X(i)     = Alpha*X(i)
          X(i + 1) = Alpha*X(i + 1)
          X(i + 2) = Alpha*X(i + 2)
          X(i + 3) = Alpha*X(i + 3)
          X(i + 4) = Alpha*X(i + 4)
        END DO
      END IF

      END SUBROUTINE WSCAL

!--------------------------------------------------------------
      REAL(kind=dp) FUNCTION WLAMCH( C )
!--------------------------------------------------------------
!     returns epsilon machine
!     after LAPACK
!     replace this by the function from the optimized LAPACK implementation:
!          CALL SLAMCH('E') or CALL DLAMCH('E')
!--------------------------------------------------------------
!      USE gckpp_Precision

      CHARACTER ::  C
      INTEGER    :: i
      REAL(kind=dp), SAVE  ::  Eps
      REAL(kind=dp)  ::  Suma
      REAL(kind=dp), PARAMETER  ::  ONE=1.0_dp, HALF=0.5_dp
      LOGICAL, SAVE   ::  First=.TRUE.

!$OMP THREADPRIVATE( Eps, First )      

      IF (First) THEN
        First = .FALSE.
        Eps = HALF**(16)
        DO i = 17, 80
          Eps = Eps*HALF
          CALL WLAMCH_ADD(ONE,Eps,Suma)
          IF (Suma.LE.ONE) GOTO 10
        END DO
        PRINT*,'ERROR IN WLAMCH. EPS < ',Eps
        RETURN
10      Eps = Eps*2
        i = i-1      
      END IF

      WLAMCH = Eps

      END FUNCTION WLAMCH
     
      SUBROUTINE WLAMCH_ADD( A, B, Suma )
!      USE gckpp_Precision
      
      REAL(kind=dp) A, B, Suma
      Suma = A + B

      END SUBROUTINE WLAMCH_ADD
!--------------------------------------------------------------


!--------------------------------------------------------------
      SUBROUTINE SET2ZERO(N,Y)
!--------------------------------------------------------------
!     copies zeros into the vector y:  y <- 0
!     after BLAS
!--------------------------------------------------------------
      
      INTEGER ::  i,M,MP1,N
      REAL(kind=dp) ::  Y(N)
      REAL(kind=dp), PARAMETER :: ZERO = 0.0d0

      IF (N.LE.0) RETURN

      M = MOD(N,8)
      IF( M .NE. 0 ) THEN
        DO i = 1,M
          Y(i) = ZERO
        END DO
        IF( N .LT. 8 ) RETURN
      END IF    
      MP1 = M+1
      DO i = MP1,N,8
        Y(i)     = ZERO
        Y(i + 1) = ZERO
        Y(i + 2) = ZERO
        Y(i + 3) = ZERO
        Y(i + 4) = ZERO
        Y(i + 5) = ZERO
        Y(i + 6) = ZERO
        Y(i + 7) = ZERO
      END DO

      END SUBROUTINE SET2ZERO


!--------------------------------------------------------------
      REAL(kind=dp) FUNCTION WDOT (N, DX, incX, DY, incY) 
!--------------------------------------------------------------
!     dot produce: wdot = x(1:N)*y(1:N) 
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL SDOT(N,X,1,Y,1) or  CALL DDOT(N,X,1,Y,1)
!--------------------------------------------------------------
!      USE messy_mecca_kpp_Precision
!--------------------------------------------------------------
      IMPLICIT NONE
      INTEGER :: N, incX, incY
      REAL(kind=dp) :: DX(N), DY(N) 

      INTEGER :: i, IX, IY, M, MP1, NS
                                 
      WDOT = 0.0D0 
      IF (N .LE. 0) RETURN 
      IF (incX .EQ. incY) IF (incX-1) 5,20,60 
!                                                                       
!     Code for unequal or nonpositive increments.                       
!                                                                       
    5 IX = 1 
      IY = 1 
      IF (incX .LT. 0) IX = (-N+1)*incX + 1 
      IF (incY .LT. 0) IY = (-N+1)*incY + 1 
      DO i = 1,N 
        WDOT = WDOT + DX(IX)*DY(IY) 
        IX = IX + incX 
        IY = IY + incY 
      END DO 
      RETURN 
!                                                                       
!     Code for both increments equal to 1.                              
!                                                                       
!     Clean-up loop so remaining vector length is a multiple of 5.      
!                                                                       
   20 M = MOD(N,5) 
      IF (M .EQ. 0) GO TO 40 
      DO i = 1,M 
         WDOT = WDOT + DX(i)*DY(i) 
      END DO 
      IF (N .LT. 5) RETURN 
   40 MP1 = M + 1 
      DO i = MP1,N,5 
          WDOT = WDOT + DX(i)*DY(i) + DX(i+1)*DY(i+1) + DX(i+2)*DY(i+2) +  &
                   DX(i+3)*DY(i+3) + DX(i+4)*DY(i+4)                   
      END DO 
      RETURN 
!                                                                       
!     Code for equal, positive, non-unit increments.                    
!                                                                       
   60 NS = N*incX 
      DO i = 1,NS,incX 
        WDOT = WDOT + DX(i)*DY(i) 
      END DO 

      END FUNCTION WDOT                                          


!--------------------------------------------------------------
      SUBROUTINE WADD(N,X,Y,Z)
!--------------------------------------------------------------
!     adds two vectors: z <- x + y
!     BLAS - like
!--------------------------------------------------------------
!     USE gckpp_Precision
      
      INTEGER :: i, M, MP1, N
      REAL(kind=dp) :: X(N),Y(N),Z(N)

      IF (N.LE.0) RETURN

      M = MOD(N,5)
      IF( M /= 0 ) THEN
         DO i = 1,M
            Z(i) = X(i) + Y(i)
         END DO
         IF( N < 5 ) RETURN
      END IF    
      MP1 = M+1
      DO i = MP1,N,5
         Z(i)     = X(i)     + Y(i)
         Z(i + 1) = X(i + 1) + Y(i + 1)
         Z(i + 2) = X(i + 2) + Y(i + 2)
         Z(i + 3) = X(i + 3) + Y(i + 3)
         Z(i + 4) = X(i + 4) + Y(i + 4)
      END DO

      END SUBROUTINE WADD
      
      
      
!--------------------------------------------------------------
      SUBROUTINE WGEFA(N,A,Ipvt,info)
!--------------------------------------------------------------
!     WGEFA FACTORS THE MATRIX A (N,N) BY
!           GAUSS ELIMINATION WITH PARTIAL PIVOTING
!     LINPACK - LIKE 
!--------------------------------------------------------------
!
      INTEGER       :: N,Ipvt(N),info
      REAL(kind=dp) :: A(N,N)
      REAL(kind=dp) :: t, dmax, da
      INTEGER       :: j,k,l
      REAL(kind=dp), PARAMETER :: ZERO = 0.0, ONE = 1.0

      info = 0

size: IF (n > 1) THEN
      
col:  DO k = 1, n-1

!        find l = pivot index
!        l = idamax(n-k+1,A(k,k),1) + k - 1
         l = k; dmax = abs(A(k,k))
         DO j = k+1,n
            da = ABS(A(j,k))
            IF (da > dmax) THEN
              l = j; dmax = da
            END IF
         END DO
         Ipvt(k) = l

!        zero pivot implies this column already triangularized
         IF (ABS(A(l,k)) < TINY(ZERO)) THEN
            info = k
            return
         ELSE   
            IF (l /= k) THEN
               t = A(l,k); A(l,k) = A(k,k); A(k,k) = t
            END IF
            t = -ONE/A(k,k)
            CALL WSCAL(n-k,t,A(k+1,k),1)
            DO j = k+1, n
               t = A(l,j)
               IF (l /= k) THEN
                  A(l,j) = A(k,j); A(k,j) = t
               END IF
               CALL WAXPY(n-k,t,A(k+1,k),1,A(k+1,j),1)
            END DO         
         END IF
         
       END DO col
       
      END IF size
      
      Ipvt(N) = N
      IF (ABS(A(N,N)) == ZERO) info = N
      
      END SUBROUTINE WGEFA


!--------------------------------------------------------------
      SUBROUTINE WGESL(Trans,N,A,Ipvt,b)
!--------------------------------------------------------------
!     WGESL solves the system
!     a * x = b  or  trans(a) * x = b
!     using the factors computed by WGEFA.
!
!     Trans      = 'N'   to solve  A*x = b ,
!                = 'T'   to solve  transpose(A)*x = b
!     LINPACK - LIKE 
!--------------------------------------------------------------

      INTEGER       :: N,Ipvt(N)
      CHARACTER     :: trans
      REAL(kind=dp) :: A(N,N),b(N)
      REAL(kind=dp) :: t
      INTEGER       :: k,kb,l

      
      SELECT CASE (Trans)

      CASE ('n','N')  !  Solve  A * x = b

!        first solve  L*y = b
         IF (n >= 2) THEN
          DO k = 1, n-1
            l = Ipvt(k)
            t = b(l)
            IF (l /= k) THEN
               b(l) = b(k)
               b(k) = t
            END IF
            CALL WAXPY(n-k,t,a(k+1,k),1,b(k+1),1)
          END DO
         END IF
!        now solve  U*x = y
         DO kb = 1, n
            k = n + 1 - kb
            b(k) = b(k)/a(k,k)
            t = -b(k)
            CALL WAXPY(k-1,t,a(1,k),1,b(1),1)
         END DO
      
      CASE ('t','T')  !  Solve transpose(A) * x = b

!        first solve  trans(U)*y = b
         DO k = 1, n
            t = WDOT(k-1,a(1,k),1,b(1),1)
            b(k) = (b(k) - t)/a(k,k)
         END DO
!        now solve trans(L)*x = y
         IF (n >= 2) THEN
         DO kb = 1, n-1
            k = n - kb
            b(k) = b(k) + WDOT(n-k,a(k+1,k),1,b(k+1),1)
            l = Ipvt(k)
            IF (l /= k) THEN
               t = b(l); b(l) = b(k); b(k) = t
            END IF
         END DO
         END IF
   
      END SELECT

      END SUBROUTINE WGESL
! End of BLAS_UTIL function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~



END MODULE gckpp_LinearAlgebra

